using System;
using System.Data;
using System.Web;
using System.Web.Services;
using System.ComponentModel;

using RAD.AppFramework;
using RAD.AppFramework.Data;
using RAD.AppFramework.QueryObjects;

using NorthwindSample.Common;
using NorthwindSample.Data;
using NorthwindSample.DataAccess.Adapters;

namespace NorthwindSample.BusinessWebService.Base
{
	/// <summary>
	/// OrderDetailsServiceBase is a base business object implementing the most common data operations 
	/// for the Order Details table. 
	/// </summary>
	/// <remarks>
	/// Any application specific business logic must be added to the 
	/// OrderDetailsService class. Do not modify this class.
	///
	/// This class was automatically generated by Rad Software NextGeneration <a href="http://www.radsoftware.com.au">http://www.radsoftware.com.au</a>
	/// </remarks>
	public abstract class OrderDetailsServiceBase : System.Web.Services.WebService
	{
		#region Fields
		
		/// <summary>
		/// The strongly-typed DataAdapter to use for Get and Update operations
		/// </summary>
		protected OrderDetailsDataAdapter m_OrderDetailsAdapter;
		
		/// <summary>
		/// The Database Connection that will be used to read from and update the Database
		/// </summary>
		private DatabaseConnection m_DatabaseConnection;

		#endregion

		#region Constructors
		
		/// <summary>
		/// Creates a new OrderDetailsService
		/// </summary>
		public OrderDetailsServiceBase() : base()
		{
			DatabaseAccessObjectFactory DataObjectFactory = CommonFactory.CreateDataObjectFactory();
		
			DbConnection = new DatabaseConnection(DataObjectFactory.CreateConnection());
			m_OrderDetailsAdapter = new OrderDetailsDataAdapter(DbConnection);

			InitializeComponent();
		}

		/// <summary>
		/// Creates a new OrderDetailsService and sets the Database context
		/// </summary>
		public OrderDetailsServiceBase(DatabaseConnection connection) : base()
		{
			UseConnectionAndTransaction(connection);

			m_OrderDetailsAdapter = new OrderDetailsDataAdapter(connection);

			InitializeComponent();
		}
		
		#endregion
		
		#region Properties
		
		/// <summary>
		/// The Database Connection that will be used to read from and update the Database
		/// </summary>
		protected DatabaseConnection DbConnection
		{
			get { return m_DatabaseConnection; }
			set { m_DatabaseConnection = value; }
		}

		#endregion
		
		#region Public Methods
		
		/// <summary>
		/// Specifies the Database connection to use for any Data Access operations
		/// </summary>
		/// <param name="dbConnection">the Database connection to use for any Data Access operations</param>
		/// <returns>true on success, false otherwise</returns>
		public bool UseConnectionAndTransaction(DatabaseConnection dbConnection)
		{
			m_DatabaseConnection = dbConnection;

			return true;
		}

		/// <summary>
		/// Perform any inserts, updates or deletes on the DataSet
		/// </summary>
		/// <param name="dataSetUpdate">The DataSet to update</param>
		/// <returns>The populated Data Set</returns>
		[WebMethod]
		public DataSet UpdateDataSet(DataSet dataSetUpdate)
		{
			m_OrderDetailsAdapter.UseConnectionAndTransaction(DbConnection);
		
			m_OrderDetailsAdapter.Update(dataSetUpdate);
			
			return  dataSetUpdate;
		}
		
		/// <summary>
		/// Returns all rows from the Order Details table
		/// </summary>
		/// <returns>The populated DataSet</returns>
		[WebMethod]
		public DataSet GetAll()
		{
			m_OrderDetailsAdapter.UseConnectionAndTransaction(DbConnection);
			OrderDetailsDataSet ds = new OrderDetailsDataSet();
			m_OrderDetailsAdapter.Fill(ds);
			return ds;
		}
		
			
		/// <summary>
		/// Return all rows from the Order Details table by Primary Key
		/// </summary>
		/// <param name="OrderID">The OrderID to use as search criteria</param>
		/// <param name="ProductID">The ProductID to use as search criteria</param>
		/// <returns>The DataSet</returns>
		[WebMethod]
		public DataSet GetByOrderIDAndProductID(Int32 OrderID, Int32 ProductID)
		{
			m_OrderDetailsAdapter.UseConnectionAndTransaction(DbConnection);
			
			OrderDetailsDataSet ds = new OrderDetailsDataSet();
			m_OrderDetailsAdapter.FillByOrderIDAndProductID(ds, OrderID, ProductID);
			return ds;
		}
		
		/// <summary>
		/// Return all rows from the Order Details table by OrderID
		/// </summary>
		/// <param name="dataSetFill">The DataSet to return the rows into</param>
		/// <param name="OrderID">The OrderID to use as search criteria</param>
		/// <returns>The number of rows added to the DataSet</returns>
		public int GetByOrderID(DataSet dataSetFill, Int32 OrderID)
		{
			m_OrderDetailsAdapter.UseConnectionAndTransaction(DbConnection);
		
			return m_OrderDetailsAdapter.FillByOrderID(dataSetFill, OrderID);
		}

		/// <summary>
		/// Returns all rows from the Order Details table by OrderID
		/// </summary>
		/// <param name="OrderID">The OrderID to use as search criteria</param>
		/// <returns>The DataSet</returns>
		[WebMethod]
		public DataSet GetByOrderID(Int32 OrderID)
		{
			m_OrderDetailsAdapter.UseConnectionAndTransaction(DbConnection);
		
			OrderDetailsDataSet ds = new OrderDetailsDataSet();
			m_OrderDetailsAdapter.FillByOrderID(ds, OrderID);
			return ds;
		}
		
		/// <summary>
		/// Return all rows from the Order Details table by ProductID
		/// </summary>
		/// <param name="dataSetFill">The DataSet to return the rows into</param>
		/// <param name="ProductID">The ProductID to use as search criteria</param>
		/// <returns>The number of rows added to the DataSet</returns>
		public int GetByProductID(DataSet dataSetFill, Int32 ProductID)
		{
			m_OrderDetailsAdapter.UseConnectionAndTransaction(DbConnection);
		
			return m_OrderDetailsAdapter.FillByProductID(dataSetFill, ProductID);
		}

		/// <summary>
		/// Returns all rows from the Order Details table by ProductID
		/// </summary>
		/// <param name="ProductID">The ProductID to use as search criteria</param>
		/// <returns>The DataSet</returns>
		[WebMethod]
		public DataSet GetByProductID(Int32 ProductID)
		{
			m_OrderDetailsAdapter.UseConnectionAndTransaction(DbConnection);
		
			OrderDetailsDataSet ds = new OrderDetailsDataSet();
			m_OrderDetailsAdapter.FillByProductID(ds, ProductID);
			return ds;
		}
	
			
		/// <summary>
		/// Returns rows by Query Definition
		/// </summary>
		/// <param name="queryDefinition">A Query that defines the query</param>
		/// <returns>A count of the rows added to the DataSet</returns>
		[WebMethod]
		public DataSet GetByQuery(Query queryDefinition)
		{
			m_OrderDetailsAdapter.UseConnectionAndTransaction(DbConnection);
			DataSet ds = new DataSet();
			m_OrderDetailsAdapter.FillByQuery(ds, queryDefinition);
			return ds;
		}
	
		#endregion


		#region Component Designer generated code
		
		//Required by the Web Services Designer 
		private IContainer components = null;
				
		/// <summary>
		/// Required method for Designer support - do not modify
		/// the contents of this method with the code editor.
		/// </summary>
		private void InitializeComponent()
		{
		}

		/// <summary>
		/// Clean up any resources being used.
		/// </summary>
		protected override void Dispose( bool disposing )
		{
			if(disposing && components != null)
			{
				components.Dispose();
			}
			base.Dispose(disposing);		
		}
		
		#endregion
	}
}
