using System;
using System.Data;
using System.Web;
using System.Web.Services;
using System.ComponentModel;

using RAD.AppFramework;
using RAD.AppFramework.Data;
using RAD.AppFramework.QueryObjects;

using NorthwindSample.Common;
using NorthwindSample.Data;
using NorthwindSample.DataAccess.Adapters;

namespace NorthwindSample.BusinessWebService.Base
{
	/// <summary>
	/// OrdersServiceBase is a base business object implementing the most common data operations 
	/// for the Orders table. 
	/// </summary>
	/// <remarks>
	/// Any application specific business logic must be added to the 
	/// OrdersService class. Do not modify this class.
	///
	/// This class was automatically generated by Rad Software NextGeneration <a href="http://www.radsoftware.com.au">http://www.radsoftware.com.au</a>
	/// </remarks>
	public abstract class OrdersServiceBase : System.Web.Services.WebService
	{
		#region Fields
		
		/// <summary>
		/// The strongly-typed DataAdapter to use for Get and Update operations
		/// </summary>
		protected OrdersDataAdapter m_OrdersAdapter;
		
		/// <summary>
		/// The Database Connection that will be used to read from and update the Database
		/// </summary>
		private DatabaseConnection m_DatabaseConnection;

		#endregion

		#region Constructors
		
		/// <summary>
		/// Creates a new OrdersService
		/// </summary>
		public OrdersServiceBase() : base()
		{
			DatabaseAccessObjectFactory DataObjectFactory = CommonFactory.CreateDataObjectFactory();
		
			DbConnection = new DatabaseConnection(DataObjectFactory.CreateConnection());
			m_OrdersAdapter = new OrdersDataAdapter(DbConnection);

			InitializeComponent();
		}

		/// <summary>
		/// Creates a new OrdersService and sets the Database context
		/// </summary>
		public OrdersServiceBase(DatabaseConnection connection) : base()
		{
			UseConnectionAndTransaction(connection);

			m_OrdersAdapter = new OrdersDataAdapter(connection);

			InitializeComponent();
		}
		
		#endregion
		
		#region Properties
		
		/// <summary>
		/// The Database Connection that will be used to read from and update the Database
		/// </summary>
		protected DatabaseConnection DbConnection
		{
			get { return m_DatabaseConnection; }
			set { m_DatabaseConnection = value; }
		}

		#endregion
		
		#region Public Methods
		
		/// <summary>
		/// Specifies the Database connection to use for any Data Access operations
		/// </summary>
		/// <param name="dbConnection">the Database connection to use for any Data Access operations</param>
		/// <returns>true on success, false otherwise</returns>
		public bool UseConnectionAndTransaction(DatabaseConnection dbConnection)
		{
			m_DatabaseConnection = dbConnection;

			return true;
		}

		/// <summary>
		/// Perform any inserts, updates or deletes on the DataSet
		/// </summary>
		/// <param name="dataSetUpdate">The DataSet to update</param>
		/// <returns>The populated Data Set</returns>
		[WebMethod]
		public DataSet UpdateDataSet(DataSet dataSetUpdate)
		{
			m_OrdersAdapter.UseConnectionAndTransaction(DbConnection);
		
			m_OrdersAdapter.Update(dataSetUpdate);
			
			return  dataSetUpdate;
		}
		
		/// <summary>
		/// Returns all rows from the Orders table
		/// </summary>
		/// <returns>The populated DataSet</returns>
		[WebMethod]
		public DataSet GetAll()
		{
			m_OrdersAdapter.UseConnectionAndTransaction(DbConnection);
			OrdersDataSet ds = new OrdersDataSet();
			m_OrdersAdapter.Fill(ds);
			return ds;
		}
		
			
		/// <summary>
		/// Return all rows from the Orders table by Primary Key
		/// </summary>
		/// <param name="OrderID">The OrderID to use as search criteria</param>
		/// <returns>The DataSet</returns>
		[WebMethod]
		public DataSet GetByOrderID(Int32 OrderID)
		{
			m_OrdersAdapter.UseConnectionAndTransaction(DbConnection);
			
			OrdersDataSet ds = new OrdersDataSet();
			m_OrdersAdapter.FillByOrderID(ds, OrderID);
			return ds;
		}
		
		/// <summary>
		/// Return all rows from the Orders table by CustomerID
		/// </summary>
		/// <param name="dataSetFill">The DataSet to return the rows into</param>
		/// <param name="CustomerID">The CustomerID to use as search criteria</param>
		/// <returns>The number of rows added to the DataSet</returns>
		public int GetByCustomerID(DataSet dataSetFill, String CustomerID)
		{
			m_OrdersAdapter.UseConnectionAndTransaction(DbConnection);
		
			return m_OrdersAdapter.FillByCustomerID(dataSetFill, CustomerID);
		}

		/// <summary>
		/// Returns all rows from the Orders table by CustomerID
		/// </summary>
		/// <param name="CustomerID">The CustomerID to use as search criteria</param>
		/// <returns>The DataSet</returns>
		[WebMethod]
		public DataSet GetByCustomerID(String CustomerID)
		{
			m_OrdersAdapter.UseConnectionAndTransaction(DbConnection);
		
			OrdersDataSet ds = new OrdersDataSet();
			m_OrdersAdapter.FillByCustomerID(ds, CustomerID);
			return ds;
		}
		
		/// <summary>
		/// Return all rows from the Orders table by EmployeeID
		/// </summary>
		/// <param name="dataSetFill">The DataSet to return the rows into</param>
		/// <param name="EmployeeID">The EmployeeID to use as search criteria</param>
		/// <returns>The number of rows added to the DataSet</returns>
		public int GetByEmployeeID(DataSet dataSetFill, Int32 EmployeeID)
		{
			m_OrdersAdapter.UseConnectionAndTransaction(DbConnection);
		
			return m_OrdersAdapter.FillByEmployeeID(dataSetFill, EmployeeID);
		}

		/// <summary>
		/// Returns all rows from the Orders table by EmployeeID
		/// </summary>
		/// <param name="EmployeeID">The EmployeeID to use as search criteria</param>
		/// <returns>The DataSet</returns>
		[WebMethod]
		public DataSet GetByEmployeeID(Int32 EmployeeID)
		{
			m_OrdersAdapter.UseConnectionAndTransaction(DbConnection);
		
			OrdersDataSet ds = new OrdersDataSet();
			m_OrdersAdapter.FillByEmployeeID(ds, EmployeeID);
			return ds;
		}
		
		/// <summary>
		/// Return all rows from the Orders table by ShipVia
		/// </summary>
		/// <param name="dataSetFill">The DataSet to return the rows into</param>
		/// <param name="ShipVia">The ShipVia to use as search criteria</param>
		/// <returns>The number of rows added to the DataSet</returns>
		public int GetByShipVia(DataSet dataSetFill, Int32 ShipVia)
		{
			m_OrdersAdapter.UseConnectionAndTransaction(DbConnection);
		
			return m_OrdersAdapter.FillByShipVia(dataSetFill, ShipVia);
		}

		/// <summary>
		/// Returns all rows from the Orders table by ShipVia
		/// </summary>
		/// <param name="ShipVia">The ShipVia to use as search criteria</param>
		/// <returns>The DataSet</returns>
		[WebMethod]
		public DataSet GetByShipVia(Int32 ShipVia)
		{
			m_OrdersAdapter.UseConnectionAndTransaction(DbConnection);
		
			OrdersDataSet ds = new OrdersDataSet();
			m_OrdersAdapter.FillByShipVia(ds, ShipVia);
			return ds;
		}
	
			
		/// <summary>
		/// Returns rows by Query Definition
		/// </summary>
		/// <param name="queryDefinition">A Query that defines the query</param>
		/// <returns>A count of the rows added to the DataSet</returns>
		[WebMethod]
		public DataSet GetByQuery(Query queryDefinition)
		{
			m_OrdersAdapter.UseConnectionAndTransaction(DbConnection);
			DataSet ds = new DataSet();
			m_OrdersAdapter.FillByQuery(ds, queryDefinition);
			return ds;
		}
	
		#endregion


		#region Component Designer generated code
		
		//Required by the Web Services Designer 
		private IContainer components = null;
				
		/// <summary>
		/// Required method for Designer support - do not modify
		/// the contents of this method with the code editor.
		/// </summary>
		private void InitializeComponent()
		{
		}

		/// <summary>
		/// Clean up any resources being used.
		/// </summary>
		protected override void Dispose( bool disposing )
		{
			if(disposing && components != null)
			{
				components.Dispose();
			}
			base.Dispose(disposing);		
		}
		
		#endregion
	}
}
