using System;
using System.Data;
using System.Data.Common;
using System.Data.OleDb;
using System.Data.SqlClient;
using System.ComponentModel;

using NorthwindSample.Common;

using RAD.AppFramework.Data;
using RAD.AppFramework.QueryObjects;

namespace NorthwindSample.DataAccess.Adapters.Base
{
	/// <summary>
	/// OrderDetailsDataAdapterBase handles SELECT, INSERT, UPDATE and DELETE operations 
	/// for the OrderDetails table. 
	/// <seealso cref="OrderDetailsDataAdapter"/>
	/// </summary>
	/// <remarks>
	/// Do not make modifications to this class. Any additional functionality for the OrderDetails table 
	/// must be added to the OrderDetailsDataAdapter class.
	/// <br/><br/>
	/// This class was automatically generated by Rad Software NextGeneration <a href="http://www.radsoftware.com.au">http://www.radsoftware.com.au</a>
	/// </remarks>
	public abstract class OrderDetailsDataAdapterBase : DataAccessObject
	{
		#region Fields
		
		/// <summary>
		/// The name of the stored procedure that is used to retrieve rows from the Order Details table by primary key
		/// </summary>
		protected string SelectByOrderIDAndProductIDCommandName = "gspOrderDetails_SelectByOrderIDAndProductID";
		
		/// <summary>
		/// The stored procedure used to retrieve rows based on the relationship to the Orders table 
		/// </summary>
		protected string SelectByOrderIDCommandName = "gspOrderDetails_SelectByOrderID";
					
		/// <summary>
		/// The stored procedure used to retrieve rows based on the relationship to the Products table 
		/// </summary>
		protected string SelectByProductIDCommandName = "gspOrderDetails_SelectByProductID";
					

		#endregion
		
		
		#region Constructors
		
		/// <summary>
		/// Creates a new OrderDetailsDataAdapterBase 
		/// that uses the specified DatabaseConnection
		/// </summary>
		protected OrderDetailsDataAdapterBase(DatabaseConnection dbconnection) : this()
		{
			UseConnectionAndTransaction(dbconnection);
		}
		
		
		/// <summary>
		/// Creates a new OrderDetailsDataAdapterBase 
		/// </summary>
		public OrderDetailsDataAdapterBase() : base()
		{
			InsertCommandName = "gspOrderDetails_Insert";
			UpdateCommandName = "gspOrderDetails_Update";
			DeleteCommandName = "gspOrderDetails_Delete";
			SelectAllCommandName = "gspOrderDetails_SelectAll";
		
			//
			// Map the default table name of "Table" to the strongly typed DataTable 
			//
			Adapter.TableMappings.Add("Table", "OrderDetails");
			
			
		}
		
		
		#endregion
		
		
		#region Private Methods
		
		
		/// <summary>
		/// Creates an instance of a factory that is used to create Database objects
		/// </summary>
		/// <returns>A DatabaseAccessObjectFactory instance </returns>
		protected override DatabaseAccessObjectFactory CreateDataObjectFactory()
		{
			return CommonFactory.CreateDataObjectFactory();
		}
		

		/// <summary>
		/// Adds parameters representing the columns in the  
		/// new row to the Insert Command
		/// </summary>
		/// <param name="insertCommand">The command to add the parameters to</param>
		protected override void AddInsertCommandParameters(IDbCommand insertCommand)
		{
			base.AddInsertCommandParameters(insertCommand);
			
			insertCommand.Parameters.Add(DataObjectFactory.CreateCommandParameter("@OrderID", "OrderID", SqlDbType.Int));
			insertCommand.Parameters.Add(DataObjectFactory.CreateCommandParameter("@ProductID", "ProductID", SqlDbType.Int));
			insertCommand.Parameters.Add(DataObjectFactory.CreateCommandParameter("@UnitPrice", "UnitPrice", SqlDbType.Money));
			insertCommand.Parameters.Add(DataObjectFactory.CreateCommandParameter("@Quantity", "Quantity", SqlDbType.SmallInt));
			insertCommand.Parameters.Add(DataObjectFactory.CreateCommandParameter("@Discount", "Discount", SqlDbType.Real));
			
		}
		

		/// <summary>
		/// Adds parameters representing the columns in the 
		/// updated row to the Update Command
		/// </summary>
		/// <param name="updateCommand">The Command to add the parameters to</param>
		protected override void AddUpdateCommandParameters(IDbCommand updateCommand)
		{
			base.AddUpdateCommandParameters(updateCommand);
			
			updateCommand.Parameters.Add(DataObjectFactory.CreateCommandParameter("@OrderIDOriginal", "OrderID", SqlDbType.Int, DataRowVersion.Original));
			updateCommand.Parameters.Add(DataObjectFactory.CreateCommandParameter("@OrderID", "OrderID", SqlDbType.Int));
			
			updateCommand.Parameters.Add(DataObjectFactory.CreateCommandParameter("@ProductIDOriginal", "ProductID", SqlDbType.Int, DataRowVersion.Original));
			updateCommand.Parameters.Add(DataObjectFactory.CreateCommandParameter("@ProductID", "ProductID", SqlDbType.Int));
			
			updateCommand.Parameters.Add(DataObjectFactory.CreateCommandParameter("@UnitPrice", "UnitPrice", SqlDbType.Money));
			updateCommand.Parameters.Add(DataObjectFactory.CreateCommandParameter("@Quantity", "Quantity", SqlDbType.SmallInt));
			updateCommand.Parameters.Add(DataObjectFactory.CreateCommandParameter("@Discount", "Discount", SqlDbType.Real));
			
		}
		

		/// <summary>
		/// Adds parameters representing the columns in the
		/// deleted row to the Delete Command
		/// </summary>
		/// <param name="deleteCommand">The Command to add the parameters to</param>
		protected override void AddDeleteCommandParameters(IDbCommand deleteCommand)
		{
			base.AddDeleteCommandParameters(deleteCommand);
			
			deleteCommand.Parameters.Add(DataObjectFactory.CreateCommandParameter("@OrderID", "OrderID", SqlDbType.Int));
			deleteCommand.Parameters.Add(DataObjectFactory.CreateCommandParameter("@ProductID", "ProductID", SqlDbType.Int));
			
		}

		
		#endregion
		
		
		#region Public Methods
		
		/// <summary>
		/// Calls the respective INSERT, UPDATE, or DELETE statements 
		/// for each inserted, updated, or deleted row in the specified DataSet
		/// </summary>
		/// <param name="dataSetUpdate">The DataSet used to update the data source</param>
		/// <returns>The number of rows successfully updated from the DataSet</returns>
		public override int Update(DataSet dataSetUpdate)
		{
			int baseCount = base.Update(dataSetUpdate);
			
			if (AdapterCommands.InsertCommand == null)
			{
				//
				// Open the Database Connection 
				//
				DbConnection.Open();

				//
				// Insert Command
				//
				IDbCommand InsertCommand = DataObjectFactory.CreateCommand(DbConnection, CommandType.StoredProcedure);
				InsertCommand.CommandText = InsertCommandName;
				InsertCommand.UpdatedRowSource = UpdateRowSource.FirstReturnedRecord;
				AddInsertCommandParameters(InsertCommand);
				AdapterCommands.InsertCommand = InsertCommand;

				//
				// Update Command
				//
				IDbCommand UpdateCommand = DataObjectFactory.CreateCommand(DbConnection, CommandType.StoredProcedure);
				UpdateCommand.CommandText = UpdateCommandName;
				UpdateCommand.UpdatedRowSource = UpdateRowSource.FirstReturnedRecord;
				AddUpdateCommandParameters(UpdateCommand);
				AdapterCommands.UpdateCommand = UpdateCommand;

				//
				// Delete Command
				//
				IDbCommand DeleteCommand = DataObjectFactory.CreateCommand(DbConnection, CommandType.StoredProcedure);
				DeleteCommand.CommandText = DeleteCommandName;
				AddDeleteCommandParameters(DeleteCommand);
				AdapterCommands.DeleteCommand = DeleteCommand;
			}
			else
			{
				//
				// DataAdapter and Command objects have already been created
				// make sure the current connection and transaction are being used
				//
				DbConnection.Open();
				
				AdapterCommands.InsertCommand.Connection = DbConnection.Connection;
				AdapterCommands.InsertCommand.Transaction = DbConnection.Transaction;

				AdapterCommands.UpdateCommand.Connection = DbConnection.Connection;
				AdapterCommands.UpdateCommand.Transaction = DbConnection.Transaction;

				AdapterCommands.DeleteCommand.Connection = DbConnection.Connection;
				AdapterCommands.DeleteCommand.Transaction = DbConnection.Transaction;
			}

			//
			// Apply the changes in the DataSet and return the number of affected rows
			//
			try
			{
				return baseCount + Adapter.Update(dataSetUpdate);
			}
			finally
			{
				DbConnection.Close();
			}
		}
		
		
		/// <summary>
		/// Fill the DataSet with all rows from the OrderDetails Table
		/// </summary>
		/// <param name="dataSetFill">The DataSet to fill</param>
		/// <returns>A count of the rows added to the DataSet</returns>
		public override int Fill(DataSet dataSetFill)
		{
			int baseCount = base.Fill(dataSetFill);
			
			IDbCommand FillCommand = DataObjectFactory.CreateCommand(DbConnection, CommandType.StoredProcedure);

			FillCommand.CommandText = SelectAllCommandName;
			
			return baseCount + LoadFromCommand(dataSetFill, FillCommand);
		}
		
		
		/// <summary>
		/// Fill the DataSet by Query Definition
		/// </summary>
		/// <param name="dataSetFill">The DataSet to fill</param>
		/// <param name="queryDefinition">An Query object that defines the the query</param>
		/// <returns>A count of the rows added to the DataSet</returns>
		public override int FillByQuery(DataSet dataSetFill, Query queryDefinition)
		{
			if (queryDefinition == null)
			{
				throw new ArgumentNullException("queryDefinition");
			}

			IDbCommand FillCommand = DataObjectFactory.CreateCommand(DbConnection, CommandType.Text);

			if (queryDefinition.TableName.Length == 0)
			{
				queryDefinition.TableName = "gvwOrderDetails";
			}

			queryDefinition.BuildCommand(FillCommand);
			
			return LoadFromCommand(dataSetFill, FillCommand);
		}

		
		
		/// <summary>
		/// Fill the DataSet with all rows from the Order Details Table by Primary key (OrderID and ProductID)
		/// </summary>
		/// <param name="dataSetFill">The DataSet to fill</param>
		/// <param name="OrderID">The OrderID to use as search criteria</param>
		/// <param name="ProductID">The ProductID to use as search criteria</param>
		/// <returns>A count of the rows added to the DataSet</returns>
		public int FillByOrderIDAndProductID(DataSet dataSetFill, Int32 OrderID, Int32 ProductID)
		{
			IDbCommand FillCommand = DataObjectFactory.CreateCommand(DbConnection, CommandType.StoredProcedure);

			FillCommand.CommandText = SelectByOrderIDAndProductIDCommandName;

			FillCommand.Parameters.Add(DataObjectFactory.CreateCommandParameter("@OrderID", SqlDbType.Int, OrderID));
			FillCommand.Parameters.Add(DataObjectFactory.CreateCommandParameter("@ProductID", SqlDbType.Int, ProductID));
			
			return LoadFromCommand(dataSetFill, FillCommand);
		}	


		/// <summary>
		/// Fill the DataSet with rows from the Order Details table that match the specified OrderID
		/// </summary>
		/// <param name="dataSetFill">The DataSet to fill</param>
		/// <param name="OrderID">The OrderID to use as search criteria</param>
		/// <returns>A count of the rows added to the DataSet</returns>
		public int FillByOrderID(DataSet dataSetFill, Int32 OrderID)
		{
			IDbCommand FillCommand = DataObjectFactory.CreateCommand(DbConnection, CommandType.StoredProcedure);

			FillCommand.CommandText = SelectByOrderIDCommandName;

			FillCommand.Parameters.Add(DataObjectFactory.CreateCommandParameter("@OrderID", SqlDbType.Int, OrderID));
			
			return LoadFromCommand(dataSetFill, FillCommand);
		}	


		/// <summary>
		/// Fill the DataSet with rows from the Order Details table that match the specified ProductID
		/// </summary>
		/// <param name="dataSetFill">The DataSet to fill</param>
		/// <param name="ProductID">The ProductID to use as search criteria</param>
		/// <returns>A count of the rows added to the DataSet</returns>
		public int FillByProductID(DataSet dataSetFill, Int32 ProductID)
		{
			IDbCommand FillCommand = DataObjectFactory.CreateCommand(DbConnection, CommandType.StoredProcedure);

			FillCommand.CommandText = SelectByProductIDCommandName;

			FillCommand.Parameters.Add(DataObjectFactory.CreateCommandParameter("@ProductID", SqlDbType.Int, ProductID));
			
			return LoadFromCommand(dataSetFill, FillCommand);
		}	


		
		#endregion
	}
}
