using System;
using System.Data;
using System.Data.OleDb;
using System.Data.SqlClient;
using System.Collections;

using RAD.AppFramework.Data;
using RAD.AppFramework.QueryObjects;

using NorthwindSample.Common;
using NorthwindSample.DataAccess;

namespace NorthwindSample.DataAccess.Readers.Base
{
	/// <summary>
	/// Base class for the OrderDetailsDataReader
	/// <seealso cref="OrderDetailsDataReader"/>
	/// </summary>
	/// <remarks>
	/// Provides forward-only read access to the Order Details table.
	/// 
	/// This class has been auto-generated and should not be modified. Any modifications should
	/// be made to the <see cref="OrderDetailsDataReader">OrderDetailsDataReader</see> class.
	/// <br/><br/>
	/// This class was automatically generated by Rad Software NextGeneration <a href="http://www.radsoftware.com.au">http://www.radsoftware.com.au</a>
	/// </remarks>
	public class OrderDetailsDataReaderBase : StronglyTypedDataReader
	{		
		#region Fields
	
		/// <summary>The ordinal position of the OrderID column in the result set</summary>
		protected int m_OrderIDOrdinal;
		/// <summary>The ordinal position of the ProductID column in the result set</summary>
		protected int m_ProductIDOrdinal;
		/// <summary>The ordinal position of the UnitPrice column in the result set</summary>
		protected int m_UnitPriceOrdinal;
		/// <summary>The ordinal position of the Quantity column in the result set</summary>
		protected int m_QuantityOrdinal;
		/// <summary>The ordinal position of the Discount column in the result set</summary>
		protected int m_DiscountOrdinal;
			
		#endregion
		
		
		#region Constructors
		
		/// <summary>
		/// Creates a new Order DetailsDataReaderBase
		/// </summary>
		public OrderDetailsDataReaderBase()
		{
			DatabaseAccessObjectFactory DataObjectFactory = CommonFactory.CreateDataObjectFactory();
		
			Connection = DataObjectFactory.CreateConnection();
		}
		
		#endregion
		

		#region Column Attributes


		/// <summary>
		/// Returns the value of the OrderID column for the current row
		/// </summary>
		public Int32 OrderID
		{
			get 
			{
					return (Int32)DataRecord[m_OrderIDOrdinal];
			}
		}
	
		/// <summary>
		/// Returns the value of the ProductID column for the current row
		/// </summary>
		public Int32 ProductID
		{
			get 
			{
					return (Int32)DataRecord[m_ProductIDOrdinal];
			}
		}
	
		/// <summary>
		/// Returns the value of the UnitPrice column for the current row
		/// </summary>
		public Decimal UnitPrice
		{
			get 
			{
					return (Decimal)DataRecord[m_UnitPriceOrdinal];
			}
		}
	
		/// <summary>
		/// Returns the value of the Quantity column for the current row
		/// </summary>
		public Int16 Quantity
		{
			get 
			{
					return (Int16)DataRecord[m_QuantityOrdinal];
			}
		}
	
		/// <summary>
		/// Returns the value of the Discount column for the current row
		/// </summary>
		public Single Discount
		{
			get 
			{
					return (Single)DataRecord[m_DiscountOrdinal];
			}
		}
	

		#endregion

		
		#region Private Methods
		
		/// <summary>
		/// Sets the indexes of the columns within the result set
		/// </summary>
		protected override void SetColumnOrdinals()
		{
			m_OrderIDOrdinal = DataReader.GetOrdinal("OrderID");
			m_ProductIDOrdinal = DataReader.GetOrdinal("ProductID");
			m_UnitPriceOrdinal = DataReader.GetOrdinal("UnitPrice");
			m_QuantityOrdinal = DataReader.GetOrdinal("Quantity");
			m_DiscountOrdinal = DataReader.GetOrdinal("Discount");
		}
		
		#endregion
		
		
		#region Public Methods
		
		/// <summary>
		/// Selects all rows from the Order Details table
		/// </summary>
		/// <returns>true on success, false otherwise</returns>
		public bool SelectAll()
		{
			DatabaseAccessObjectFactory DataObjectFactory = CommonFactory.CreateDataObjectFactory();
		
			CommandSelect = DataObjectFactory.CreateCommand(Connection, CommandType.StoredProcedure);
			CommandSelect.CommandText = "gspOrderDetails_SelectAll";
			
			return OpenReader();
		}
		
		/// <summary>
		/// Selects rows from the Order Details table by Query definion
		/// </summary>
		/// <param name="queryDefinition">A Query object that defines the Query used to select rows from the database</param>
		/// <returns>true on success, false otherwise</returns>
		public bool SelectByQuery(Query queryDefinition)
		{
			DatabaseAccessObjectFactory DataObjectFactory = CommonFactory.CreateDataObjectFactory();

			CommandSelect = DataObjectFactory.CreateCommand(Connection, CommandType.Text);

			if (queryDefinition.TableName.Length == 0)
			{
				queryDefinition.TableName = "gvwOrder Details";
			}

			queryDefinition.BuildCommand(CommandSelect);

			return OpenReader();
		}
		
		
		/// <summary>
		/// Selects rows from the Order Details table by Primary Key (OrderID, ProductID)
		/// </summary>
		/// <param name="OrderID">The OrderID to use as search criteria</param>
		/// <param name="ProductID">The ProductID to use as search criteria</param>
		/// <returns>true on success, false otherwise</returns>
		public bool SelectByOrderIDAndProductID(Int32 OrderID, Int32 ProductID)
		{
			DatabaseAccessObjectFactory DataObjectFactory = CommonFactory.CreateDataObjectFactory();
		
			CommandSelect = DataObjectFactory.CreateCommand(Connection, CommandType.StoredProcedure);
			CommandSelect.CommandText = "gspOrderDetails_SelectByOrderIDAndProductID";
			
			CommandSelect.Parameters.Add(DataObjectFactory.CreateCommandParameter("@OrderID", SqlDbType.Int, OrderID));
			CommandSelect.Parameters.Add(DataObjectFactory.CreateCommandParameter("@ProductID", SqlDbType.Int, ProductID));
			
			return OpenReader();
		}
		
		/// <summary>
		/// Selects rows from the Order Details table by OrderID
		/// </summary>
		/// <param name="OrderID">The OrderID to use as search criteria</param>
		/// <returns>true on success, false otherwise</returns>
		public bool SelectByOrderID(Int32 OrderID)
		{
			DatabaseAccessObjectFactory DataObjectFactory = CommonFactory.CreateDataObjectFactory();
		
			CommandSelect = DataObjectFactory.CreateCommand(Connection, CommandType.StoredProcedure);
			CommandSelect.CommandText = "gspOrderDetails_SelectByOrderID";
			
			CommandSelect.Parameters.Add(DataObjectFactory.CreateCommandParameter("@OrderID", SqlDbType.Int, OrderID));
			
			return OpenReader();
		}
		
		/// <summary>
		/// Selects rows from the Order Details table by ProductID
		/// </summary>
		/// <param name="ProductID">The ProductID to use as search criteria</param>
		/// <returns>true on success, false otherwise</returns>
		public bool SelectByProductID(Int32 ProductID)
		{
			DatabaseAccessObjectFactory DataObjectFactory = CommonFactory.CreateDataObjectFactory();
		
			CommandSelect = DataObjectFactory.CreateCommand(Connection, CommandType.StoredProcedure);
			CommandSelect.CommandText = "gspOrderDetails_SelectByProductID";
			
			CommandSelect.Parameters.Add(DataObjectFactory.CreateCommandParameter("@ProductID", SqlDbType.Int, ProductID));
			
			return OpenReader();
		}
		
		
		
		
		#endregion
	}
}
