using System;
using System.Data;
using System.Data.OleDb;
using System.Data.SqlClient;
using System.Collections;

using RAD.AppFramework.Data;
using RAD.AppFramework.QueryObjects;

using NorthwindSample.Common;
using NorthwindSample.DataAccess;

namespace NorthwindSample.DataAccess.Readers.Base
{
	/// <summary>
	/// Base class for the ShippersDataReader
	/// <seealso cref="ShippersDataReader"/>
	/// </summary>
	/// <remarks>
	/// Provides forward-only read access to the Shippers table.
	/// 
	/// This class has been auto-generated and should not be modified. Any modifications should
	/// be made to the <see cref="ShippersDataReader">ShippersDataReader</see> class.
	/// <br/><br/>
	/// This class was automatically generated by Rad Software NextGeneration <a href="http://www.radsoftware.com.au">http://www.radsoftware.com.au</a>
	/// </remarks>
	public class ShippersDataReaderBase : StronglyTypedDataReader
	{		
		#region Fields
	
		/// <summary>The ordinal position of the ShipperID column in the result set</summary>
		protected int m_ShipperIDOrdinal;
		/// <summary>The ordinal position of the CompanyName column in the result set</summary>
		protected int m_CompanyNameOrdinal;
		/// <summary>The ordinal position of the Phone column in the result set</summary>
		protected int m_PhoneOrdinal;
			
		#endregion
		
		
		#region Constructors
		
		/// <summary>
		/// Creates a new ShippersDataReaderBase
		/// </summary>
		public ShippersDataReaderBase()
		{
			DatabaseAccessObjectFactory DataObjectFactory = CommonFactory.CreateDataObjectFactory();
		
			Connection = DataObjectFactory.CreateConnection();
		}
		
		#endregion
		

		#region Column Attributes


		/// <summary>
		/// Returns the value of the ShipperID column for the current row
		/// </summary>
		public Int32 ShipperID
		{
			get 
			{
					return (Int32)DataRecord[m_ShipperIDOrdinal];
			}
		}
	
		/// <summary>
		/// Returns the value of the CompanyName column for the current row
		/// </summary>
		public String CompanyName
		{
			get 
			{
					return (String)DataRecord[m_CompanyNameOrdinal];
			}
		}
	
		/// <summary>
		/// Returns the value of the Phone column for the current row
		/// </summary>
		public String Phone
		{
			get 
			{
				try
				{
					return (String)DataRecord[m_PhoneOrdinal];
				}
				catch (InvalidCastException e) 
				{
					throw new StrongTypingException("Cannot get value because it is DBNull.", e);
				}
			}
		}
	

		#endregion

		
		#region Private Methods
		
		/// <summary>
		/// Sets the indexes of the columns within the result set
		/// </summary>
		protected override void SetColumnOrdinals()
		{
			m_ShipperIDOrdinal = DataReader.GetOrdinal("ShipperID");
			m_CompanyNameOrdinal = DataReader.GetOrdinal("CompanyName");
			m_PhoneOrdinal = DataReader.GetOrdinal("Phone");
		}
		
		#endregion
		
		
		#region Public Methods
		
		/// <summary>
		/// Selects all rows from the Shippers table
		/// </summary>
		/// <returns>true on success, false otherwise</returns>
		public bool SelectAll()
		{
			DatabaseAccessObjectFactory DataObjectFactory = CommonFactory.CreateDataObjectFactory();
		
			CommandSelect = DataObjectFactory.CreateCommand(Connection, CommandType.StoredProcedure);
			CommandSelect.CommandText = "gspShippers_SelectAll";
			
			return OpenReader();
		}
		
		/// <summary>
		/// Selects rows from the Shippers table by Query definion
		/// </summary>
		/// <param name="queryDefinition">A Query object that defines the Query used to select rows from the database</param>
		/// <returns>true on success, false otherwise</returns>
		public bool SelectByQuery(Query queryDefinition)
		{
			DatabaseAccessObjectFactory DataObjectFactory = CommonFactory.CreateDataObjectFactory();

			CommandSelect = DataObjectFactory.CreateCommand(Connection, CommandType.Text);

			if (queryDefinition.TableName.Length == 0)
			{
				queryDefinition.TableName = "gvwShippers";
			}

			queryDefinition.BuildCommand(CommandSelect);

			return OpenReader();
		}
		
		
		/// <summary>
		/// Selects rows from the Shippers table by Primary Key (ShipperID)
		/// </summary>
		/// <param name="ShipperID">The ShipperID to use as search criteria</param>
		/// <returns>true on success, false otherwise</returns>
		public bool SelectByShipperID(Int32 ShipperID)
		{
			DatabaseAccessObjectFactory DataObjectFactory = CommonFactory.CreateDataObjectFactory();
		
			CommandSelect = DataObjectFactory.CreateCommand(Connection, CommandType.StoredProcedure);
			CommandSelect.CommandText = "gspShippers_SelectByShipperID";
			
			CommandSelect.Parameters.Add(DataObjectFactory.CreateCommandParameter("@ShipperID", SqlDbType.Int, ShipperID));
			
			return OpenReader();
		}
		
		/// <summary>
		/// Checks if the value of the Phone column is NULL
		/// </summary>
		/// <returns>true if Phone is NULL, false if it is not NULL</returns>
		public bool IsPhoneNull()
		{
			return DataRecord.IsDBNull(m_PhoneOrdinal);
		}
		
		
		
		
		#endregion
	}
}
