<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet 
	version="1.0" 
	xmlns:xsl="http://www.w3.org/1999/XSL/Transform" 
	>

<xsl:output 
	method="text" 
	indent="no" 
	omit-xml-declaration="yes" 
	/>
<!-- 
//
// NextGeneration Template
// 
// Template Set:	Business Service Interfaces
// Language:		.NET C#
// Template:		Business Service Base Interface
//
// Copyright (c) Ross Donald 2003-2004
// http://www.radsoftware.com.au
//
-->

<!-- FileName = "I{0}ServiceBase.cs" -->
<!-- Folder = "BusinessServiceInterfaces\Base" -->

<xsl:param name="ObjectName" select="'Timesheet'"/>
<xsl:param name="Namespace" select="'NextGeneration'"/>

<!--
//
// Main Template
//
-->
<xsl:template match="/">

	<!-- 
	// Create the Business Service classes 
	-->	
	<xsl:apply-templates select="/db/Table[table_name_safe = $ObjectName]"/>	
	
</xsl:template>


<!--
//
// Create the IBusinessServiceBase class
//
-->
<xsl:template match="Table">

	<xsl:text>
using System;
using System.Data;

using RAD.AppFramework.QueryObjects;

using </xsl:text><xsl:value-of select="$Namespace"/><xsl:text>.Data;

namespace </xsl:text>
<xsl:value-of select="$Namespace"/>
<xsl:text>.BusinessServiceInterfaces.Base
{
	/// &lt;summary&gt;
	/// </xsl:text>
	<xsl:value-of select="table_name_safe" />
	<xsl:text>ServiceBase defines the methods that are automatically generated for Business services.
	/// &lt;/summary&gt;
	/// &lt;remarks&gt;
	/// Any additional functionality must be added to the </xsl:text>
	<xsl:value-of select="table_name_safe" /><xsl:text>Service class.
	/// &lt;br/&gt;&lt;br/&gt;
	/// This class was automatically generated by Rad Software NextGeneration &lt;a href="http://www.radsoftware.com.au"&gt;http://www.radsoftware.com.au&lt;/a&gt;
	/// &lt;/remarks&gt;
	public interface I</xsl:text><xsl:value-of select="table_name_safe" /><xsl:text>ServiceBase
	{
		/// &lt;summary&gt;
		/// Fills the DataSet with all rows from the </xsl:text><xsl:value-of select="table_name" /><xsl:text> table
		/// &lt;/summary&gt;
		/// &lt;param name=&quot;dataSetFill&quot;&gt;The DataSet to fill&lt;/param&gt;
		/// &lt;returns&gt;A count of the rows selected&lt;/returns&gt;
		int GetAll(</xsl:text><xsl:value-of select="table_name_safe" /><xsl:text>DataSet dataSetFill);
		
		/// &lt;summary&gt;
		/// Fills a DataSet based on a Query definition
		/// &lt;/summary&gt;
		/// &lt;param name=&quot;dataSetFill&quot;&gt;The DataSet to return the rows into&lt;/param&gt;
		/// &lt;param name=&quot;queryDefinition&quot;&gt;A Query object that defines the query&lt;/param&gt;
		/// &lt;returns&gt;A count of the rows added to the DataSet&lt;/returns&gt;
		int GetByQuery(DataSet dataSetFill, Query queryDefinition);
		
		/// &lt;summary&gt;
		/// Perform any inserts, updates or deletes on the DataSet
		/// &lt;/summary&gt;
		/// &lt;param name="dataSetUpdate"&gt;The DataSet to update&lt;/param&gt;
		/// &lt;returns&gt;The number of rows updated&lt;/returns&gt;
		int UpdateDataSet(</xsl:text><xsl:value-of select="table_name_safe" /><xsl:text>DataSet dataSetUpdate);
		
		</xsl:text>
		<xsl:if test="count(Column[is_key='true']) &gt; 0">
			<xsl:apply-templates select="." mode="GetByPK"/>
		</xsl:if>
		<xsl:for-each select="Foreign_Key_Child">
			<xsl:variable name="pkcol" select="../Column[is_key='true']/column_name"/>
			<xsl:variable name="fkcol" select="Column/fk_column_name"/>
						
			<!-- 
			Compare the primary key column names to the columns in the foreign key. 
			if they are equal then do not create a SelectByFK method as it would 
			be the same as the SelectByPK method. Bug 0000002.
			-->
			<xsl:variable name="compare">
				<xsl:for-each select="$pkcol">
					<xsl:if test="not($fkcol = string(current()))">
						<xsl:text>NEQ</xsl:text>
					</xsl:if>
				</xsl:for-each>
			</xsl:variable>
			<xsl:choose>
				<xsl:when test="normalize-space($compare)">
					<xsl:apply-templates select="."/>
				</xsl:when>
				<!--	<xsl:otherwise>fk columns are equal to the primary key</xsl:otherwise>-->
			</xsl:choose>
		</xsl:for-each>		
		<xsl:text>
	}
}

</xsl:text>


</xsl:template>
<!--
	//
	// Generate a Get command for a Primary key
	//
-->
<xsl:template match="Table" mode="GetByPK">

	<xsl:text>	
		/// &lt;summary&gt;
		/// Return all rows from the </xsl:text>
		<xsl:value-of select="table_name" />
		<xsl:text> table by Primary Key
		/// &lt;/summary&gt;
		/// &lt;param name="dataSetFill"&gt;The DataSet to return the rows into&lt;/param&gt;</xsl:text>
		<xsl:for-each select="Column[is_key = 'true']">
		<xsl:text>
		/// &lt;param name="</xsl:text><xsl:value-of select="column_name_safe" /><xsl:text>"&gt;The </xsl:text><xsl:value-of select="column_name_safe" /><xsl:text> to use as search criteria&lt;/param&gt;</xsl:text>
		</xsl:for-each>
		<xsl:text>
		/// &lt;returns&gt;The number of rows added to the DataSet&lt;/returns&gt;
		int GetBy</xsl:text>

	<xsl:for-each select="Column[is_key = 'true']">

		<xsl:if test="position() != 1">
			<xsl:text>And</xsl:text>
		</xsl:if>
		<xsl:value-of select="column_name_safe" />
			
	</xsl:for-each>
	
	<xsl:text>(</xsl:text><xsl:value-of select="table_name_safe" /><xsl:text>DataSet dataSetFill, </xsl:text>
	
		
	<xsl:for-each select="Column[is_key = 'true']">
	
		<xsl:if test="position() != 1">
			<xsl:text>, </xsl:text>
		</xsl:if>
		<xsl:value-of select="data_type_clr" />
		<xsl:text> </xsl:text>
		<xsl:value-of select="column_name_safe" />
			
	</xsl:for-each>
	
	<xsl:text>);
	</xsl:text>
	
</xsl:template>




<!--
	//
	// Generate a Get command for a foreign key
	//
-->
<xsl:template match="Foreign_Key_Child">

	<xsl:text>	
		/// &lt;summary&gt;
		/// Return all rows from the </xsl:text>
		<xsl:value-of select="parent::*/table_name" />
		<xsl:text> table by </xsl:text>
		
		<xsl:for-each select="Column">
	
			<xsl:variable name="FKColumnName" select="fk_column_name"/>
	
			<xsl:choose>
				<xsl:when test="position() != 1 and position() != last()">
					<xsl:text>, </xsl:text>
				</xsl:when>
				
				<xsl:when test="position() != 1 and position() = last()">
					<xsl:text> and </xsl:text>
				</xsl:when>
			
			</xsl:choose>
	
			<xsl:value-of select="parent::*/parent::*/Column[column_name=$FKColumnName]/column_name_safe" />
			
		</xsl:for-each>
		<xsl:text>
		/// &lt;/summary&gt;
		/// &lt;param name="dataSetFill"&gt;The DataSet to return the rows into&lt;/param&gt;</xsl:text>
		
		<xsl:for-each select="Column">
	
			<xsl:variable name="FKColumnName" select="fk_column_name"/>
	
			<xsl:text>
		/// &lt;param name="</xsl:text>
		<xsl:value-of select="parent::*/parent::*/Column[column_name=$FKColumnName]/column_name_safe" />
		<xsl:text>"&gt;The </xsl:text>
		<xsl:value-of select="parent::*/parent::*/Column[column_name=$FKColumnName]/column_name_safe" />
		<xsl:text> to use as search criteria&lt;/param&gt;</xsl:text>
	
		</xsl:for-each>

		<xsl:text>
		/// &lt;returns&gt;The number of rows added to the DataSet&lt;/returns&gt;
		int GetBy</xsl:text>

	<xsl:for-each select="Column">
	
		<xsl:variable name="FKColumnName" select="fk_column_name"/>

		<xsl:if test="position() != 1">
			<xsl:text>And</xsl:text>
		</xsl:if>
		<xsl:value-of select="parent::*/parent::*/Column[column_name=$FKColumnName]/column_name_safe" />
			
	</xsl:for-each>
	
	<xsl:text>(</xsl:text><xsl:value-of select="parent::*/table_name_safe" /><xsl:text>DataSet dataSetFill, </xsl:text>
		
	<xsl:for-each select="Column">
	
		<xsl:variable name="FKColumnName" select="fk_column_name"/>

		<xsl:if test="position() != 1">
			<xsl:text>, </xsl:text>
		</xsl:if>
		<xsl:value-of select="parent::*/parent::*/Column[column_name=$FKColumnName]/data_type_clr" />
		<xsl:text> </xsl:text>
		<xsl:value-of select="parent::*/parent::*/Column[column_name=$FKColumnName]/column_name_safe" />
			
	</xsl:for-each>
	
	<xsl:text>);
	</xsl:text>
	
</xsl:template>

</xsl:stylesheet>

