<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet 
	version="1.0" 
	xmlns:xsl="http://www.w3.org/1999/XSL/Transform" 
	>

<xsl:output 
	method="text" 
	indent="no" 
	omit-xml-declaration="yes" 
	/>
<!-- 
//
// NextGeneration Template
// 
// Template Set:	Business Service Layer
// Language:		.NET C#
// Template:		Business Service Sub Class
//
// Copyright (c) Ross Donald 2003-2004
// http://www.radsoftware.com.au
//
-->

<!-- FileName = "{0}WebServiceWrapperBase.cs" -->
<!-- Folder = "BusinessWebServiceWrapper\Base" -->

<xsl:param name="ObjectName" select="'Timesheet'"/>
<xsl:param name="Namespace" select="'NextGeneration'"/>

<!--
//
// Main Template
//
-->
<xsl:template match="/">

	<!-- 
	// Create the Business Service classes 
	-->	
	<xsl:apply-templates select="/db/Table[table_name_safe = $ObjectName]"/>	
	
</xsl:template>


<!--
//
// Create the BusinessService class
//
-->
<xsl:template match="Table">

	<xsl:text>
using System;

using RAD.AppFramework.QueryObjects;

using </xsl:text><xsl:value-of select="$Namespace"/><xsl:text>.BusinessServiceInterfaces.Base;
using </xsl:text><xsl:value-of select="$Namespace"/><xsl:text>.Data;

using </xsl:text><xsl:value-of select="$Namespace"/><xsl:text>.WebServiceWrapper.</xsl:text><xsl:value-of select="table_name_safe" /><xsl:text>WebService;

namespace </xsl:text>
<xsl:value-of select="$Namespace"/>
<xsl:text>.WebServiceWrapper.Base
{
	public class </xsl:text><xsl:value-of select="table_name_safe" /><xsl:text>WebServiceWrapperBase : I</xsl:text><xsl:value-of select="table_name_safe" />ServiceBase<xsl:text>
	{
		#region Fields

		protected string m_UrlBase;

		#endregion


		#region Constructors

		public </xsl:text><xsl:value-of select="table_name_safe" /><xsl:text>WebServiceWrapperBase(string urlBase) 
		{
			m_UrlBase = urlBase;
		}

		#endregion


		#region Private Methods

		private </xsl:text><xsl:value-of select="table_name_safe" /><xsl:text>Service CreateServiceInstance() 
		{
			</xsl:text><xsl:value-of select="table_name_safe" /><xsl:text>Service instance = new </xsl:text><xsl:value-of select="table_name_safe" /><xsl:text>Service();
			instance.Url = m_UrlBase + "/</xsl:text><xsl:value-of select="table_name_safe" /><xsl:text>Service.asmx";
			return instance;
		}
		

		#endregion


		#region Public Methods

		public int GetAll(</xsl:text><xsl:value-of select="table_name_safe" /><xsl:text>DataSet dataSetFill) 
		{
			DataTable dt = CreateServiceInstance().GetAll().Tables[0];
			ds.Merge(dt);
			return dt.Rows.Count;
		}


		public int GetByQuery(DataSet dataSetFill, Query queryDefinition) 
		{
			</xsl:text><xsl:value-of select="table_name_safe" /><xsl:text>DataSet ds = new </xsl:text><xsl:value-of select="table_name_safe" /><xsl:text>DataSet();
			ds.Merge(CreateServiceInstance().GetByQuery(queryDefinition).Tables[0]);
			return ds;
		}


		</xsl:text>
		<xsl:if test="count(Column[is_key='true']) &gt; 0">
			<xsl:apply-templates select="." mode="GetByPK"/>
		</xsl:if>
		
		<!-- Generate GetByForeignKey methods -->
		
		<xsl:for-each select="Foreign_Key_Child">
			<xsl:variable name="pkcol" select="../Column[is_key='true']/column_name"/>
			<xsl:variable name="fkcol" select="Column/fk_column_name"/>
						
			<!-- 
			Compare the primary key column names to the columns in the foreign key. 
			if they are equal then do not create a SelectByFK method as it would 
			be the same as the SelectByPK method. Bug 0000002.
			-->
			<xsl:variable name="compare">
				<xsl:for-each select="$pkcol">
					<xsl:if test="not($fkcol = string(current()))">
						<xsl:text>NEQ</xsl:text>
					</xsl:if>
				</xsl:for-each>
			</xsl:variable>
			<xsl:choose>
				<xsl:when test="normalize-space($compare)">
					<xsl:apply-templates select="."/>
				</xsl:when>
				<!--	<xsl:otherwise>fk columns are equal to the primary key</xsl:otherwise>-->
			</xsl:choose>
		</xsl:for-each>
		<xsl:text>

		
		#endregion
	}
}

</xsl:text>


</xsl:template>
<!--
	//
	// Generate a Get command for a Primary key
	//
-->

<xsl:template match="Table" mode="GetByPK">

	<xsl:text>	
		public int </xsl:text>
		<xsl:apply-templates select="." mode="GetByPKMethodName" />

	<xsl:text>(</xsl:text><xsl:value-of select="table_name_safe" /><xsl:text>DataSet dataSetFill, </xsl:text>
	
	<xsl:apply-templates select="." mode="PKMethodParam">
		<xsl:with-param name="PrintType" select="1" />
	</xsl:apply-templates>
	
	<xsl:text>)
		{
			</xsl:text>
			<xsl:value-of select="table_name_safe" />
			<xsl:text>DataSet ds = new </xsl:text>
			<xsl:value-of select="table_name_safe" /><xsl:text>DataSet();
			ds.Merge(CreateServiceInstance().</xsl:text>
			<xsl:apply-templates select="." mode="GetByPKMethodName" />
			<xsl:text>(</xsl:text>
			<xsl:apply-templates select="." mode="PKMethodParam">
				<xsl:with-param name="PrintType" select="0" />
			</xsl:apply-templates>
			<xsl:text>).Tables[0]);
			return ds;
		}
	</xsl:text>
	
</xsl:template>


<xsl:template match="Table" mode="GetByPKMethodName">
	<xsl:text>GetBy</xsl:text>
	
	<xsl:for-each select="Column[is_key = 'true']">

		<xsl:if test="position() != 1">
			<xsl:text>And</xsl:text>
		</xsl:if>
		<xsl:value-of select="column_name_safe" />
			
	</xsl:for-each>
</xsl:template>

<xsl:template match="Table" mode="PKMethodParam">
	<xsl:param name="PrintType" />

	<xsl:for-each select="Column[is_key = 'true']">
	
		<xsl:if test="position() != 1">
			<xsl:text>, </xsl:text>
		</xsl:if>
		<xsl:if test="boolean(number($PrintType))">
			<xsl:value-of select="data_type_clr" />
			<xsl:text> </xsl:text>
		</xsl:if>
		<xsl:value-of select="column_name_safe" />
			
	</xsl:for-each>
</xsl:template>

<!--
	//
	// Generate a Get command for a foreign key
	//
-->
<xsl:template match="Foreign_Key_Child">
		<xsl:text>
		
		public int </xsl:text>
		<xsl:apply-templates select="." mode="GetByFKMethodName" />

		<xsl:text>(</xsl:text><xsl:value-of select="parent::*/table_name_safe" /><xsl:text>DataSet dataSetFill, </xsl:text>

		<xsl:apply-templates select="." mode="FKMethodParam">
			<xsl:with-param name="PrintType" select="1" />
		</xsl:apply-templates>
	
	<xsl:text>)
		{
			</xsl:text>
			<xsl:value-of select="parent::*/table_name_safe" />
			<xsl:text>DataSet ds = new </xsl:text>
			<xsl:value-of select="parent::*/table_name_safe" />
			<xsl:text>DataSet();
			ds.Merge(CreateServiceInstance().</xsl:text>
			<xsl:apply-templates select="." mode="GetByFKMethodName" />
			<xsl:text>(</xsl:text>
			<xsl:apply-templates select="." mode="FKMethodParam">
				<xsl:with-param name="PrintType" select="0" />
			</xsl:apply-templates>
			<xsl:text>).Tables[0]);
			return ds;
		}
	</xsl:text>
	
</xsl:template>

<xsl:template match="Foreign_Key_Child" mode="GetByFKMethodName">
	<xsl:text>GetBy</xsl:text>

	<xsl:for-each select="Column">
	
		<xsl:variable name="FKColumnName" select="fk_column_name"/>

		<xsl:if test="position() != 1">
			<xsl:text>And</xsl:text>
		</xsl:if>
		<xsl:value-of select="parent::*/parent::*/Column[column_name=$FKColumnName]/column_name_safe" />
			
	</xsl:for-each>
	
</xsl:template>

<xsl:template match="Foreign_Key_Child" mode="FKMethodParam">
	<xsl:param name="PrintType" />
	<xsl:for-each select="Column">
	
		<xsl:variable name="FKColumnName" select="fk_column_name"/>

		<xsl:if test="position() != 1">
			<xsl:text>, </xsl:text>
		</xsl:if>
		<xsl:if test="boolean(number($PrintType))">
			<xsl:value-of select="parent::*/parent::*/Column[column_name=$FKColumnName]/data_type_clr" />
			<xsl:text> </xsl:text>
		</xsl:if>
		<xsl:value-of select="parent::*/parent::*/Column[column_name=$FKColumnName]/column_name_safe" />
			
	</xsl:for-each>
</xsl:template>

</xsl:stylesheet>

