<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet 
	version="1.0" 
	xmlns:xsl="http://www.w3.org/1999/XSL/Transform" 
	>

<xsl:output 
	method="text" 
	indent="no" 
	omit-xml-declaration="yes" 
	/>
<!-- 
//
// NextGeneration Template
// 
// Template Set:	Business Service Layer
// Language:		.NET C#
// Template:		Business Service Sub Class
//
// Copyright (c) Ross Donald 2003-2004
// http://www.radsoftware.com.au
//
-->

<!-- FileName = "{0}WebServiceWrapperBase.vb" -->
<!-- Folder = "BusinessWebServiceWrapper\Base" -->

<xsl:param name="ObjectName" select="'Timesheet'"/>
<xsl:param name="Namespace" select="'NextGeneration'"/>
<xsl:param name="BusinessWebServiceUseInterfaces" select="'false'"/>

<!--
//
// Main Template
//
-->
<xsl:template match="/">

	<!-- 
	// Create the Business Service classes 
	-->	
	<xsl:apply-templates select="/db/Table[table_name_safe = $ObjectName]"/>	
	
</xsl:template>


<!--
//
// Create the BusinessService Class
//
-->
<xsl:template match="Table">

	<xsl:text>
Imports System

Imports RAD.AppFramework.QueryObjects

</xsl:text>
<xsl:if test="$BusinessWebServiceUseInterfaces = 'true'">
<xsl:text>Imports </xsl:text><xsl:value-of select="$Namespace"/><xsl:text>.BusinessServiceInterfaces.Base
</xsl:text>
</xsl:if>
<xsl:text>
Imports </xsl:text><xsl:value-of select="$Namespace"/><xsl:text>.Data
Imports </xsl:text><xsl:value-of select="$Namespace"/><xsl:text>.WebServiceWrapper.</xsl:text><xsl:value-of select="table_name_safe" /><xsl:text>WebService

Namespace Base

	Public Class </xsl:text><xsl:value-of select="table_name_safe" /><xsl:text>WebServiceWrapperBase 
		</xsl:text>
<xsl:if test="$BusinessWebServiceUseInterfaces = 'true'">
	<xsl:text>Implements I</xsl:text><xsl:value-of select="table_name_safe" />ServiceBase
</xsl:if>
<xsl:text>

#Region "Fields"

		Protected m_UrlBase As String
		Private m_ServiceInstance As </xsl:text><xsl:value-of select="table_name_safe" /><xsl:text>Service

#End Region


#Region "Constructors"

		Public Sub New(ByVal urlBase As String) 

			m_UrlBase = urlBase
			m_ServiceInstance = CreateServiceInstance()
			
		End Sub

#End Region


#Region "Protected Properties"

		Protected ReadOnly Property ServiceInstance() As </xsl:text><xsl:value-of select="table_name_safe" /><xsl:text>Service
			Get
				Return m_ServiceInstance
			End Get
		End Property

#End Region


#Region "Protected Methods"

		Protected Overridable Function CreateServiceInstance() As </xsl:text><xsl:value-of select="table_name_safe" /><xsl:text>Service

			Dim instance As New </xsl:text><xsl:value-of select="table_name_safe" /><xsl:text>Service()
			instance.Url = m_UrlBase &amp; "</xsl:text><xsl:value-of select="table_name_safe" /><xsl:text>Service.asmx"

			InitializeInstance(instance)

			Return instance
			
		End Function
		

		'
		' InitializeInstance can be used to set security credentials
		'
		Protected Overridable Sub InitializeInstance(ByVal instance As </xsl:text><xsl:value-of select="table_name_safe" /><xsl:text>Service)

		End Sub
		
		
#End Region


#Region "Public Methods"

		Public Function GetAll(ByVal dataSetFill As </xsl:text><xsl:value-of select="table_name_safe" /><xsl:text>DataSet) As Integer </xsl:text>
<xsl:if test="$BusinessWebServiceUseInterfaces = 'true'">
<xsl:text>_
			Implements I</xsl:text><xsl:value-of select="table_name_safe" /><xsl:text>ServiceBase.GetAll</xsl:text>
</xsl:if>
<xsl:text>

			Dim resultsTable As DataTable = ServiceInstance.GetAll().Tables(0)
			dataSetFill.Merge(resultsTable)
			Return resultsTable.Rows.Count
		
		End Function


		Public Function GetByQuery(ByVal dataSetFill As DataSet, ByVal queryDefinition As Query) As Integer </xsl:text>
<xsl:if test="$BusinessWebServiceUseInterfaces = 'true'">
<xsl:text>_
			Implements I</xsl:text><xsl:value-of select="table_name_safe" /><xsl:text>ServiceBase.GetByQuery</xsl:text>
</xsl:if>
<xsl:text>

			Dim resultsTable As DataTable = ServiceInstance.GetByQuery(queryDefinition).Tables(0)
			dataSetFill.Merge(resultsTable)
			Return resultsTable.Rows.Count
		
		End Function
		
		
		Public Function UpdateDataSet(ByVal dataSetUpdate As </xsl:text><xsl:value-of select="table_name_safe" /><xsl:text>DataSet) As Integer </xsl:text>
<xsl:if test="$BusinessWebServiceUseInterfaces = 'true'">
<xsl:text>_
			Implements I</xsl:text><xsl:value-of select="table_name_safe" /><xsl:text>ServiceBase.UpdateDataSet</xsl:text>
</xsl:if>
<xsl:text>

			Dim returnedDataSet As DataSet = ServiceInstance.UpdateDataSet(dataSetUpdate)

			Dim recordCount As Integer = returnedDataSet.Tables(0).Rows.Count

			If recordCount > 0 Then

				'
				' Need to clear the dataset as Merge does not work with new rows 
				' that have a primary key assigned automatically
				'
				dataSetUpdate.Clear()
                dataSetUpdate.Merge(returnedDataSet)

            End If

            Return recordCount

        End Function
		</xsl:text>
		<xsl:if test="count(Column[is_key='true']) &gt; 0">
			<xsl:apply-templates select="." mode="GetByPK"/>
		</xsl:if>
		
		<!-- Generate GetByForeignKey methods -->
		
		<xsl:for-each select="Foreign_Key_Child">
			<xsl:variable name="pkcol" select="../Column[is_key='true']/column_name"/>
			<xsl:variable name="fkcol" select="Column/fk_column_name"/>
						
			<!-- 
			Compare the primary key column names to the columns in the foreign key. 
			if they are equal then do not create a SelectByFK method as it would 
			be the same as the SelectByPK method. Bug 0000002.
			-->
			<xsl:variable name="compare">
				<xsl:for-each select="$pkcol">
					<xsl:if test="not($fkcol = string(current()))">
						<xsl:text>NEQ</xsl:text>
					</xsl:if>
				</xsl:for-each>
			</xsl:variable>
			<xsl:choose>
				<xsl:when test="normalize-space($compare)">
					<xsl:apply-templates select="."/>
				</xsl:when>
				<!--	<xsl:otherwise>fk columns are equal to the primary key</xsl:otherwise>-->
			</xsl:choose>
		</xsl:for-each>
		<xsl:text>

		
#End Region
		
	End Class
	
End Namespace

</xsl:text>


</xsl:template>
<!--
	//
	// Generate a Get command for a Primary key
	//
-->

<xsl:template match="Table" mode="GetByPK">

	<xsl:text>	
		Public Function </xsl:text>
		<xsl:apply-templates select="." mode="GetByPKMethodName" />

	<xsl:text>(ByVal dataSetFill As </xsl:text><xsl:value-of select="table_name_safe" /><xsl:text>DataSet, </xsl:text>
	
	<xsl:apply-templates select="." mode="PKMethodParam">
		<xsl:with-param name="PrintType" select="1" />
	</xsl:apply-templates>
	
	<xsl:text>) As Integer </xsl:text>
<xsl:if test="$BusinessWebServiceUseInterfaces = 'true'">
<xsl:text>_
			Implements I</xsl:text><xsl:value-of select="table_name_safe" /><xsl:text>ServiceBase.</xsl:text><xsl:apply-templates select="." mode="GetByPKMethodName" />
</xsl:if>
<xsl:text>

			Dim resultsTable As DataTable = ServiceInstance.</xsl:text>
			<xsl:apply-templates select="." mode="GetByPKMethodName" />
			<xsl:text>(</xsl:text>
			<xsl:apply-templates select="." mode="PKMethodParam">
				<xsl:with-param name="PrintType" select="0" />
			</xsl:apply-templates>
			<xsl:text>).Tables(0)
			dataSetFill.Merge(resultsTable)
			Return resultsTable.Rows.Count
			
		End Function
	</xsl:text>
	
</xsl:template>


<xsl:template match="Table" mode="GetByPKMethodName">
	<xsl:text>GetBy</xsl:text>
	
	<xsl:for-each select="Column[is_key = 'true']">

		<xsl:if test="position() != 1">
			<xsl:text>And</xsl:text>
		</xsl:if>
		<xsl:value-of select="column_name_safe" />
			
	</xsl:for-each>
</xsl:template>

<xsl:template match="Table" mode="PKMethodParam">
	<xsl:param name="PrintType" />

	<xsl:for-each select="Column[is_key = 'true']">
	
		<xsl:if test="position() != 1">
			<xsl:text>, </xsl:text>
		</xsl:if>
		<xsl:if test="boolean(number($PrintType))">
			<xsl:text>ByVal </xsl:text>
		</xsl:if>
		<xsl:value-of select="column_name_safe" />
		<xsl:if test="boolean(number($PrintType))">
			<xsl:text> As </xsl:text>
			<xsl:value-of select="data_type_clr" />
		</xsl:if>
			
	</xsl:for-each>
</xsl:template>

<!--
	//
	// Generate a Get command for a foreign key
	//
-->
<xsl:template match="Foreign_Key_Child">
		<xsl:text>
		
		Public Function </xsl:text>
		<xsl:apply-templates select="." mode="GetByFKMethodName" />

		<xsl:text>(ByVal dataSetFill As </xsl:text><xsl:value-of select="parent::*/table_name_safe" /><xsl:text>DataSet, </xsl:text>

		<xsl:apply-templates select="." mode="FKMethodParam">
			<xsl:with-param name="PrintType" select="1" />
		</xsl:apply-templates>
	
	<xsl:text>) As Integer </xsl:text>
<xsl:if test="$BusinessWebServiceUseInterfaces = 'true'">
<xsl:text>_
			Implements I</xsl:text><xsl:value-of select="parent::*/table_name_safe" /><xsl:text>ServiceBase.</xsl:text><xsl:apply-templates select="." mode="GetByFKMethodName" />
</xsl:if>
<xsl:text>

			Dim resultsTable As DataTable = ServiceInstance.</xsl:text>
			<xsl:apply-templates select="." mode="GetByFKMethodName" />
			<xsl:text>(</xsl:text>
			<xsl:apply-templates select="." mode="FKMethodParam">
				<xsl:with-param name="PrintType" select="0" />
			</xsl:apply-templates>
			<xsl:text>).Tables(0)
			dataSetFill.Merge(resultsTable)
			Return resultsTable.Rows.Count
			
		End Function
	</xsl:text>
	
</xsl:template>

<xsl:template match="Foreign_Key_Child" mode="GetByFKMethodName">
	<xsl:text>GetBy</xsl:text>

	<xsl:for-each select="Column">
	
		<xsl:variable name="FKColumnName" select="fk_column_name"/>

		<xsl:if test="position() != 1">
			<xsl:text>And</xsl:text>
		</xsl:if>
		<xsl:value-of select="parent::*/parent::*/Column[column_name=$FKColumnName]/column_name_safe" />
			
	</xsl:for-each>
	
</xsl:template>

<xsl:template match="Foreign_Key_Child" mode="FKMethodParam">
	<xsl:param name="PrintType" />
	<xsl:for-each select="Column">
	
		<xsl:variable name="FKColumnName" select="fk_column_name"/>

		<xsl:if test="position() != 1">
			<xsl:text>, </xsl:text>
		</xsl:if>
		<xsl:if test="boolean(number($PrintType))">
			<xsl:text>ByVal </xsl:text>
		</xsl:if>
		<xsl:value-of select="parent::*/parent::*/Column[column_name=$FKColumnName]/column_name_safe" />
		<xsl:if test="boolean(number($PrintType))">
			<xsl:text> As </xsl:text>
			<xsl:value-of select="parent::*/parent::*/Column[column_name=$FKColumnName]/data_type_clr" />
		</xsl:if>
			
	</xsl:for-each>
</xsl:template>

</xsl:stylesheet>

