<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet 
	version="1.0" 
	xmlns:xsl="http://www.w3.org/1999/XSL/Transform" 
	>

<xsl:output 
	method="text" 
	indent="no" 
	omit-xml-declaration="yes" 
	/>
<!-- 
//
// NextGeneration Template
// 
// Template Set:	Business Service Layer
// Language:		.NET C#
// Template:		Business Service Sub Class
//
// Copyright (c) Ross Donald 2003-2004
// http://www.radsoftware.com.au
//
-->

<!-- FileName = "{0}WebService.asmx.cs" -->
<!-- Folder = "BusinessWebService\Code" -->

<xsl:param name="ObjectName" select="'Timesheet'"/>
<xsl:param name="Namespace" select="'NextGeneration'"/>
<xsl:param name="BusinessWebServiceNamespace" select="'http://tempuri.org/'"/>

<!--
//
// Template Parameters
//
-->
<xsl:template mode="Parameters" match="none">

<Parameter 
	KeyName="BusinessWebServiceNamespace" 
	DisplayName="Web Service Namespace" 
	Type="String"
	Description="The XML namespace to use for the Web service. e.g. http://www.mycompany.com/Accounting/. An XML Web service should change its default XML namespace before the it is made public. Each XML Web service needs a unique XML namespace to identify it so that client applications can distinguish it from other services on the Web. http://tempuri.org/ is available for XML Web services that are under development, but published XML Web services should use a more permanent namespace." 
	DefaultValue="http://tempuri.org/" 
	ListType="None">
</Parameter>

</xsl:template>


<!--
//
// Main Template
//
-->
<xsl:template match="/">

	<!-- 
	// Create the Business Service classes 
	-->	
	<xsl:apply-templates select="/db/Table[table_name_safe = $ObjectName]"/>	
	
</xsl:template>


<!--
//
// Create the BusinessService class
//
-->
<xsl:template match="Table">

	<xsl:text>
using System;
using System.Data;
using System.Web.Services;

using RAD.AppFramework;
using RAD.AppFramework.Data;
using RAD.AppFramework.QueryObjects;

using </xsl:text><xsl:value-of select="$Namespace"/><xsl:text>.Common;
using </xsl:text><xsl:value-of select="$Namespace"/><xsl:text>.DatabaseSchema;
using </xsl:text><xsl:value-of select="$Namespace"/><xsl:text>.Data;
using </xsl:text><xsl:value-of select="$Namespace"/><xsl:text>.DataAccess.Adapters;
using </xsl:text><xsl:value-of select="$Namespace"/><xsl:text>.BusinessWebService.Base;

namespace </xsl:text>
<xsl:value-of select="$Namespace"/>
<xsl:text>.BusinessWebService
{
	/// &lt;summary&gt;
	/// </xsl:text>
	<xsl:value-of select="table_name_safe" />
	<xsl:text>Service allows for application specific business logic to be added without 
	/// having to make changes to the auto-generated </xsl:text><xsl:value-of select="table_name_safe" /><xsl:text>ServiceBase class. 
	/// &lt;/summary&gt;
	/// &lt;remarks&gt;
	/// Any additional functionality must be added to the </xsl:text><xsl:value-of select="table_name_safe" />
	<xsl:text>Service class.
	/// &lt;br/&gt;&lt;br/&gt;
	/// This class was automatically generated by Rad Software NextGeneration &lt;a href="http://www.radsoftware.com.au"&gt;http://www.radsoftware.com.au&lt;/a&gt;
	/// &lt;/remarks&gt;
	[WebService(
		Description="",
		Namespace="</xsl:text><xsl:value-of select="$BusinessWebServiceNamespace"/><xsl:text>")]
	public class </xsl:text><xsl:value-of select="table_name_safe" /><xsl:text>Service : </xsl:text><xsl:value-of select="table_name_safe" /><xsl:text>ServiceBase
	{
		#region Constants
		
		
		
		#endregion
		
		
		#region Fields
		
		/// &lt;summary&gt;
		/// A static instance of the </xsl:text><xsl:value-of select="table_name_safe"/><xsl:text>Service
		/// &lt;/summary&gt;
		static </xsl:text><xsl:value-of select="table_name_safe"/><xsl:text>Service m_Instance;
		
		#endregion
		
		
		#region Constructors
		
		/// &lt;summary&gt;
		/// Creates a new </xsl:text><xsl:value-of select="table_name_safe" /><xsl:text>Service
		/// &lt;/summary&gt;
		public </xsl:text><xsl:value-of select="table_name_safe" /><xsl:text>Service() : base()
		{
		}
		
		/// &lt;summary&gt;
		/// Creates a new </xsl:text><xsl:value-of select="table_name_safe" /><xsl:text>Service and specifies the Database context
		/// &lt;/summary&gt;		
		public </xsl:text><xsl:value-of select="table_name_safe" /><xsl:text>Service(DatabaseConnection connection) : base(connection)
		{
		}
				
		/// &lt;summary&gt;
		/// Initializes the static instance
		/// &lt;/summary&gt;
		static </xsl:text><xsl:value-of select="table_name_safe"/><xsl:text>Service()
		{
			m_Instance = new </xsl:text><xsl:value-of select="table_name_safe"/><xsl:text>Service();
		}
		
		#endregion
		
		
		#region Public Properties
		
		/// &lt;summary&gt;
		/// A default instance of the </xsl:text><xsl:value-of select="table_name_safe"/><xsl:text>Service
		/// &lt;/summary&gt;
		public static </xsl:text><xsl:value-of select="table_name_safe"/><xsl:text>Service Instance
		{
			get { return m_Instance; }
		}
		
		#endregion
		
		
		#region Private Methods
		
		
		
		#endregion
		
		
		#region Public Methods
		
		
		
		#endregion
	}
}

</xsl:text>


</xsl:template>

</xsl:stylesheet>

