<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet 
	version="1.0" 
	xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
	>

<xsl:output 
	method="text" 
	indent="no" 
	omit-xml-declaration="yes" 
	/>

<!-- 
//
// NextGeneration Template
// 
// Template Set:	Business Service Layer
// Language:		.NET C#
// Template:		Business Service Super Class
//
// Copyright (c) Ross Donald 2003-2004
// http://www.radsoftware.com.au
//
-->

<!-- FileName = "{0}WebServiceBase.cs" -->
<!-- Folder = "BusinessWebService\Base\" -->

<xsl:param name="ObjectName" select="'TimesheetItem'"/>
<xsl:param name="Namespace" select="'NextGeneration'"/>

<!--
//
// Main Template
//
-->
<xsl:template match="/">

	<!-- 
	// Create the Business Service Classes for the Current Object 
	-->	
	<xsl:apply-templates select="/db/Table[table_name_safe = $ObjectName]"/>	
	
</xsl:template>


<!--
//
// Create the BusinessWebService.Base class
//
-->
<xsl:template match="Table">

	<xsl:text>
using System;
using System.Data;
using System.Web;
using System.Web.Services;
using System.ComponentModel;

using RAD.AppFramework;
using RAD.AppFramework.Data;
using RAD.AppFramework.QueryObjects;

using </xsl:text><xsl:value-of select="$Namespace"/><xsl:text>.Common;
using </xsl:text><xsl:value-of select="$Namespace"/><xsl:text>.Data;
using </xsl:text><xsl:value-of select="$Namespace"/><xsl:text>.DataAccess.Adapters;

namespace </xsl:text>
<xsl:value-of select="$Namespace"/>
<xsl:text>.BusinessWebService.Base
{
	/// &lt;summary&gt;
	/// </xsl:text><xsl:value-of select="table_name_safe" />
	<xsl:text>ServiceBase is a base business object implementing the most common data operations 
	/// for the </xsl:text>	<xsl:value-of select="table_name"/><xsl:text> table. 
	/// &lt;/summary&gt;
	/// &lt;remarks&gt;
	/// Any application specific business logic must be added to the 
	/// </xsl:text><xsl:value-of select="table_name_safe" /><xsl:text>Service class. Do not modify this class.
	///
	/// This class was automatically generated by Rad Software NextGeneration &lt;a href="http://www.radsoftware.com.au"&gt;http://www.radsoftware.com.au&lt;/a&gt;
	/// &lt;/remarks&gt;
	public abstract class </xsl:text><xsl:value-of select="table_name_safe" /><xsl:text>ServiceBase : System.Web.Services.WebService
	{
		#region Fields
		
		/// &lt;summary&gt;
		/// The strongly-typed DataAdapter to use for Get and Update operations
		/// &lt;/summary&gt;
		protected </xsl:text><xsl:value-of select="table_name_safe" /><xsl:text>DataAdapter m_</xsl:text><xsl:value-of select="table_name_safe" /><xsl:text>Adapter;
		
		/// &lt;summary&gt;
		/// The Database Connection that will be used to read from and update the Database
		/// &lt;/summary&gt;
		private DatabaseConnection m_DatabaseConnection;

		#endregion

		#region Constructors
		
		/// &lt;summary&gt;
		/// Creates a new </xsl:text><xsl:value-of select="table_name_safe" /><xsl:text>Service
		/// &lt;/summary&gt;
		public </xsl:text><xsl:value-of select="table_name_safe" /><xsl:text>ServiceBase() : base()
		{
			DatabaseAccessObjectFactory DataObjectFactory = CommonFactory.CreateDataObjectFactory();
		
			DbConnection = new DatabaseConnection(DataObjectFactory.CreateConnection());
			m_</xsl:text><xsl:value-of select="table_name_safe" /><xsl:text>Adapter = new </xsl:text><xsl:value-of select="table_name_safe" /><xsl:text>DataAdapter(DbConnection);

			InitializeComponent();
		}

		/// &lt;summary&gt;
		/// Creates a new </xsl:text><xsl:value-of select="table_name_safe" /><xsl:text>Service and sets the Database context
		/// &lt;/summary&gt;
		public </xsl:text><xsl:value-of select="table_name_safe" /><xsl:text>ServiceBase(DatabaseConnection connection) : base()
		{
			UseConnectionAndTransaction(connection);

			m_</xsl:text><xsl:value-of select="table_name_safe" /><xsl:text>Adapter = new </xsl:text><xsl:value-of select="table_name_safe" /><xsl:text>DataAdapter(connection);

			InitializeComponent();
		}
		
		#endregion
		
		#region Properties
		
		/// &lt;summary&gt;
		/// The Database Connection that will be used to read from and update the Database
		/// &lt;/summary&gt;
		protected DatabaseConnection DbConnection
		{
			get { return m_DatabaseConnection; }
			set { m_DatabaseConnection = value; }
		}

		#endregion
		
		#region Public Methods
		
		/// &lt;summary&gt;
		/// Specifies the Database connection to use for any Data Access operations
		/// &lt;/summary&gt;
		/// &lt;param name=&quot;dbConnection&quot;&gt;the Database connection to use for any Data Access operations&lt;/param&gt;
		/// &lt;returns&gt;true on success, false otherwise&lt;/returns&gt;
		public bool UseConnectionAndTransaction(DatabaseConnection dbConnection)
		{
			m_DatabaseConnection = dbConnection;

			return true;
		}

		/// &lt;summary&gt;
		/// Perform any inserts, updates or deletes on the DataSet
		/// &lt;/summary&gt;
		/// &lt;param name="dataSetUpdate"&gt;The DataSet to update&lt;/param&gt;
		/// &lt;returns&gt;The populated Data Set&lt;/returns&gt;
		[WebMethod]
		public DataSet UpdateDataSet(DataSet dataSetUpdate)
		{
			</xsl:text><xsl:apply-templates select="." mode="DataAdapterUseConnection"/><xsl:text>
		
			m_</xsl:text><xsl:value-of select="table_name_safe" /><xsl:text>Adapter.Update(dataSetUpdate);
			
			return  dataSetUpdate;
		}
		
		/// &lt;summary&gt;
		/// Returns all rows from the </xsl:text><xsl:value-of select="table_name" /><xsl:text> table
		/// &lt;/summary&gt;
		/// &lt;returns&gt;The populated DataSet&lt;/returns&gt;
		[WebMethod]
		public DataSet GetAll()
		{
			</xsl:text><xsl:apply-templates select="." mode="DataAdapterUseConnection"/><xsl:text>
			</xsl:text><xsl:value-of select="table_name_safe" /><xsl:text>DataSet ds = new </xsl:text><xsl:value-of select="table_name_safe" /><xsl:text>DataSet();
			m_</xsl:text><xsl:value-of select="table_name_safe" /><xsl:text>Adapter.Fill(ds);
			return ds;
		}
		
		</xsl:text>
		
		<xsl:if test="count(Column[is_key='true']) &gt; 0">
			<xsl:apply-templates select="." mode="GetByPK"/>
		</xsl:if>
		
		<!-- Generate GetByForeignKey methods -->
		
		<xsl:for-each select="Foreign_Key_Child">
			<xsl:variable name="pkcol" select="../Column[is_key='true']/column_name"/>
			<xsl:variable name="fkcol" select="Column/fk_column_name"/>
						
			<!-- 
			Compare the primary key column names to the columns in the foreign key. 
			if they are equal then do not create a SelectByFK method as it would 
			be the same as the SelectByPK method. Bug 0000002.
			-->
			<xsl:variable name="compare">
				<xsl:for-each select="$pkcol">
					<xsl:if test="not($fkcol = string(current()))">
						<xsl:text>NEQ</xsl:text>
					</xsl:if>
				</xsl:for-each>
			</xsl:variable>
			<xsl:choose>
				<xsl:when test="normalize-space($compare)">
					<xsl:apply-templates select="."/>
				</xsl:when>
				<!--	<xsl:otherwise>fk columns are equal to the primary key</xsl:otherwise>-->
			</xsl:choose>
		</xsl:for-each>		
		
		<xsl:text>
			
		/// &lt;summary&gt;
		/// Returns rows by Query Definition
		/// &lt;/summary&gt;
		/// &lt;param name="queryDefinition"&gt;A Query that defines the query&lt;/param&gt;
		/// &lt;returns&gt;A count of the rows added to the DataSet&lt;/returns&gt;
		[WebMethod]
		public DataSet GetByQuery(Query queryDefinition)
		{
			</xsl:text>
			<xsl:apply-templates select="." mode="DataAdapterUseConnection"/><xsl:text>
			DataSet ds = new DataSet();
			m_</xsl:text><xsl:value-of select="table_name_safe" /><xsl:text>Adapter.FillByQuery(ds, queryDefinition);
			return ds;
		}
	
		#endregion


		#region Component Designer generated code
		
		//Required by the Web Services Designer 
		private IContainer components = null;
				
		/// &lt;summary&gt;
		/// Required method for Designer support - do not modify
		/// the contents of this method with the code editor.
		/// &lt;/summary&gt;
		private void InitializeComponent()
		{
		}

		/// &lt;summary&gt;
		/// Clean up any resources being used.
		/// &lt;/summary&gt;
		protected override void Dispose( bool disposing )
		{
			if(disposing &amp;&amp; components != null)
			{
				components.Dispose();
			}
			base.Dispose(disposing);		
		}
		
		#endregion
	}
}

</xsl:text>

</xsl:template>



<!--
	//
	// Generate a Get command for a Primary key
	//
-->
<xsl:template match="Table" mode="GetByPK">

	<xsl:text>	
		/// &lt;summary&gt;
		/// Return all rows from the </xsl:text>
		<xsl:value-of select="table_name" />
		<xsl:text> table by Primary Key
		/// &lt;/summary&gt;</xsl:text>
		<xsl:for-each select="Column[is_key = 'true']">
		<xsl:text>
		/// &lt;param name="</xsl:text><xsl:value-of select="column_name_safe" /><xsl:text>"&gt;The </xsl:text><xsl:value-of select="column_name_safe" /><xsl:text> to use as search criteria&lt;/param&gt;</xsl:text>
		</xsl:for-each>
		<xsl:text>
		/// &lt;returns&gt;The DataSet&lt;/returns&gt;
		[WebMethod]
		public DataSet GetBy</xsl:text>

	<xsl:for-each select="Column[is_key = 'true']">

		<xsl:if test="position() != 1">
			<xsl:text>And</xsl:text>
		</xsl:if>
		<xsl:value-of select="column_name_safe" />
			
	</xsl:for-each>
	
	<xsl:text>(</xsl:text>
	
		
	<xsl:for-each select="Column[is_key = 'true']">
	
		<xsl:if test="position() != 1">
			<xsl:text>, </xsl:text>
		</xsl:if>
		<xsl:value-of select="data_type_clr" />
		<xsl:text> </xsl:text>
		<xsl:value-of select="column_name_safe" />
			
	</xsl:for-each>
	
	<xsl:text>)
		{
			</xsl:text><xsl:apply-templates select="." mode="DataAdapterUseConnection"/><xsl:text>
			
			</xsl:text><xsl:value-of select="table_name_safe" /><xsl:text>DataSet ds = new </xsl:text><xsl:value-of select="table_name_safe" /><xsl:text>DataSet();
			m_</xsl:text><xsl:value-of select="table_name_safe" /><xsl:text>Adapter.FillBy</xsl:text>
			
			<xsl:for-each select="Column[is_key = 'true']">

				<xsl:if test="position() != 1">
					<xsl:text>And</xsl:text>
				</xsl:if>
				<xsl:value-of select="column_name_safe" />
					
			</xsl:for-each>
			
			<xsl:text>(ds, </xsl:text>
			
			<xsl:for-each select="Column[is_key = 'true']">

		<xsl:if test="position() != 1">
			<xsl:text>, </xsl:text>
		</xsl:if>
		<xsl:value-of select="column_name_safe" />
			
		</xsl:for-each>
			
			<xsl:text>);
			return ds;
		}
	</xsl:text>
	
</xsl:template>




<!--
	//
	// Generate a Get command for a foreign key
	//
-->
<xsl:template match="Foreign_Key_Child">

	<xsl:text>	
		/// &lt;summary&gt;
		/// Return all rows from the </xsl:text>
		<xsl:value-of select="parent::*/table_name" />
		<xsl:text> table by </xsl:text>
		
		<xsl:for-each select="Column">
	
			<xsl:variable name="FKColumnName" select="fk_column_name"/>
	
			<xsl:choose>
				<xsl:when test="position() != 1 and position() != last()">
					<xsl:text>, </xsl:text>
				</xsl:when>
				
				<xsl:when test="position() != 1 and position() = last()">
					<xsl:text> and </xsl:text>
				</xsl:when>
			
			</xsl:choose>
	
			<xsl:value-of select="parent::*/parent::*/Column[column_name=$FKColumnName]/column_name_safe" />
			
		</xsl:for-each>
		<xsl:text>
		/// &lt;/summary&gt;
		/// &lt;param name="dataSetFill"&gt;The DataSet to return the rows into&lt;/param&gt;</xsl:text>
		
		<xsl:for-each select="Column">
	
			<xsl:variable name="FKColumnName" select="fk_column_name"/>
	
			<xsl:text>
		/// &lt;param name="</xsl:text>
		<xsl:value-of select="parent::*/parent::*/Column[column_name=$FKColumnName]/column_name_safe" />
		<xsl:text>"&gt;The </xsl:text>
		<xsl:value-of select="parent::*/parent::*/Column[column_name=$FKColumnName]/column_name_safe" />
		<xsl:text> to use as search criteria&lt;/param&gt;</xsl:text>
	
		</xsl:for-each>

		<xsl:text>
		/// &lt;returns&gt;The number of rows added to the DataSet&lt;/returns&gt;
		public int GetBy</xsl:text>

	<xsl:for-each select="Column">
	
		<xsl:variable name="FKColumnName" select="fk_column_name"/>

		<xsl:if test="position() != 1">
			<xsl:text>And</xsl:text>
		</xsl:if>
		<xsl:value-of select="parent::*/parent::*/Column[column_name=$FKColumnName]/column_name_safe" />
			
	</xsl:for-each>
	
	<xsl:text>(DataSet dataSetFill, </xsl:text>
		
	<xsl:for-each select="Column">
	
		<xsl:variable name="FKColumnName" select="fk_column_name"/>

		<xsl:if test="position() != 1">
			<xsl:text>, </xsl:text>
		</xsl:if>
		<xsl:value-of select="parent::*/parent::*/Column[column_name=$FKColumnName]/data_type_clr" />
		<xsl:text> </xsl:text>
		<xsl:value-of select="parent::*/parent::*/Column[column_name=$FKColumnName]/column_name_safe" />
			
	</xsl:for-each>
	
	<xsl:text>)
		{
			</xsl:text><xsl:apply-templates select="parent::*" mode="DataAdapterUseConnection"/><xsl:text>
		
			return m_</xsl:text><xsl:value-of select="parent::*/table_name_safe" /><xsl:text>Adapter.FillBy</xsl:text>
			
				<xsl:for-each select="Column">
	
				<xsl:variable name="FKColumnName" select="fk_column_name"/>

				<xsl:if test="position() != 1">
					<xsl:text>And</xsl:text>
				</xsl:if>
				<xsl:value-of select="parent::*/parent::*/Column[column_name=$FKColumnName]/column_name_safe" />
			
			</xsl:for-each>

			
			<xsl:text>(dataSetFill, </xsl:text>
			
			<xsl:for-each select="Column">
	
		<xsl:variable name="FKColumnName" select="fk_column_name"/>

		<xsl:if test="position() != 1">
			<xsl:text>, </xsl:text>
		</xsl:if>
		<xsl:value-of select="parent::*/parent::*/Column[column_name=$FKColumnName]/column_name_safe" />
			
		</xsl:for-each>
			
			<xsl:text>);
		}

		/// &lt;summary&gt;
		/// Returns all rows from the </xsl:text>
		<xsl:value-of select="parent::*/table_name" />
		<xsl:text> table by </xsl:text>
		
		<xsl:for-each select="Column">
	
			<xsl:variable name="FKColumnName" select="fk_column_name"/>
	
			<xsl:choose>
				<xsl:when test="position() != 1 and position() != last()">
					<xsl:text>, </xsl:text>
				</xsl:when>
				
				<xsl:when test="position() != 1 and position() = last()">
					<xsl:text> and </xsl:text>
				</xsl:when>
			
			</xsl:choose>
	
			<xsl:value-of select="parent::*/parent::*/Column[column_name=$FKColumnName]/column_name_safe" />
			
		</xsl:for-each>
		<xsl:text>
		/// &lt;/summary&gt;</xsl:text>
		
		<xsl:for-each select="Column">
	
			<xsl:variable name="FKColumnName" select="fk_column_name"/>
	
			<xsl:text>
		/// &lt;param name="</xsl:text>
		<xsl:value-of select="parent::*/parent::*/Column[column_name=$FKColumnName]/column_name_safe" />
		<xsl:text>"&gt;The </xsl:text>
		<xsl:value-of select="parent::*/parent::*/Column[column_name=$FKColumnName]/column_name_safe" />
		<xsl:text> to use as search criteria&lt;/param&gt;</xsl:text>
	
		</xsl:for-each>

		<xsl:text>
		/// &lt;returns&gt;The DataSet&lt;/returns&gt;
		[WebMethod]
		public DataSet GetBy</xsl:text>

	<xsl:for-each select="Column">
	
		<xsl:variable name="FKColumnName" select="fk_column_name"/>

		<xsl:if test="position() != 1">
			<xsl:text>And</xsl:text>
		</xsl:if>
		<xsl:value-of select="parent::*/parent::*/Column[column_name=$FKColumnName]/column_name_safe" />
			
	</xsl:for-each>
	
	<xsl:text>(</xsl:text>
		
	<xsl:for-each select="Column">
	
		<xsl:variable name="FKColumnName" select="fk_column_name"/>

		<xsl:if test="position() != 1">
			<xsl:text>, </xsl:text>
		</xsl:if>
		<xsl:value-of select="parent::*/parent::*/Column[column_name=$FKColumnName]/data_type_clr" />
		<xsl:text> </xsl:text>
		<xsl:value-of select="parent::*/parent::*/Column[column_name=$FKColumnName]/column_name_safe" />
			
	</xsl:for-each>
	
	<xsl:text>)
		{
			</xsl:text><xsl:apply-templates select="parent::*" mode="DataAdapterUseConnection"/><xsl:text>
		
			</xsl:text><xsl:value-of select="parent::*/table_name_safe" /><xsl:text>DataSet ds = new </xsl:text><xsl:value-of select="$ObjectName" /><xsl:text>DataSet();
			m_</xsl:text><xsl:value-of select="parent::*/table_name_safe" /><xsl:text>Adapter.FillBy</xsl:text>
			
				<xsl:for-each select="Column">
	
				<xsl:variable name="FKColumnName" select="fk_column_name"/>

				<xsl:if test="position() != 1">
					<xsl:text>And</xsl:text>
				</xsl:if>
				<xsl:value-of select="parent::*/parent::*/Column[column_name=$FKColumnName]/column_name_safe" />
			
			</xsl:for-each>

			
			<xsl:text>(ds, </xsl:text>
			
			<xsl:for-each select="Column">
	
		<xsl:variable name="FKColumnName" select="fk_column_name"/>

		<xsl:if test="position() != 1">
			<xsl:text>, </xsl:text>
		</xsl:if>
		<xsl:value-of select="parent::*/parent::*/Column[column_name=$FKColumnName]/column_name_safe" />
			
		</xsl:for-each>
			
			<xsl:text>);
			return ds;
		}
	</xsl:text>
	
</xsl:template>

<!-- 
//
// Get the DataAdapter to use the connection and transaction
//
-->
<xsl:template match="Table" mode="DataAdapterUseConnection">

	<xsl:text>m_</xsl:text>
	<xsl:value-of select="table_name_safe"/>
	<xsl:text>Adapter.UseConnectionAndTransaction(DbConnection);</xsl:text>

</xsl:template>

</xsl:stylesheet>

