<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet version="1.0" 
	xmlns:xsl="http://www.w3.org/1999/XSL/Transform" 
	>

<xsl:output 
	method="text" 
	indent="no" 
	omit-xml-declaration="yes"
	/>
<!-- 
//
// NextGeneration Template
// 
// Template Set:	Web User Interface
// Language:		.NET C#
// Template:		BasePage base class
//
// Copyright (c) Ross Donald 2003-2004
// http://www.radsoftware.com.au
//
-->

<!-- FileName = "BasePage.cs"	-->
<!-- Folder   = "WebUI"	-->

<xsl:param name="ObjectName" select="'Client'"/>
<xsl:param name="Namespace" select="NextGeneration"/>

<!--
//
// Main Template
//
-->
<xsl:template match="/">
<xsl:text>
using System;
using System.Collections;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Web;
using System.Web.SessionState;
using System.Web.UI;
using System.Web.UI.WebControls;
using System.Web.UI.HtmlControls;


namespace </xsl:text><xsl:value-of select="$Namespace"/><xsl:text>.WebUI
{
	/// &lt;summary&gt;
	/// Base web page
	/// &lt;/summary&gt;
	public class BasePage : System.Web.UI.Page
	{
		#region Constants


		
		#endregion


		#region Fields

		string m_PageTitle = string.Empty;

		string m_DefaultReturnPage = &quot;./&quot;;

		#endregion

		
		#region Page Events

		/// &lt;summary&gt;
		/// Called when the page is loading
		/// &lt;/summary&gt;
		/// &lt;param name=&quot;sender&quot;&gt;The object that raised the event&lt;/param&gt;
		/// &lt;param name=&quot;e&quot;&gt;Event arguments&lt;/param&gt;
		private void Page_Load(object sender, System.EventArgs e)
		{
			if (IsPostBack)
			{
				
			}
			else
			{
				if (Request.UrlReferrer == null)
				{
					//
					// No referrer for the current request, use the default
					//
					UrlPrevious = new Uri(Request.Url, DefaultReturnPage);
				}
				else
				{
					UrlPrevious = Request.UrlReferrer;
				}
			}
		}


		/// &lt;summary&gt;
		/// Creates a new instance of the base Page
		/// &lt;/summary&gt;
		public BasePage()
		{
			this.Load += new EventHandler(Page_Load);
		}

		#endregion


		#region Event Handlers for Controls



		#endregion


		#region Private Methods


		/// &lt;summary&gt;
		/// Retrieves a value from the ViewState or
		/// the default value if the ViewState is empty
		/// &lt;/summary&gt;
		/// &lt;param name=&quot;key&quot;&gt;The key of the value to return&lt;/param&gt;
		/// &lt;param name=&quot;defaultValue&quot;&gt;The value to return if the ViewState does not contain a value&lt;/param&gt;
		/// &lt;returns&gt;The value in the ViewState for the key or the default value&lt;/returns&gt;
		protected object GetViewState(string key, object defaultValue)
		{
			object ViewStateValue = ViewState[key];

			if (ViewStateValue == null) 
			{
				return defaultValue;
			}
			else
			{
				return ViewStateValue;
			}
		}


		/// &lt;summary&gt;
		/// Checks if the Query string contains a parameter
		/// &lt;/summary&gt;
		/// &lt;param name=&quot;parameterName&quot;&gt;The name of the parameter&lt;/param&gt;
		/// &lt;returns&gt;true if the parameter exists, false if it does not&lt;/returns&gt;
		protected bool HasQueryStringParameter(string parameterName)
		{
			if (Request.QueryString[parameterName] == null)
			{
				return false;
			}
			else
			{
				return true;
			}
		}


		/// &lt;summary&gt;
		/// Gets a value from the QueryString. The default value is returned
		/// if the parameter is not found.
		/// &lt;/summary&gt;
		/// &lt;param name=&quot;paramName&quot;&gt;The name of the parameter in the query string&lt;/param&gt;
		/// &lt;param name=&quot;defaultValue&quot;&gt;The value to return if the parameter is not found&lt;/param&gt;
		/// &lt;returns&gt;The value of the query parameter or the default value&lt;/returns&gt;
		protected string GetQueryStringParameter(string parameterName, string defaultValue)
		{
			string QueryParameterValue = Request.QueryString[parameterName];

			if (QueryParameterValue == null)
			{
				return defaultValue;
			}
			else
			{
				return QueryParameterValue;
			}
		}


		/// &lt;summary&gt;
		/// Changes or sets the value of a query string parameter
		/// &lt;/summary&gt;
		/// &lt;param name=&quot;urlQuery&quot;&gt;The current query string&lt;/param&gt;
		/// &lt;param name=&quot;key&quot;&gt;The name of the parameter in the query string&lt;/param&gt;
		/// &lt;param name=&quot;valueNew&quot;&gt;The new value for the parameter&lt;/param&gt;
		/// &lt;returns&gt;The query string with the parameter updated&lt;/returns&gt;
		/// &lt;example&gt;
		/// &lt;code&gt;
		/// UriBuilder UrlWithSort = new UriBuilder(Request.Url);
		/// UrlWithSort.Query = ChangeQueryStringValue(UrlWithSort.Query, &quot;SortDir&quot;, &quot;CompanyName&quot;);
		/// &lt;/code&gt;
		/// &lt;/example&gt;
		protected string ChangeQueryStringValue(string urlQuery, string key, string valueNew)
		{
			if (urlQuery.Length &gt; 0)
			{
				//
				// Remove the leading question mark as it will be put back on by the UrlBuilder
				//
				urlQuery = urlQuery.Remove(0, 1);
			}

			if (HasQueryStringParameter(key))
			{
				System.Text.RegularExpressions.Regex SortRegex = new System.Text.RegularExpressions.Regex(@&quot;\b&quot; + key + &quot;=([^&amp;]*)&quot;, System.Text.RegularExpressions.RegexOptions.IgnoreCase);
				return SortRegex.Replace(urlQuery, key + &quot;=&quot; + valueNew);
			}
			else
			{
				if (urlQuery.Length &gt; 0)
				{
					urlQuery += &quot;&amp;&quot;;
				}

				return urlQuery + key + &quot;=&quot; + valueNew;
			}
		}


		#endregion
		

		#region Public Properties

		/// &lt;summary&gt;
		/// The title of web page 
		/// &lt;/summary&gt;
		public string PageTitle
		{
			get { return GetViewState(&quot;Title&quot;, string.Empty) as string; }
			set { ViewState[&quot;Title&quot;] = value; }
		}


		/// &lt;summary&gt;
		/// The page that the user visited before this page
		/// &lt;/summary&gt;
		[DesignerSerializationVisibility(DesignerSerializationVisibility.Hidden)]
		public Uri UrlPrevious
		{
			get { return GetViewState(&quot;UrlPrev&quot;, new Uri(Request.Url.ToString())) as Uri; }
			set { ViewState[&quot;UrlPrev&quot;] = value; }
		}


		/// &lt;summary&gt;
		/// The page address returned by UrlPrevious 
		/// when there is no referrer for the current request 
		/// &lt;/summary&gt;
		/// &lt;remarks&gt;
		/// Only the page filename needs to be specified to go to 
		/// a page in the same folder. This property must be set in the
		/// constructor of the inheriting page.
		/// &lt;/remarks&gt;
		/// &lt;example&gt;
		/// Employees_Search.aspx
		/// &lt;/example&gt;
		public string DefaultReturnPage
		{
			get { return m_DefaultReturnPage; }
			set { m_DefaultReturnPage = value; }
		}


		#endregion
	}
}
</xsl:text>

</xsl:template>


</xsl:stylesheet>