<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet version="1.0" 
	xmlns:xsl="http://www.w3.org/1999/XSL/Transform" 
	>

<xsl:output 
	method="text" 
	indent="no" 
	omit-xml-declaration="yes"
	/>
<!-- 
//
// NextGeneration Template
// 
// Template Set:	Web User Interface
// Language:		.NET C#
// Template:		EditablePage base class
//
// Copyright (c) Ross Donald 2003-2004
// http://www.radsoftware.com.au
//
-->

<!-- FileName = "EditablePage.cs"	-->
<!-- Folder   = "WebUI"	-->

<xsl:param name="ObjectName" select="'Client'"/>
<xsl:param name="Namespace" select="NextGeneration"/>

<!--
//
// Main Template
//
-->
<xsl:template match="/">
<xsl:text>
using System;
using System.Collections;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Web;
using System.Web.SessionState;
using System.Web.UI;
using System.Web.UI.WebControls;
using System.Web.UI.HtmlControls;


namespace </xsl:text><xsl:value-of select="$Namespace"/><xsl:text>.WebUI
{
	/// &lt;summary&gt;
	/// An editable web page that is used for data entry
	/// &lt;/summary&gt;
	public class EditablePage : BasePage
	{
		#region PageDataEntryMode enumeration
		
		/// &lt;summary&gt;
		/// The Data Entry Mode for an ASPX page
		/// &lt;/summary&gt;
		protected enum PageDataEntryMode
		{
			/// &lt;summary&gt;
			/// The page will add a new row
			/// &lt;/summary&gt;
			AddRow,
			/// &lt;summary&gt;
			/// The page is editing a row
			/// &lt;/summary&gt;
			EditRow,
			/// &lt;summary&gt;
			/// The page is viewing a row only
			/// &lt;/summary&gt;
			ViewRow,
			/// &lt;summary&gt;
			/// There is an error on the page / row to edit could not be found
			/// &lt;/summary&gt;
			ErrorOccurred
		}	
		
		#endregion
		
	
		#region Constants

		/// &lt;summary&gt;
		/// The name of the Read only parameter in the query string
		/// &lt;/summary&gt;
		protected const string ReadOnlyKeyName = &quot;ReadOnly&quot;;

		#endregion


		#region Fields

		

		#endregion

		
		#region Page Events

		/// &lt;summary&gt;
		/// Called when the page is loading
		/// &lt;/summary&gt;
		private void Page_Load(object sender, System.EventArgs e)
		{
			if (IsPostBack)
			{
				
			}
			else
			{
				//
				// Check if page should be read only
				//
				if (HasQueryStringParameter(ReadOnlyKeyName))
				{
					if (Request.QueryString[ReadOnlyKeyName].ToLower() == &quot;true&quot;)
					{
						DataEntryMode = PageDataEntryMode.ViewRow;

						DisableDataEntryControls(Controls);
					}
				}
			}
		}


		/// &lt;summary&gt;
		/// Creates a new instance of the base Page
		/// &lt;/summary&gt;
		public EditablePage()
		{
			this.Load += new EventHandler(Page_Load);
		}

		#endregion


		#region Event Handlers for Controls



		#endregion


		#region Private Methods
		
		/// &lt;summary&gt;
		/// Disables all data entry contols in the control collection
		/// &lt;/summary&gt;
		/// &lt;example&gt;
		/// DisableDataEntryControls(Page.Controls);
		/// &lt;/example&gt;
		/// &lt;param name=&quot;controlList&quot;&gt;A list of controls to disable&lt;/param&gt;
		protected void DisableDataEntryControls(ControlCollection controlList)
		{
			foreach (Control ControlCurrent in controlList)
			{
				if (ControlCurrent is HtmlContainerControl)
				{
					//
					// Call this method again recursively for container controls
					//
					HtmlContainerControl Container = ControlCurrent as HtmlContainerControl;
					DisableDataEntryControls(Container.Controls);
				}

				if (ControlCurrent is WebControl)
				{
					WebControl WebControlCurrent = ControlCurrent as WebControl;	

					if (WebControlCurrent is Calendar)
					{
						WebControlCurrent.Enabled = false;
					}
					if (WebControlCurrent is CheckBox)
					{
						WebControlCurrent.Enabled = false;
					}
					if (WebControlCurrent is LinkButton)
					{
						WebControlCurrent.Enabled = false;
					}
					if (WebControlCurrent is ListControl)
					{
						WebControlCurrent.Enabled = false;
					}
					if (WebControlCurrent is TextBox)
					{
						WebControlCurrent.Enabled = false;
					}
				}
			}
		}


		#endregion
		

		#region Public Properties

		/// &lt;summary&gt;
		/// The Data entry mode for editable pages
		/// &lt;/summary&gt;
		protected PageDataEntryMode DataEntryMode
		{
			get { return (PageDataEntryMode)GetViewState(&quot;DataEntryMode&quot;, PageDataEntryMode.AddRow); }
			set { ViewState[&quot;DataEntryMode&quot;] = value; }
		}

		#endregion
		
	}
}
</xsl:text>

</xsl:template>


</xsl:stylesheet>