<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet version="1.0" 
	xmlns:xsl="http://www.w3.org/1999/XSL/Transform" 
	>

<xsl:output 
	method="text" 
	indent="no" 
	omit-xml-declaration="yes"
	/>
<!-- 
//
// NextGeneration Template
// 
// Template Set:	Web User Interface
// Language:		.NET C#
// Template:		SearchPage base class
//
// Copyright (c) Ross Donald 2003-2004
// http://www.radsoftware.com.au
//
-->

<!-- FileName = "SearchPage.cs"	-->
<!-- Folder   = "WebUI"	-->

<xsl:param name="ObjectName" select="'Client'"/>
<xsl:param name="Namespace" select="NextGeneration"/>

<!--
//
// Main Template
//
-->
<xsl:template match="/">
<xsl:text>
using System;
using System.Collections;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Web;
using System.Web.SessionState;
using System.Web.UI;
using System.Web.UI.WebControls;
using System.Web.UI.HtmlControls;

using RAD.AppFramework.QueryObjects;

namespace </xsl:text><xsl:value-of select="$Namespace"/><xsl:text>.WebUI
{
	/// &lt;summary&gt;
	/// SearchPage
	/// &lt;/summary&gt;
	public class SearchPage : BasePage
	{
		#region Constants

		/// &lt;summary&gt;
		/// The message displayed when there are no matches for a search
		/// &lt;/summary&gt;
		protected const string NoMatchesMessage = &quot;Nothing was found that matched your search.&quot;;
		
		/// &lt;summary&gt;
		/// The message displayed on a successful search
		/// &lt;/summary&gt;
		protected const string MatchesFoundMessage = &quot;{0} matches for your search.&quot;;

		/// &lt;summary&gt;
		/// The index of the first page on a DataGrid
		/// &lt;/summary&gt;
		protected const int FirstPage = 0;

		/// &lt;summary&gt;
		/// The name of the parameter in the query string that 
		/// specifies the column to sort on
		/// &lt;/summary&gt;
		/// &lt;remarks&gt;
		/// Change this if you have a column in the Database called 'Sort'
		/// &lt;/remarks&gt;
		protected const string SortParameterName = &quot;Sort&quot;;

		/// &lt;summary&gt;
		/// The name of the parameter in the query string that 
		/// specifies the sort direction
		/// &lt;/summary&gt;
		protected const string SortDirectionParameterName = &quot;SortDir&quot;;

		#endregion


		#region Fields

		bool m_AllowSearchAll = false;

		#endregion


		#region Constructors

		/// &lt;summary&gt;
		/// Creates a new instance of the SearchPage class
		/// &lt;/summary&gt;		
		public SearchPage()
		{
		}

		#endregion

		
		#region Page Events



		#endregion


		#region Event Handlers for Controls



		#endregion


		#region Methods - Private


		/// &lt;summary&gt;
		/// Reads the query string to populate a 
		/// search criteria control
		/// &lt;/summary&gt;
		/// &lt;param name=&quot;fieldName&quot;&gt;The name of the parameter in the query string that has the search criteria&lt;/param&gt;
		/// &lt;param name=&quot;searchControl&quot;&gt;The control to populate with the search criteria&lt;/param&gt;
		/// &lt;returns&gt;zero if no criteria was found, or one if criteria is specified&lt;/returns&gt;
		protected int LoadSearchString(string fieldName, HtmlInputText searchControl)
		{
			if (HasQueryStringParameter(fieldName))
			{
				string SearchValue = Request.QueryString[fieldName];

				if ((SearchValue != null &amp;&amp; SearchValue.Length &gt; 0) || AllowSearchAll)
				{
					searchControl.Value = SearchValue;

					return 1;
				}
			}

			return 0;
		}


		/// &lt;summary&gt;
		/// Reads the query string to populate a 
		/// yes/no search criteria control
		/// &lt;/summary&gt;
		/// &lt;param name=&quot;fieldName&quot;&gt;The name of the parameter in the query string that has the search criteria&lt;/param&gt;
		/// &lt;param name=&quot;searchControl&quot;&gt;The control to populate with the search criteria&lt;/param&gt;
		/// &lt;returns&gt;zero if no criteria was found, or one if criteria is specified&lt;/returns&gt;
		protected int LoadSearchBoolean(string fieldName, HtmlSelect searchControl)
		{
			if (HasQueryStringParameter(fieldName))
			{
				string SearchValue = Request.QueryString[fieldName];

				if ((SearchValue != null &amp;&amp; SearchValue.Length &gt; 0) || AllowSearchAll)
				{
					searchControl.Value = SearchValue;

					return 1;
				}
			}

			return 0;
		}


		/// &lt;summary&gt;
		/// Reads the query string to populate a 
		/// search criteria control for a range search
		/// &lt;/summary&gt;
		/// &lt;param name=&quot;fieldName&quot;&gt;The name of the parameter in the query string that has the search criteria&lt;/param&gt;
		/// &lt;param name=&quot;searchControlBegin&quot;&gt;The control to populate with the beginning search criteria&lt;/param&gt;
		/// &lt;param name=&quot;searchControlEnd&quot;&gt;The control to populate with the ending search criteria&lt;/param&gt;
		/// &lt;returns&gt;&lt;/returns&gt;
		protected int LoadSearchBetween(string fieldName, HtmlInputText searchControlBegin, HtmlInputText searchControlEnd)
		{
			int CriteriaCount = LoadSearchString(fieldName + &quot;Begin&quot;, searchControlBegin);

			CriteriaCount += LoadSearchString(fieldName + &quot;End&quot;, searchControlEnd);

			return CriteriaCount;
		}


		/// &lt;summary&gt;
		/// Adds search criteria to a Query if the search control is not empty
		/// &lt;/summary&gt;
		/// &lt;param name=&quot;queryDefinition&quot;&gt;The query to add the criteria to&lt;/param&gt;
		/// &lt;param name=&quot;column&quot;&gt;The column to search on&lt;/param&gt;
		/// &lt;param name=&quot;comparisionMethod&quot;&gt;The type of search to perform&lt;/param&gt;
		/// &lt;param name=&quot;searchControl&quot;&gt;The search control that has the criteria&lt;/param&gt;
		protected void AddToQuery(Query queryDefinition, Enum column, Comparison comparisionMethod, HtmlInputText searchControl)
		{
			if (searchControl.Value.Length &gt; 0)
			{
				queryDefinition.And(Criteria.Create(column, Condition.Is, comparisionMethod, searchControl.Value));
			}
		}


		/// &lt;summary&gt;
		/// Adds search criteria to a Query if the search control is not empty
		/// &lt;/summary&gt;
		/// &lt;param name=&quot;queryDefinition&quot;&gt;The query to add the criteria to&lt;/param&gt;
		/// &lt;param name=&quot;column&quot;&gt;The column to search on&lt;/param&gt;
		/// &lt;param name=&quot;comparisionMethod&quot;&gt;The type of search to perform&lt;/param&gt;
		/// &lt;param name=&quot;searchControl&quot;&gt;The search control that has the criteria&lt;/param&gt;
		protected void AddToQuery(Query queryDefinition, Enum column, Comparison comparisionMethod, HtmlSelect searchControl)
		{
			if (searchControl.Value.Length &gt; 0)
			{
				queryDefinition.And(Criteria.Create(column, Condition.Is, comparisionMethod, System.Xml.XmlConvert.ToBoolean(searchControl.Value)));
			}
		}


		/// &lt;summary&gt;
		/// Adds Between search criteria to a Query if the search controls are not empty
		/// &lt;/summary&gt;
		/// &lt;param name=&quot;queryDefinition&quot;&gt;The query to add the criteria to&lt;/param&gt;
		/// &lt;param name=&quot;column&quot;&gt;The column to search on&lt;/param&gt;
		/// &lt;param name=&quot;searchControlBegin&quot;&gt;The search control with the lowest value&lt;/param&gt;
		/// &lt;param name=&quot;searchControlEnd&quot;&gt;The search control with the highest value&lt;/param&gt;
		protected void AddToQuery(Query queryDefinition, Enum column, HtmlInputText searchControlBegin, HtmlInputText searchControlEnd)
		{
			if (searchControlBegin.Value.Length &gt; 0 &amp;&amp; searchControlEnd.Value.Length &gt; 0)
			{
				//
				// Two values specified, use Between
				//
				queryDefinition.And(Criteria.Create(column, Condition.Is, Comparison.Between, searchControlBegin.Value, searchControlEnd.Value));

			}
			else if (searchControlBegin.Value.Length &gt; 0)
			{
				//
				// Low value specified, use GreaterThanOrEqualTo 
				//
				queryDefinition.And(Criteria.Create(column, Condition.Is, Comparison.GreaterThanOrEqualTo, searchControlBegin.Value));

			}
			else if (searchControlEnd.Value.Length &gt; 0)
			{
				//
				// High value specified, use GreaterThanOrEqualTo 
				//
				queryDefinition.And(Criteria.Create(column, Condition.Is, Comparison.LessThanOrEqualTo, searchControlEnd.Value));

			}
		}


		/// &lt;summary&gt;
		/// Reads the query string and adds a sort to the query
		/// if a sort expression is found
		/// &lt;/summary&gt;
		/// &lt;param name=&quot;queryDefinition&quot;&gt;The query to add the sort to&lt;/param&gt;
		/// &lt;param name=&quot;tableType&quot;&gt;The type of the Table enum that the current search is for e.g. typeof(EmployeeTable)&lt;/param&gt;
		protected void AddSortToQuery(Query queryDefinition, Type tableType)
		{
			string SortExpression = GetSortExpression();

			if (SortExpression.Length &gt; 0)
			{
				try
				{
					Enum SortColumn = (Enum)Enum.Parse(tableType, SortExpression, true);

					queryDefinition.Sort.Add(SortBy.Create(SortColumn, GetSortDirection()));
				}
				catch (ArgumentException)
				{
					//
					// Could not parse the SortExpression
					// do not add a sort to the query
					//
				}
			}
		}


		/// &lt;summary&gt;
		/// Reads the query string and returns 
		/// the current sort expression 
		/// &lt;/summary&gt;
		/// &lt;returns&gt;The column name to sort on or an empty string&lt;/returns&gt;
		protected string GetSortExpression()
		{
			if (HasQueryStringParameter(SortParameterName))
			{
				return Request.QueryString[SortParameterName];
			}

			return string.Empty;
		}


		/// &lt;summary&gt;
		/// Reads the query string and returns 
		/// the current sort direction
		/// &lt;/summary&gt;
		/// &lt;returns&gt;The SortDirection set in the query string or SortDirection.Ascending if none is found&lt;/returns&gt;
		protected SortDirection GetSortDirection()
		{
			if (HasQueryStringParameter(SortDirectionParameterName))
			{
				if (Request.QueryString[SortDirectionParameterName].Length &gt; 0)
				{
					try
					{
						//
						// Convert the string value into the enum value
						//
						return (SortDirection)Enum.Parse(typeof(SortDirection), Request.QueryString[SortDirectionParameterName], true);
					}
					catch (ArgumentException)
					{
						return SortDirection.Ascending;
					}
				}
			}

			return SortDirection.Ascending;
		}


		/// &lt;summary&gt;
		/// Sets the the sort expression in the url and 
		/// redirects to the url
		/// &lt;/summary&gt;
		/// &lt;param name=&quot;sortExpression&quot;&gt;The column name to sort on&lt;/param&gt;
		/// &lt;remarks&gt;
		/// The sort direction is checked and inverted
		/// if the sort expression is the same as the current sort expression in the query string
		/// &lt;/remarks&gt;
		protected void RedirectWithSortExpression(string sortExpression)
		{
			SortDirection SortDirectionCurrent = GetSortDirection();

			if (sortExpression == GetSortExpression())
			{
				//
				// The sort is on the same column so switch the sort direction
				//
				if (SortDirectionCurrent == SortDirection.Ascending)
				{
					SortDirectionCurrent = SortDirection.Descending;
				}
				else
				{
					SortDirectionCurrent = SortDirection.Ascending;
				}
			}
			else
			{
				//
				// Sorting on a different column so change back to the default sort
				//
				SortDirectionCurrent = SortDirection.Ascending;
			}

			UriBuilder UrlWithSort = new UriBuilder(Request.Url);

			UrlWithSort.Query = ChangeQueryStringValue(UrlWithSort.Query, SortParameterName, sortExpression);
			UrlWithSort.Query = ChangeQueryStringValue(UrlWithSort.Query, SortDirectionParameterName, SortDirectionCurrent.ToString());
			
			Response.Redirect(UrlWithSort.ToString());
		}


		#endregion


		#region Protected Properties

		/// &lt;summary&gt;
		/// Specifies if searches without criteria are allowed.
		/// A search without criteria will return all of the rows in a table.
		/// &lt;/summary&gt;
		protected bool AllowSearchAll
		{
			get { return m_AllowSearchAll; }
			set { m_AllowSearchAll = value; }
		}

		#endregion
		
	}
}
</xsl:text>

</xsl:template>


</xsl:stylesheet>