' ********* ********* ********* ********* ********* ********* 
' Script: CreateIISApplication.vbs 
'
' Creates an IIS virtual directory and web application
' and grants modify permissions to the ' anonymous internet 
' account and the ASP.NET worker process
'
' This script used by Rad Software NextGeneration 
' http://www.radsoftware.com.au
' ********* ********* ********* ********* ********* ********* 
' Info from: 
' http://www.eggheadcafe.com/articles/20010609.asp 
' http://www.15seconds.com/issue/010710.htm
' ********* ********* ********* ********* ********* ********* 

Option Explicit

Dim objWScriptNetwork
Dim objWScriptShell
Dim objIIS 							' ADSI IIS Object
Dim objFileSystem 					' VBScript FileSystemObject
Dim strAnonInternetUser 			' NT Folder Owner
Dim objVirtualDirectory 			' ADSI IIS Virtual Directory Object
Dim strACLCommand 					' Command Line string to set ACLs

' Command-line arguments
Dim strVirtualDirectoryName 		' IIS Virtual Directory Name - e.g. MyWebApp, BugTracker
Dim strVirtualDirectoryPath 		' IIS Virtual Directory Path - e.g. C:\Projects\MyWebApp, C:\Dev\BugTrackerApp\WebUI

'
' Start Script
'
WScript.Echo "-------------------------------------------------------------------------------"
WScript.Echo "Rad Software NextGeneration - http://www.radsoftware.com.au"
WScript.Echo "Create IIS Virtual Directory Script"
WScript.Echo "-------------------------------------------------------------------------------"

If WScript.Arguments.Count < 2 Then
	WScript.Echo "This script creates a virtual directory mapping in IIS"
	WScript.Echo " "
	WScript.Echo "Usage: CreateIISApplication.vbs virtualdir path"
	WScript.Echo "e.g."
	WScript.Echo "cscript CreateIISApplication.vbs BugTracker C:\Dev\BugTrackerApp\WebUI"
	WScript.Echo " "
	WScript.Quit(0)
End If
WScript.Echo "-------------------------------------------------------------------------------"

'
' Get command-line arguments
'
strVirtualDirectoryName = WScript.Arguments(0)
strVirtualDirectoryPath = WScript.Arguments(1)

'
' VirtualDirectoryPath must not end in a backslash or the cacls will not work
'
If Mid(strVirtualDirectoryPath, Len(strVirtualDirectoryPath), 1) = "\" Then
	'
	' Ends with backslash (\), remove it
	'
	strVirtualDirectoryPath = Mid(strVirtualDirectoryPath, 1, Len(strVirtualDirectoryPath)-1)
End If

'
' Get the Computer name using WScript.Network 
' and add IUSR_ to create IIS IUSR account name (IIS 5)
'
Set objWScriptNetwork = WScript.CreateObject("WScript.Network")
strAnonInternetUser = "IUSR_" & objWScriptNetwork.ComputerName
Set objWScriptNetwork = Nothing

Set objWScriptShell = WScript.CreateObject("WScript.Shell")

'
' Check if the Web application already exists
'
On Error Resume Next
Set objIIS = GetObject("IIS://localhost/W3SVC/1/Root/" & strVirtualDirectoryName)

If Err.Number = 0 Then
	WScript.Echo "A web application with this name already exists, exiting script."
	WScript.Quit(1)
End If

Set objIIS = Nothing

'
' Create the IIS application
'
WScript.Echo "Opening IIS Web root..."
Set objIIS = GetObject("IIS://localhost/W3SVC/1/Root")

'
' Check that the folder exists
'
WScript.Echo "Creating FileSystemObject"
WScript.Echo "A warning might be displayed if you have anti-virus software installed..."

Set objFileSystem = WScript.CreateObject("Scripting.FileSystemObject")
On Error Resume Next

Set Folder = objFileSystem.GetFolder(strVirtualDirectoryPath)

If Hex(Err.number) = "4C" Then
	WScript.Echo "Folder does not exist, creating folder: " & strVirtualDirectoryPath
	set f = objFileSystem.CreateFolder(strVirtualDirectoryPath)
End If

Set objFileSystem = Nothing

'
' Create a virtual directory
'
WScript.Echo "Creating IIS virtual directory..."
Set objVirtualDirectory = objIIS.Create("IISWebVirtualDir", strVirtualDirectoryName)

objVirtualDirectory.AccessScript = True
objVirtualDirectory.Path = strVirtualDirectoryPath

objVirtualDirectory.AccessWrite = False
objVirtualDirectory.AccessRead = True
objVirtualDirectory.AccessExecute = False
'
' Allow anonymous authentication, Windows authentication
'
objVirtualDirectory.AuthAnonymous = True
objVirtualDirectory.AuthNTLM = True
objVirtualDirectory.AuthMD5 = True

objVirtualDirectory.EnableDirBrowsing = True
objVirtualDirectory.FrontPageWeb = 1
objVirtualDirectory.SetInfo 

Set objVirtualDirectory = Nothing

'
' Install FrontPage Extensions on the Virtual Directory
'
WScript.Echo "Installing FrontPage extensions for /" & strVirtualDirectoryName & "..."
strACLCommand = "cmd /c """"C:\Program Files\Common Files\Microsoft Shared\web server extensions\40\bin\fpsrvadm.exe"" -operation install -p 80 -web " & strVirtualDirectoryName & " > fpsrvadm.log"""
'''WScript.Echo "COMMAND: " & strACLCommand 
objWScriptShell.Run strACLCommand, 0, True

'
' Read the output of the FrontPage server admin tool to the console
'
Const ForReading = 1
Dim fso
Dim objLogFile
Set fso = CreateObject("Scripting.FileSystemObject")
Set objLogFile = fso.OpenTextFile("fpsrvadm.log", ForReading, False)
WScript.Echo objLogFile.ReadAll
objLogFile.Close
Set objLogFile = Nothing
Set fso = Nothing

'
' Convert the Virtual Directory into a web application
'
Set objVirtualDirectory = GetObject("IIS://localhost/W3SVC/1/Root/" & strVirtualDirectoryName)

WScript.Echo "Creating IIS application..."
objVirtualDirectory.AppCreate True		' In process is True
objVirtualDirectory.AppIsolated = 2		' Pooled in-process
objVirtualDirectory.AppFriendlyName = strVirtualDirectoryName

objVirtualDirectory.SetInfo 

'
' Set Change Permissions using CACLS.exe
' need to stuff the keyboard buffer with "Y" to answer the "Are you sure?" prompt
' that CACLS displays (see KB: Q135268 )
' /E = edit ACL instead of replacing it 
'

'
' Need to get the IIS Version as IIS 5 & 6 use different anonymous users
' HKEY_LOCAL_MACHINE\SYSTEM\CurrentControlSet\Services\W3SVC\Parameters\MajorVersion = 5
' HKEY_LOCAL_MACHINE\SYSTEM\CurrentControlSet\Services\W3SVC\Parameters\MinorVersion = 1
'
WScript.Echo "Granting read permissions to " & strAnonInternetUser & "..."
strACLCommand = "cmd /c echo y| CACLS " & strVirtualDirectoryPath & " /E /g " & strAnonInternetUser & ":R"
objWScriptShell.Run strACLCommand, 0, True

WScript.Echo "Granting modify permissions to the ASPNET worker process..."
strACLCommand = "cmd /c echo y| CACLS " & strVirtualDirectoryPath & " /E /g ASPNET:C"
objWScriptShell.Run strACLCommand, 0, True

WScript.Echo "Web application created sucessfully."
WScript.Echo ""
WScript.Echo "Directory " & strVirtualDirectoryPath & " "  
WScript.Echo "is now mapped to  http://localhost/" & strVirtualDirectoryName 
WScript.Echo ""
WScript.Echo "Script completed."