<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet 
	version="1.0" 
	xmlns:xsl="http://www.w3.org/1999/XSL/Transform" 
	>

<xsl:import 
	href="WebUICommon.xsl" 
	/>
	
<xsl:output 
	method="text" 
	indent="no" 
	omit-xml-declaration="yes"
	/>
<!-- 
//
// NextGeneration Template
// 
// Template Set:	Web User Interface
// Language:		.NET C#
// Template:		Code Behind file for View and Edit Page
//
// Copyright (c) Ross Donald 2003-2004
// http://www.radsoftware.com.au
//
-->

<!-- FileName = "{0}.aspx.cs"	-->
<!-- Folder   = "WebUI"			-->

<xsl:param name="ObjectName" select="'EmployeeTerritories'"/>
<xsl:param name="Namespace" select="'NextGeneration'"/>
<xsl:param name="RowCreatedColumnName"  select="'CreateDate'" />
<xsl:param name="RowModifiedColumnName" select="'LastModifyDate'" />

<!--
//
// Main Template
//
-->
<xsl:template match="/">

	<!-- 
	// Create the code behind file for a basic edit page
	-->
	<xsl:apply-templates select="/db/Table[table_name_safe = $ObjectName]"/>
	
</xsl:template>



<!--
//
// Create the code behind file for an ASPX Editing and viewing page 
//
-->
<xsl:template match="Table">

<xsl:text>
using System;
using System.Collections;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Web;
using System.Web.SessionState;
using System.Web.UI;
using System.Web.UI.WebControls;
using System.Web.UI.HtmlControls;

using </xsl:text><xsl:value-of select="$Namespace"/><xsl:text>.BusinessServiceInterfaces;
using </xsl:text><xsl:value-of select="$Namespace"/><xsl:text>.Data;
using </xsl:text><xsl:value-of select="$Namespace"/><xsl:text>.DataRetrieval;

namespace </xsl:text><xsl:value-of select="$Namespace"/><xsl:text>.WebUI
{
	/// &lt;summary&gt;
	/// Code-behind file for the </xsl:text>
	<xsl:value-of select="table_name_safe"/>
	<xsl:text>.aspx Page
	/// &lt;/summary&gt;
	public class </xsl:text>
	<xsl:value-of select="table_name_safe"/>
	<xsl:text> : EditablePage
	{
		#region Constants


		#endregion


		#region Fields

		</xsl:text>	
		
			<xsl:for-each select="Column[is_key = 'true']">
			
			<xsl:text>private </xsl:text>
			<xsl:value-of select="data_type_clr"/>
			
			<xsl:text> m_</xsl:text>
			<xsl:value-of select="column_name_safe"/>
			<xsl:text>Current;
		</xsl:text>

			</xsl:for-each>
		
		<xsl:text>

		#endregion

				
		#region Page Events

		/// &lt;summary&gt;
		/// Event raised when the page is requested
		/// &lt;/summary&gt;
		private void Page_Load(object sender, System.EventArgs e)
		{
			//
			// Find primary key values to use to populate the form
			//
			if (</xsl:text><xsl:apply-templates select="." mode="CheckPK"/><xsl:text>)
			{
				</xsl:text>	
				<xsl:apply-templates select="." mode="LoadPKVars"/><xsl:text>
				DataEntryMode = PageDataEntryMode.EditRow;

				PageTitle = string.Format("</xsl:text>
				<xsl:value-of select="table_name_friendly"/>
				<xsl:text> - Editing </xsl:text>
				
				<!-- build a format string for string.format like "{0}: {1}, {2}: {3}" -->
				<xsl:apply-templates select="." mode="StringFormatArgList">
					<xsl:with-param name="seperatorChar" select="': '"/>
					<xsl:with-param name="joinChar" select="', '"/>
				</xsl:apply-templates>
				
				<xsl:text>", </xsl:text>
					
				<xsl:apply-templates select="." mode="StringFormatPKList"/>
				<xsl:text>);
			}
			else
			{
				DataEntryMode = PageDataEntryMode.AddRow;

				PageTitle = "</xsl:text>
				<xsl:value-of select="table_name_friendly"/>
				<xsl:text> - Adding a new entry";
				lblMessage.Text = "Adding a new entry";
			}

			if (Page.IsPostBack)
			{
			
			}
			else
			{
				//
				// Initial Page Request
				//
				PopulateControls();

				if (DataEntryMode == PageDataEntryMode.EditRow || DataEntryMode == PageDataEntryMode.ViewRow)
				{
					if (!LoadData())
					{
						//
						// Could not load the row from the database
						//
						lblMessage.Text = "Error loading </xsl:text><xsl:value-of select="table_name_safe"/><xsl:text>";

						DataEntryMode = PageDataEntryMode.ErrorOccurred;
						
						DisableDataEntryControls(this.Controls);
					}
				}
			}
		}

		#endregion


		#region Event Handlers for Controls

		/// &lt;summary&gt;
		/// Apply the changes and return to the previous screen
		/// &lt;/summary&gt;
		private void btnOK_Click(object sender, System.EventArgs e)
		{
			if (SaveData())
			{
				Response.Redirect(UrlPrevious.ToString());
			}
		}


		/// &lt;summary&gt;
		/// Apply the changes and remain on this page
		/// &lt;/summary&gt;
		private void btnApply_Click(object sender, System.EventArgs e)
		{
			if (SaveData())
			{
				//
				// Redirect back to this page in Edit mode
				//
				if (DataEntryMode == PageDataEntryMode.AddRow)
				{	</xsl:text>
					
					<xsl:choose>
					
						<!-- Table has a primary key -->
						<xsl:when test="count(Column[is_key = 'true']) &gt; 0">
							<xsl:text>
					UriBuilder EditUri = new UriBuilder(Request.Url);
					EditUri.Query += string.Format("</xsl:text>
					
					<!-- build a format string for string.format like "{0}={1}&{2}={3}"	-->
					<xsl:apply-templates select="." mode="StringFormatArgList">
						<xsl:with-param name="seperatorChar" select="'='"/>
						<xsl:with-param name="joinChar" select="'&amp;'"/>
					</xsl:apply-templates>
					
					<xsl:text>", </xsl:text>
					
					<xsl:apply-templates select="." mode="StringFormatPKList"/>
					<xsl:text>);

					//
					// Redirect back to this page 
					// with the primary key information in the query string
					//
					Response.Redirect(EditUri.ToString());
							</xsl:text>
						</xsl:when>
						
						<!-- There is no primary key -->
						<xsl:otherwise>
						<xsl:text>
					//
					// No primary key, so redirect back to this page 
					// so another row can be added
					//
					Response.Redirect(Request.Url);
						</xsl:text>
							
						</xsl:otherwise>
					
					</xsl:choose>
					
					<xsl:text>
				}
				else
				{
					lblMessage.Text = "</xsl:text><xsl:value-of select="table_name_friendly"/><xsl:text> saved";

					LoadData();
				}
			}
			else
			{
				lblMessage.Text = "Error saving </xsl:text><xsl:value-of select="table_name_friendly"/><xsl:text>";
				DataEntryMode = PageDataEntryMode.ErrorOccurred;
			}
		}
		
		
		/// &lt;summary&gt;
		/// return to the previous screen
		/// &lt;/summary&gt;
		private void btnCancel_Click(object sender, System.EventArgs e)
		{
			Response.Redirect(UrlPrevious.ToString());
		}
		
		#endregion


		#region Private Methods
		
		/// &lt;summary&gt;
		/// Loads data from the database for drop down lists
		/// &lt;/summary&gt;
		private void PopulateControls()
		{
			</xsl:text>

	<xsl:for-each select="Column[data_type_native != 'timestamp' and data_type_clr != 'Byte[]']">
	
		<xsl:variable name="ColumnCurrentName" select="column_name"/>
	
		<xsl:if test="count(parent::*/Foreign_Key_Child/Column[fk_column_name = $ColumnCurrentName]) &gt; 0">
			<xsl:variable name="FKTableName" select="parent::*/Foreign_Key_Child[Column[fk_column_name = $ColumnCurrentName]]/pk_table_name"/>
			<xsl:variable name="FKTable" select="/db/Table[table_name = $FKTableName]"/>
			<xsl:variable name="FKColumn" select="parent::*/Foreign_Key_Child/Column[fk_column_name = $ColumnCurrentName]"/>
			
			<xsl:text>
			//
			// Populate the </xsl:text><xsl:value-of select="column_name_safe"/><xsl:text> Drop Down List
			//
			</xsl:text>
			<xsl:value-of select="$FKTable/table_name_safe"/>
			<xsl:text>DataSet </xsl:text>
			<xsl:value-of select="$FKTable/table_name_safe"/>
			<xsl:text>DS = new </xsl:text>
			<xsl:value-of select="$FKTable/table_name_safe"/>
			<xsl:text>DataSet();
			I</xsl:text><xsl:value-of select="$FKTable/table_name_safe"/>
			<xsl:text>Service </xsl:text>
			<xsl:value-of select="$FKTable/table_name_safe"/>
			<xsl:text>Logic = DataRetrievalFactory.GetDataRetrievalFactory().Create</xsl:text>
			<xsl:value-of select="$FKTable/table_name_safe"/><xsl:text>Service();
			
			if (</xsl:text>
			<xsl:value-of select="$FKTable/table_name_safe"/>
			<xsl:text>Logic.GetAll(</xsl:text>
			<xsl:value-of select="$FKTable/table_name_safe"/>
			<xsl:text>DS) &gt; 0)
			{
				ListItem </xsl:text>
			<xsl:value-of select="$FKTable/table_name_safe"/>
			<xsl:text>ListItemNew;
				foreach (</xsl:text>
			<xsl:value-of select="$FKTable/table_name_safe"/>
			<xsl:text>DataSet.</xsl:text>
			<xsl:value-of select="$FKTable/table_name_safe"/>
			<xsl:text>Row </xsl:text>
			<xsl:value-of select="$FKTable/table_name_safe"/>
			<xsl:text>Current in </xsl:text>
			<xsl:value-of select="$FKTable/table_name_safe"/>
			<xsl:text>DS.</xsl:text>
			<xsl:value-of select="$FKTable/table_name_safe"/>
			<xsl:text>.Rows)
				{
					</xsl:text>
			<xsl:value-of select="$FKTable/table_name_safe"/>
			<xsl:text>ListItemNew = new ListItem();
					</xsl:text>
			<xsl:value-of select="$FKTable/table_name_safe"/>
			<xsl:text>ListItemNew.Value = </xsl:text>
			<xsl:value-of select="$FKTable/table_name_safe"/>
			<xsl:text>Current.</xsl:text>
			<xsl:value-of select="$FKColumn/pk_column_name_safe"/>
			<xsl:text>.ToString();
					</xsl:text>
			<xsl:value-of select="$FKTable/table_name_safe"/>
			<xsl:text>ListItemNew.Text = </xsl:text>
			<xsl:value-of select="$FKTable/table_name_safe"/>
			<xsl:text>Current.</xsl:text>
			<xsl:value-of select="$FKColumn/pk_column_name_safe"/>
			<xsl:text>.ToString();

					ctl</xsl:text>
			<xsl:value-of select="column_name_safe"/>
			<xsl:text>.Items.Add(</xsl:text>
			<xsl:value-of select="$FKTable/table_name_safe"/>
			<xsl:text>ListItemNew);
				}
			}
			</xsl:text>
				
		</xsl:if>
	
	</xsl:for-each>
	
	<xsl:text>
		}
		
		/// &lt;summary&gt;
		/// Loads a row from the </xsl:text><xsl:value-of select="table_name"/><xsl:text> table for viewing or editing
		/// &lt;/summary&gt;
		/// &lt;returns&gt;true on success, false on error&lt;/returns&gt;
		private bool LoadData()
		{
			if ((DataEntryMode != PageDataEntryMode.EditRow) &amp;&amp; (DataEntryMode != PageDataEntryMode.ViewRow))
			{
				return true;
			}
			
			</xsl:text>
			<xsl:value-of select="table_name_safe"/><xsl:text>DataSet </xsl:text>
			<xsl:value-of select="table_name_safe"/><xsl:text>DS = new </xsl:text>
			<xsl:value-of select="table_name_safe"/><xsl:text>DataSet();
			I</xsl:text><xsl:value-of select="table_name_safe"/><xsl:text>Service </xsl:text>
			<xsl:value-of select="table_name_safe"/><xsl:text>Logic = DataRetrievalFactory.GetDataRetrievalFactory().Create</xsl:text>
			<xsl:value-of select="table_name_safe"/><xsl:text>Service();
			
			if (</xsl:text>
			<xsl:value-of select="table_name_safe"/><xsl:text>Logic.GetBy</xsl:text>

			<!-- Call GetByPK -->

			<xsl:for-each select="Column[is_key = 'true']">
			
				<xsl:if test="position() != 1">
					<xsl:text>And</xsl:text>
				</xsl:if>
				<xsl:value-of select="column_name_safe" />
					
			</xsl:for-each>

			<xsl:text>(</xsl:text>
			<xsl:value-of select="table_name_safe"/><xsl:text>DS, </xsl:text>
			
			<xsl:for-each select="Column[is_key = 'true']">
			
				<xsl:if test="position() != 1">
					<xsl:text>, </xsl:text>
				</xsl:if>
				<xsl:text>m_</xsl:text>
				<xsl:value-of select="column_name_safe" />
				<xsl:text>Current</xsl:text>
	
			</xsl:for-each>
			
			<xsl:text>) == 0)
			{
				//
				// </xsl:text><xsl:value-of select="table_name_safe"/><xsl:text> Row not found
				//
				return false;
			}

			</xsl:text>
			<xsl:value-of select="table_name_safe"/><xsl:text>DataSet.</xsl:text>
			<xsl:value-of select="table_name_safe"/><xsl:text>Row </xsl:text>
			<xsl:value-of select="table_name_safe"/><xsl:text>RowCurrent = </xsl:text>
			<xsl:value-of select="table_name_safe"/><xsl:text>DS.</xsl:text>
			<xsl:value-of select="table_name_safe"/><xsl:text>[0];
			ListItem SelectedListItem;
			
			//
			// Populate the Page controls from the DataRow
			//
			</xsl:text>
			
			<xsl:for-each select="Column[data_type_native != 'timestamp' and data_type_clr != 'Byte[]']">
			
				<xsl:variable name="ColumnCurrentName" select="column_name"/>
			
				<xsl:choose>
			
					<!--
					// Drop Down List
					-->
					<xsl:when test="count(parent::*/Foreign_Key_Child/Column[fk_column_name = $ColumnCurrentName]) &gt; 0">

			<!--
			// Access allows null primary keys but they will not 
			// be nullable in the DataSet
			-->
			<xsl:if test="is_nullable = 'true' and is_key = 'false'"> 
				
				<xsl:text>
			if (!</xsl:text>
				<xsl:value-of select="parent::*/table_name_safe"/>
				<xsl:text>RowCurrent.Is</xsl:text>
				<xsl:value-of select="column_name_safe"/>
				<xsl:text>Null())
			{
				</xsl:text>
						
			</xsl:if>
	
			<xsl:text>SelectedListItem = ctl</xsl:text><xsl:value-of select="column_name_safe"/>
			<xsl:text>.Items.FindByValue(</xsl:text><xsl:value-of select="parent::*/table_name_safe"/>
			<xsl:text>RowCurrent.</xsl:text><xsl:value-of select="column_name_safe"/>
			<xsl:text>.ToString());
			</xsl:text>
			
			<xsl:if test="is_nullable = 'true' and is_key = 'false'">
				<xsl:text>	</xsl:text></xsl:if><xsl:text>if (SelectedListItem != null)
			</xsl:text><xsl:if test="is_nullable = 'true' and is_key = 'false'"><xsl:text>	</xsl:text></xsl:if><xsl:text>{
			</xsl:text><xsl:if test="is_nullable = 'true' and is_key = 'false'"><xsl:text>	</xsl:text></xsl:if><xsl:text>	ctl</xsl:text><xsl:value-of select="column_name_safe"/><xsl:text>.ClearSelection();
			</xsl:text><xsl:if test="is_nullable = 'true' and is_key = 'false'"><xsl:text>	</xsl:text></xsl:if><xsl:text>	SelectedListItem.Selected = true;
			</xsl:text><xsl:if test="is_nullable = 'true' and is_key = 'false'"><xsl:text>	</xsl:text></xsl:if><xsl:text>}</xsl:text>
						
				<xsl:if test="is_nullable = 'true' and is_key = 'false'"> 
					
				<xsl:text>
			}</xsl:text>

			</xsl:if>

					</xsl:when>
								
					<!-- 
					// Set Checkbox .Checked
					-->
					<xsl:when test="data_type_clr = 'Boolean'">
						<xsl:text>ctl</xsl:text>
						<xsl:value-of select="column_name_safe"/>
						<xsl:text>.Checked = </xsl:text>
						<xsl:value-of select="parent::*/table_name_safe"/>
						<xsl:text>RowCurrent.</xsl:text>
						<xsl:value-of select="column_name_safe"/>
						<xsl:text>;</xsl:text>
					</xsl:when>
								
					<!-- 
					// Textbox or Label Control
					-->		
					<xsl:otherwise>
						<xsl:text>ctl</xsl:text>
						<xsl:value-of select="column_name_safe"/>
						<xsl:text>.Text = </xsl:text>
						
						<!-- Check for nulls -->
						<xsl:if test="is_nullable = 'true' and is_key = 'false'"> 
							
							<xsl:text>(</xsl:text>
							<xsl:value-of select="parent::*/table_name_safe"/>
							<xsl:text>RowCurrent.Is</xsl:text>
							<xsl:value-of select="column_name_safe"/>
							<xsl:text>Null()) ? string.Empty : </xsl:text>
						
						</xsl:if>
						
		
						
						<xsl:value-of select="parent::*/table_name_safe"/>
						<xsl:text>RowCurrent.</xsl:text>
						<xsl:value-of select="column_name_safe"/>
						
						<xsl:choose>
							<!-- 
							Currency needs to be formatted to 2 decimal places as the
							validator will check it
							 -->
							<xsl:when test="data_type_native = 'money' or data_type_native = 'smallmoney' or data_type_native = 'Currency'">
								<xsl:text>.ToString("0.00")</xsl:text>
							</xsl:when>
							
							<xsl:otherwise>
								<!-- Convert to string if not a string data type -->
								<xsl:if test="data_type_clr != 'String'">
									<xsl:text>.ToString()</xsl:text>
								</xsl:if>
							</xsl:otherwise>
						</xsl:choose>
						
						<xsl:text>;</xsl:text>

					</xsl:otherwise>
				
				</xsl:choose>
			
				<!-- New Line -->	
				<xsl:text>
			</xsl:text>
			
			</xsl:for-each>
			
			<xsl:text>
			
			return true;
		}
		
		</xsl:text>
		
		<xsl:apply-templates select="." mode="SaveRow"/>
		
		<xsl:text>		
		
		#endregion

		
		#region Web Form Designer generated code
		
		protected System.Web.UI.WebControls.Label lblMessage;
		protected System.Web.UI.WebControls.ValidationSummary ctlValidationSummary;
		protected System.Web.UI.WebControls.Button btnOK;
		protected System.Web.UI.WebControls.Button btnApply;
		protected System.Web.UI.WebControls.Button btnCancel;
		</xsl:text>
		
		<xsl:for-each select="Column[data_type_native != 'timestamp' and data_type_clr != 'Byte[]']">
			
		
			<xsl:text>protected System.Web.UI.WebControls.</xsl:text>
			
			<!-- Retuns the ASP.NET Web Control class e.g. TextBox -->
			<xsl:variable name="ControlType">
				<xsl:apply-templates select="." mode="GetControlType"/>
			</xsl:variable>
			<xsl:value-of select="$ControlType"/>
			
			<xsl:text> ctl</xsl:text>
			
			<xsl:value-of select="column_name_safe"/><xsl:text>;
		</xsl:text>
			
		</xsl:for-each>
		
		<xsl:text>
		
		override protected void OnInit(EventArgs e)
		{
			//
			// CODEGEN: This call is required by the ASP.NET Web Form Designer.
			//
			InitializeComponent();
			base.OnInit(e);
		}
		
		/// &lt;summary&gt;
		/// Required method for Designer support - do not modify
		/// the contents of this method with the code editor.
		/// &lt;/summary&gt;
		private void InitializeComponent()
		{    
			this.btnOK.Click += new System.EventHandler(this.btnOK_Click);
			this.btnApply.Click += new System.EventHandler(this.btnApply_Click);
			this.btnCancel.Click += new System.EventHandler(this.btnCancel_Click);
			this.Load += new System.EventHandler(this.Page_Load);
			
		}
		
		#endregion
	}
}

</xsl:text>

</xsl:template>



<!--
//
// Checks that the Primary key is passed on the QueryString
// or in the ViewState
//
// e.g.
// (HasQueryStringParameter("TimesheetDate") && HasQueryStringParameter("ConsultantID")
//
-->
<xsl:template match="Table" mode="CheckPK">
	
	<xsl:for-each select="Column[is_key = 'true']">
			
		<xsl:if test="position() != 1">
		
		<xsl:text> &amp;&amp; </xsl:text>
		
		</xsl:if>
		
		<xsl:text>HasQueryStringParameter("</xsl:text>
		<xsl:value-of select="column_name_safe"/>
		
		<xsl:text>")</xsl:text>

	</xsl:for-each>

</xsl:template>


<!--
//
// Loads the Primary key from the the QueryString or the ViewState
//
// e.g.
// m_TimesheetDateCurrent = Convert.ToDateTime(Request.QueryString["TimesheetDate"]);
// m_ConsultantIDCurrent = Convert.ToString(Request.QueryString["ConsultantID"]);
//
-->
<xsl:template match="Table" mode="LoadPKVars">
	
	<xsl:for-each select="Column[is_key = 'true']">
			
		<xsl:text>m_</xsl:text>
		<xsl:value-of select="column_name_safe"/>
		<xsl:text>Current = Convert.To</xsl:text>
		<xsl:value-of select="data_type_clr"/>
		<xsl:text>(Request.QueryString["</xsl:text>
		<xsl:value-of select="column_name_safe"/>
		<xsl:text>"]);
				</xsl:text>

	</xsl:for-each>

</xsl:template>




<!--
//
// Lists the primary key variables to use with string.Format
//
// e.g.
// "TimesheetDate", m_TimesheetDateCurrent, "ConsultantID", m_ConsultantIDCurrent
//
-->
<xsl:template match="Table" mode="StringFormatPKList">
	
	<xsl:for-each select="Column[is_key = 'true']">
			
		<xsl:if test="position() != 1">
			<xsl:text>, </xsl:text>
		</xsl:if>
		
		<xsl:text>"</xsl:text>
		<xsl:value-of select="column_name_safe"/>
		<xsl:text>", m_</xsl:text>
		<xsl:value-of select="column_name_safe"/>
		<xsl:text>Current</xsl:text>

	</xsl:for-each>

</xsl:template>


<!--
//
// Save Row function
//
-->
<xsl:template match="Table" mode="SaveRow">

<xsl:text>
		/// &lt;summary&gt;
		/// Adds or updates the row in the Database
		/// &lt;/summary&gt;
		/// &lt;returns&gt;true on success, false on error&lt;/returns&gt;
		private bool SaveData()
		{
			//
			// Check that the Form has passed validation
			//
			Page.Validate();
			
			if (!Page.IsValid)
			{
				// Validation failed
				return false;
			}
			
			</xsl:text>
			<xsl:value-of select="table_name_safe"/><xsl:text>DataSet </xsl:text>
			<xsl:value-of select="table_name_safe"/><xsl:text>DS = new </xsl:text>
			<xsl:value-of select="table_name_safe"/><xsl:text>DataSet();
			I</xsl:text>
			<xsl:value-of select="table_name_safe"/><xsl:text>Service </xsl:text>
			<xsl:value-of select="table_name_safe"/><xsl:text>Logic = DataRetrievalFactory.GetDataRetrievalFactory().Create</xsl:text>
			<xsl:value-of select="table_name_safe"/><xsl:text>Service();
			</xsl:text>
			<xsl:value-of select="table_name_safe"/><xsl:text>DataSet.</xsl:text>
			<xsl:value-of select="table_name_safe"/><xsl:text>Row </xsl:text>
			<xsl:value-of select="table_name_safe"/><xsl:text>RowCurrent;
			
			
			switch (DataEntryMode)
			{
				case PageDataEntryMode.AddRow:
					//
					// Create a New Row
					//
					</xsl:text>
			<xsl:value-of select="table_name_safe"/><xsl:text>RowCurrent = </xsl:text>
			<xsl:value-of select="table_name_safe"/><xsl:text>DS.</xsl:text>
			<xsl:value-of select="table_name_safe"/><xsl:text>.New</xsl:text>
			<xsl:value-of select="table_name_safe"/><xsl:text>Row();
					break;
					
				case PageDataEntryMode.EditRow:
					//
					// Update existing Row
					//
					if (</xsl:text>
			<xsl:value-of select="table_name_safe"/><xsl:text>Logic.GetBy</xsl:text>

			<!-- Call GetByPK -->

			<xsl:for-each select="Column[is_key = 'true']">
			
				<xsl:if test="position() != 1">
					<xsl:text>And</xsl:text>
				</xsl:if>
				<xsl:value-of select="column_name_safe" />
					
			</xsl:for-each>

			<xsl:text>(</xsl:text>
			<xsl:value-of select="table_name_safe"/><xsl:text>DS, </xsl:text>
			
			<xsl:for-each select="Column[is_key = 'true']">
			
				<xsl:if test="position() != 1">
					<xsl:text>, </xsl:text>
				</xsl:if>
				<xsl:text>m_</xsl:text>
				<xsl:value-of select="column_name_safe" />
				<xsl:text>Current</xsl:text>
	
			</xsl:for-each>
			
			<xsl:text>) == 0)
					{
						//
						// </xsl:text>
			<xsl:value-of select="table_name_safe"/><xsl:text> Row not found
						//
						return false;
					}
					else
					{
						</xsl:text>
			<xsl:value-of select="table_name_safe"/><xsl:text>RowCurrent = </xsl:text>
			<xsl:value-of select="table_name_safe"/><xsl:text>DS.</xsl:text>
			<xsl:value-of select="table_name_safe"/><xsl:text>[0];
					}
					break;
					
				default:
					return false;
			}

			//
			// Set the DataRow values from the Page Controls
			//
			</xsl:text>
			
			<!--
			//
			// Go through the columns and get the values into the datarow
			//
			-->
			<xsl:for-each select="Column[is_auto_increment != 'true' and is_read_only != 'true' and column_name != $RowCreatedColumnName and column_name != $RowModifiedColumnName and data_type_native != 'timestamp' and data_type_clr != 'Byte[]']">
			
			<xsl:text>
			// </xsl:text><xsl:value-of select="column_name"/><xsl:text>
			</xsl:text>
			
				<xsl:variable name="ColumnCurrentName" select="column_name"/>
			
			<xsl:choose>
			
					<!--
					// Drop Down List
					-->
					<xsl:when test="count(parent::*/Foreign_Key_Child/Column[fk_column_name = $ColumnCurrentName]) &gt; 0">

			<!--
			// Access allows nullable primary keys but they will not 
			// be nullable in the DataSet so check if it is a key column
			-->
			<xsl:if test="is_nullable = 'true' and is_key = 'false'"> 
				
				<xsl:text>
			
			if (ctl</xsl:text>
				<xsl:value-of select="column_name_safe"/>
				<xsl:text>.SelectedIndex == 0)
			{
				</xsl:text>
				<xsl:value-of select="parent::*/table_name_safe"/>
				<xsl:text>RowCurrent.Set</xsl:text>
				<xsl:value-of select="column_name_safe"/>
				<xsl:text>Null();	
			}
			else
			{
				</xsl:text>
			
			</xsl:if>
	
			<xsl:value-of select="parent::*/table_name_safe"/>
			<xsl:text>RowCurrent.</xsl:text>
			<xsl:value-of select="column_name_safe"/>
			<xsl:text> = </xsl:text>
			
			<!--
			// Convert form control if not string
			-->
			<xsl:if test="data_type_clr != 'String'">
			
				<xsl:text>Convert.To</xsl:text>
				<xsl:value-of select="data_type_clr"/>
				<xsl:text>(</xsl:text>
			
			</xsl:if>
			
			<!-- "ctlFirstname.Text"  -->
			<xsl:text>ctl</xsl:text>
			<xsl:value-of select="column_name_safe"/>
			<xsl:text>.SelectedItem.Value</xsl:text>
			
			<!-- Close parenthesis on Convert function call -->
			<xsl:if test="data_type_clr != 'String'">
				<xsl:text>)</xsl:text>
			</xsl:if>
			
			<xsl:text>;</xsl:text>
			
			<xsl:if test="is_nullable = 'true' and is_key = 'false'"> 
				
			<xsl:text>
			}
			</xsl:text>
			
			</xsl:if>


					</xsl:when>
								
					<!-- 
					// Get Checkbox Checked value
					-->
					<xsl:when test="data_type_clr = 'Boolean'">
						
						<xsl:value-of select="parent::*/table_name_safe"/>
						<xsl:text>RowCurrent.</xsl:text>
						<xsl:value-of select="column_name_safe"/>
						<xsl:text> = ctl</xsl:text>
						<xsl:value-of select="column_name_safe"/>
						<xsl:text>.Checked;</xsl:text>
					
					</xsl:when>
					
					<!-- 
					// Get Textbox or Label Control Text value
					-->		
					<xsl:otherwise>
					
						<xsl:if test="is_nullable = 'true' and is_key = 'false'">
			<xsl:text>if (ctl</xsl:text>
				<xsl:value-of select="column_name_safe"/>
				<xsl:text>.Text.Length == 0)
			{
				</xsl:text><xsl:value-of select="parent::*/table_name_safe"/>
				<xsl:text>RowCurrent.Set</xsl:text>
			<xsl:value-of select="column_name_safe"/>
			<xsl:text>Null();
			}
			else
			{
				</xsl:text>
						</xsl:if>
							
						<!-- 
						// Set the field property
						-->
						<xsl:value-of select="parent::*/table_name_safe"/>
						<xsl:text>RowCurrent.</xsl:text>
						<xsl:value-of select="column_name_safe"/>
						<xsl:text> = </xsl:text>
						
						<xsl:choose>
							<!-- 
							// Use GuidConverter to get Guid value from a string
							-->
							<xsl:when test="data_type_clr = 'Guid'">
								<xsl:text>(Guid)(new GuidConverter().ConvertFromString(</xsl:text>
							</xsl:when>
							
							<!--
							// Convert form control if not string
							-->
							<xsl:when test="data_type_clr != 'String'">
								<xsl:text>Convert.To</xsl:text>
								<xsl:value-of select="data_type_clr"/>
								<xsl:text>(</xsl:text>
							</xsl:when>
						
						</xsl:choose>
						
						<xsl:text>ctl</xsl:text>
						<xsl:value-of select="column_name_safe"/>
						<xsl:text>.Text</xsl:text>
						
						<!-- Close Convert function call -->
						<xsl:choose>
							<xsl:when test="data_type_clr = 'Guid'">
								<xsl:text>))</xsl:text>
							</xsl:when>
							
							<xsl:when test="data_type_clr != 'String'">
								<xsl:text>)</xsl:text>
							</xsl:when>
						
						</xsl:choose>
						
						<xsl:text>;</xsl:text>
						
						<xsl:if test="is_nullable = 'true' and is_key = 'false'">
							<xsl:text>
			}
						</xsl:text>
						
						</xsl:if>

					</xsl:otherwise>
				
				</xsl:choose>
			
			</xsl:for-each>
			
			<xsl:text>
			
			if (DataEntryMode == PageDataEntryMode.AddRow)
			{
				//
				// Add the new Row to the DataSet
				//
				</xsl:text>
				<xsl:value-of select="table_name_safe"/><xsl:text>DS.</xsl:text>
				<xsl:value-of select="table_name_safe"/><xsl:text>.Rows.Add(</xsl:text>
				<xsl:value-of select="table_name_safe"/><xsl:text>RowCurrent);
			}

			//
			// Save the changes to the database
			//
			</xsl:text>
			<xsl:value-of select="table_name_safe"/><xsl:text>Logic.UpdateDataSet(</xsl:text>
			<xsl:value-of select="table_name_safe"/><xsl:text>DS);
			
			//
			// Update the primary key values
			//
			</xsl:text>
			<xsl:for-each select="Column[is_key = 'true']">
			
				<xsl:text>m_</xsl:text>
				<xsl:value-of select="column_name_safe"/>
				<xsl:text>Current = </xsl:text>
				<xsl:value-of select="parent::*/table_name_safe"/>
				
				<xsl:text>RowCurrent.</xsl:text>
				<xsl:value-of select="column_name_safe"/>
				<xsl:text>;
			</xsl:text>
		
			</xsl:for-each>
			<xsl:text>
			
			return true;
		}
</xsl:text>

</xsl:template>



</xsl:stylesheet>
