<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet 
	version="1.0" 
	xmlns:xsl="http://www.w3.org/1999/XSL/Transform" 
	xmlns:asp="urn:microsoft:aspx"
	>

	
<xsl:import 
	href="WebUICommon.xsl" 
	/>
	
<xsl:output 
	method="xml" 
	indent="yes" 
	omit-xml-declaration="yes"
	/>


	
<!-- 
//
// NextGeneration Template
// 
// Template Set:	Web User Interface
// Language:		.NET C#
// Template:		View and Edit a Row in the Database
//
// Copyright (c) Ross Donald 2003-2004
// http://www.radsoftware.com.au
//
-->

<!-- FileName = "{0}.aspx"	-->
<!-- Folder   = "WebUI"		-->

<xsl:param name="ObjectName" select="'Employees'"/>
<xsl:param name="Namespace" select="'NextGeneration'"/>
<xsl:param name="RowCreatedColumnName"  select="'CreateDate'" />
<xsl:param name="RowModifiedColumnName" select="'LastModifyDate'" />

<!--
//
// Main Template
//
-->
<xsl:template match="/">

	<!-- 
	// Create the table of controls to edit the table
	-->
	<xsl:apply-templates select="/db/Table[table_name_safe = $ObjectName]"/>
	
</xsl:template>



<!--
//
// Create an ASPX Editing and viewing page for a Table
//
-->
<xsl:template match="Table">

<xsl:text disable-output-escaping="yes">
&lt;%@ Register TagPrefix=&quot;uc1&quot; TagName=&quot;Header&quot; Src=&quot;Components/Header.ascx&quot; %&gt;
&lt;%@ Register TagPrefix=&quot;uc1&quot; TagName=&quot;Footer&quot; Src=&quot;Components/Footer.ascx&quot; %&gt;
&lt;%@ Page Language="C#" codebehind="</xsl:text>
<xsl:value-of select="table_name_safe"/>
<xsl:text disable-output-escaping="yes">.aspx.cs" autoeventwireup="false" Inherits="</xsl:text>
<xsl:value-of select="$Namespace"/>
<xsl:text>.WebUI.</xsl:text>
<xsl:value-of select="table_name_safe"/>
<xsl:text disable-output-escaping="yes">" Trace="False" %&gt;
&lt;!DOCTYPE HTML PUBLIC "-//W3C//DTD HTML 4.0 Transitional//EN" &gt;
</xsl:text>

<html>
	<head>
		<title><xsl:text disable-output-escaping="yes">&lt;%=PageTitle%&gt;</xsl:text></title>
		<link href="Default.css" type="text/css" rel="stylesheet"/>
		<meta content="C#" name="CODE_LANGUAGE"/>
		<meta content="JavaScript" name="vs_defaultClientScript"/>
		<meta content="http://schemas.microsoft.com/intellisense/ie5" name="vs_targetSchema"/>
		<meta http-equiv="Content-Type" content="text/html; charset=utf-8"/>
		<xsl:comment> Generated by Rad Software NextGeneration - http://www.radsoftware.com.au/ </xsl:comment>
	</head>
	<body>
		<form id="Form1" method="post" enctype="application/x-www-form-urlencoded" runat="server">
			<xsl:text disable-output-escaping="yes">&lt;uc1:Header id=&quot;Header1&quot; runat=&quot;server&quot;&gt;&lt;/uc1:Header&gt;</xsl:text>
			<p>
				<asp:label id="lblMessage" CssClass="DataEntryFormMessage" Runat="server"></asp:label>
			</p>
			<br/>
			<p>
			<!-- Validation Summary -->
				<asp:validationsummary 
					id="ctlValidationSummary" 
					runat="server"
					cssclass="MsgValSummary"
					forecolor=" "
					/>
			</p>
			<table id="tableView" class="DataEntryForm" cellSpacing="0" cellPadding="1" border="0">
				<tr class="DataEntryTitle">
					<!-- first column is just for padding -->
					<th nowrap="nowrap"><xsl:text disable-output-escaping="yes">&amp;nbsp;</xsl:text></th>
					<th colspan="4">
						<xsl:value-of select="table_name_friendly"/>
					</th>
					
				</tr>
				
				<!-- Generate one row for each Column -->
				<xsl:for-each select="Column[data_type_native != 'timestamp' and data_type_clr != 'Byte[]']">
					<xsl:sort  select="ordinal_position" data-type="number"/>
					<xsl:apply-templates select="."/>
				</xsl:for-each>
				
				<!--
				// Footer
				-->
				<tr class="DataEntryFooter">
					<td><xsl:text disable-output-escaping="yes">&amp;nbsp;</xsl:text></td>
					<td><xsl:text disable-output-escaping="yes">&amp;nbsp;</xsl:text></td>
					<td><xsl:text disable-output-escaping="yes">&amp;nbsp;</xsl:text></td>
					<td nowrap="nowrap" valign="top">
					
					<asp:button id="btnOK" runat="server" cssclass="Button" Text="OK"></asp:button>
						<xsl:text disable-output-escaping="yes">&amp;nbsp;</xsl:text>
					
					<asp:button id="btnCancel" runat="server" cssclass="Button" Text="Cancel" CausesValidation="False"></asp:button>
						<xsl:text disable-output-escaping="yes">&amp;nbsp;</xsl:text>
						
					<asp:button id="btnApply" runat="server" cssclass="Button" Text="Apply"></asp:button>
						<xsl:text disable-output-escaping="yes">&amp;nbsp;</xsl:text>	
						
					</td>
					<!-- padding cell -->
					<td><xsl:text disable-output-escaping="yes">&amp;nbsp;</xsl:text></td>
					
				</tr>
			</table>
			<xsl:text disable-output-escaping="yes">&lt;uc1:Footer id=&quot;Footer1&quot; runat=&quot;server&quot;&gt;&lt;/uc1:Footer&gt;</xsl:text>
		</form>
	</body>
</html>

</xsl:template>


<!--
//
// Create a form control for a Table column
//
-->
<xsl:template match="Column">
	
		<tr>
			<!-- padding cell -->
			<td><xsl:text disable-output-escaping="yes">&amp;nbsp;</xsl:text></td>
			<!-- 
			// Column Label 
			-->
			<td valign="top" nowrap="nowrap">
				<span class="FieldCaption">
					<xsl:value-of select="column_name_friendly"/>
				</span>
			</td>
			
			<!-- 
			// Required Field Marker 
			-->
			<td valign="top" nowrap="nowrap">
				<xsl:if test="is_nullable = 'false' and column_name != $RowCreatedColumnName and column_name != $RowModifiedColumnName">
					<span 
						class="RequiredFieldMark"
						title="{column_name_friendly} must be entered"
						>*</span>
				</xsl:if>
			</td>
			
			<!-- 
			// Data entry control
			-->
			<td nowrap="nowrap">
			
			<!-- Retuns the ASP.NET Web Control class e.g. TextBox -->
			<xsl:variable name="ControlType">
				<xsl:apply-templates select="." mode="GetControlType"/>
			</xsl:variable>
			
			<xsl:choose>
			
				<!--
				// Create as a Drop Down List
				-->
				<xsl:when test="$ControlType = 'DropDownList'">
					<xsl:apply-templates select="." mode="DropDownList"/>
				</xsl:when>
			
				<!-- 
				// Create as Read only Label
				-->
				<xsl:when test="$ControlType = 'Label'">
					<xsl:apply-templates select="." mode="Label"/>
				</xsl:when>
				
				<!-- 
				// Create as Checkbox
				-->
				<xsl:when test="$ControlType = 'CheckBox'">
					<xsl:apply-templates select="." mode="CheckBox"/>
				</xsl:when>
							
				<!-- 
				// Create as Textbox Control
				-->		
				<xsl:otherwise>
					<xsl:apply-templates select="." mode="TextBox"/>
				</xsl:otherwise>
				
			</xsl:choose>
			
			</td>
				
			<!-- padding cell -->
			<td><xsl:text disable-output-escaping="yes">&amp;nbsp;</xsl:text></td>			
	</tr>
</xsl:template>

<!--
//
// Create a TextBox Control for the current column
//
-->
<xsl:template match="Column" mode="TextBox">

	<!-- 
	// TextBox Control
	-->
	<xsl:element name="asp:TextBox">
	<xsl:attribute name="id">ctl<xsl:value-of select="column_name_safe"/></xsl:attribute>
	<xsl:attribute name="runat">server</xsl:attribute>
	<xsl:attribute name="cssclass">DataEntry</xsl:attribute>
	<xsl:attribute name="tabIndex"><xsl:value-of select="ordinal_position"/></xsl:attribute>
	
	<xsl:if test="column_name = $RowCreatedColumnName or column_name = $RowModifiedColumnName">
		<xsl:attribute name="Enabled">False</xsl:attribute>
	</xsl:if>

	<xsl:if test="number(character_maximum_length) &gt; 0">
		<xsl:choose>
		
			<!-- Make a Text Area - Multiline Text box -->	
			<xsl:when test="character_maximum_length &gt; 100">
				<!-- 100 characters wide is the max for any control -->
				<xsl:attribute name="Columns">100</xsl:attribute>
				<xsl:attribute name="textmode">MultiLine</xsl:attribute>
				
				<xsl:choose>
					<xsl:when test="character_maximum_length &gt; 300">
						<!-- absolute maximum of 4 rows -->
						<xsl:attribute name="Rows">4</xsl:attribute>
					</xsl:when>
					
					<xsl:otherwise>
						<!-- work out the number of rows -->
						<xsl:attribute name="Rows"><xsl:value-of select="format-number(character_maximum_length div 100, '#')"/></xsl:attribute>
					</xsl:otherwise>
		
				</xsl:choose>
				
			</xsl:when>
		
			<!-- set maximum number of characters for TextBox controls -->	
			<xsl:when test="character_maximum_length &lt; 101">
				<xsl:attribute name="Columns"><xsl:value-of select="character_maximum_length"/></xsl:attribute>
				<xsl:attribute name="MaxLength"><xsl:value-of select="character_maximum_length"/></xsl:attribute>
			</xsl:when>
					
		</xsl:choose>
	</xsl:if>
	
	<xsl:if test="character_maximum_length = '-1'">
	
		<xsl:choose>
		
			<xsl:when test="data_type_clr = 'DateTime'">
				<xsl:attribute name="Columns">25</xsl:attribute>
			</xsl:when>
		
		</xsl:choose>
	
	</xsl:if>
	
	<!-- end asp:TextBox -->
	</xsl:element>

	<br/>

	<!-- 
	// Create a Validator control
	-->	
	<xsl:if test="is_nullable = 'false' and is_auto_increment = 'false' and column_name != $RowCreatedColumnName and column_name != $RowModifiedColumnName">
		<!-- 
		// Required Field Validator
		-->
		
		<asp:requiredfieldvalidator 
					id="ctl{column_name_safe}ValRequired" 
					runat="server" 
					ErrorMessage="{column_name_friendly} must be entered" 
					ControlToValidate="ctl{column_name_safe}"
					display="Dynamic"
					forecolor=" "
					cssclass="MsgVal">
		</asp:requiredfieldvalidator>
	</xsl:if>	
	
	<!--
	// Data Type validator
	-->
	<xsl:choose>
		
		<xsl:when test="data_type_clr = 'Double'">
			<asp:comparevalidator 
				id="ctl{column_name_safe}DataTypeDouble" 
				runat="server" 
				ControlToValidate="ctl{column_name_safe}" 
				ErrorMessage="{column_name_friendly} must be a number between -1.79769313486232e308 and 1.79769313486232e308" 
				CssClass="MsgVal" 
				Operator="DataTypeCheck" 
				Display="Dynamic" 
				ForeColor=" " 
				Type="Double">
			</asp:comparevalidator>
		</xsl:when>
		
		<!--
		// Currency Validator
		-->		
		<xsl:when test="data_type_native = 'money' or data_type_native = 'smallmoney' or data_type_native = 'Currency'">
			<asp:comparevalidator 
				id="ctl{column_name_safe}DataTypeCurrency" 
				runat="server" 
				ControlToValidate="ctl{column_name_safe}" 
				ErrorMessage="{column_name_friendly} must be a money amount to two decimal places without the dollar sign" 
				CssClass="MsgVal" 
				Operator="DataTypeCheck" 
				Display="Dynamic" 
				ForeColor=" " 
				Type="Currency"
				>
			</asp:comparevalidator>
		</xsl:when>
		
		<!--
		// BigInt Validator
		-->
		<!--
		doesnt work
		<xsl:when test="data_type_native = 'bigint' or data_type_clr = 'Int64'">
			<asp:rangevalidator 
				id="ctl{column_name_safe}ValInt64" 
				runat="server" 
				ControlToValidate="ctl{column_name_safe}" 
				ErrorMessage="{column_name_friendly} must a whole number between -9,223,372,036,854,775,808 and 9,223,372,036,854,775,807" 
				CssClass="MsgVal" 
				ForeColor=" " 
				type="Integer"
				MinimumValue="-9,223,372,036,854,775,808" 
				MaximumValue="9,223,372,036,854,775,807"
				Display="Dynamic" 
				>
			</asp:rangevalidator>			
		</xsl:when>
-->

		<!--
		// Integer Validator
		-->
		<xsl:when test="data_type_clr = 'Int32'">
			<asp:rangevalidator 
				id="ctl{column_name_safe}ValInt32" 
				runat="server" 
				ControlToValidate="ctl{column_name_safe}" 
				ErrorMessage="{column_name_friendly} must be a whole number between -2147483648 and 2147483647" 
				CssClass="MsgVal" 
				ForeColor=" " 
				type="Integer"
				MinimumValue="-2147483648" 
				MaximumValue="2147483647"
				Display="Dynamic" 
				>
			</asp:rangevalidator>			
		</xsl:when>
		
		<!--
		// SmallInt Validator
		-->
		<xsl:when test="data_type_native = 'smallint' or data_type_clr = 'Int16'">
			<asp:rangevalidator 
				id="ctl{column_name_safe}ValInt16" 
				runat="server" 
				ControlToValidate="ctl{column_name_safe}" 
				ErrorMessage="{column_name_friendly} must a whole number between -32768 and 32767" 
				CssClass="MsgVal" 
				ForeColor=" " 
				type="Integer"
				MinimumValue="-32768" 
				MaximumValue="32767"
				Display="Dynamic" 
				>
			</asp:rangevalidator>			
		</xsl:when>
		
		<!--
		// TinyInt / Byte Validator
		-->
		<xsl:when test="data_type_native = 'tinyint' or data_type_clr = 'Byte'">
			<asp:rangevalidator 
				id="ctl{column_name_safe}ValByte" 
				runat="server" 
				ControlToValidate="ctl{column_name_safe}" 
				ErrorMessage="{column_name_friendly} must a whole number between 0 and 255" 
				CssClass="MsgVal" 
				ForeColor=" " 
				type="Integer"
				MinimumValue="0" 
				MaximumValue="255"
				Display="Dynamic" 
				>
			</asp:rangevalidator>			
		</xsl:when>
				
	</xsl:choose>

</xsl:template>


<!--
//
// Create a CheckBox Control for the current column
//
-->
<xsl:template match="Column" mode="CheckBox">

	<xsl:element name="asp:CheckBox">
		<xsl:attribute name="id">ctl<xsl:value-of select="column_name_safe"/></xsl:attribute>
		<xsl:attribute name="runat">server</xsl:attribute>
		<xsl:attribute name="CssClass">DataEntry</xsl:attribute>
		<xsl:attribute name="tabIndex"><xsl:value-of select="ordinal_position"/></xsl:attribute>
		
		<xsl:if test="string(number(column_default)) != 'NaN'">
			<xsl:if test="column_default != '0'">
				<xsl:attribute name="Checked">True</xsl:attribute>
			</xsl:if>
		</xsl:if>
		
	</xsl:element>

</xsl:template>


<!--
//
// Create a Label Control for the current column
//
-->
<xsl:template match="Column" mode="Label">

	<asp:Label 
		id="ctl{column_name_safe}" 
		runat="server" 
		CssClass="DataEntry"
		tabIndex="{ordinal_position}" 
		>
	</asp:Label>

</xsl:template>


<!--
//
// Create a DropDownList Control for the current column
//
-->
<xsl:template match="Column" mode="DropDownList">

	<asp:DropDownList 
		id="ctl{column_name_safe}" 
		tabIndex="{ordinal_position}" 
		runat="server" 
		CssClass="DataEntry">
		<!-- add a 'null' entry to every text box -->
		<asp:listitem Value="(null)">(none)</asp:listitem>
	</asp:DropDownList>
	
	<!--
	// Create a validator to ensure that an item is selected from the 
	// DropDownlist
	-->
	<xsl:if test="is_nullable = 'false' and is_auto_increment = 'false'">
		<br/>
		<asp:comparevalidator 
			id="ctl{column_name_safe}ValNotNull" 
			runat="server" 
			ControlToValidate="ctl{column_name_safe}" 
			ErrorMessage="{column_name_friendly} must be entered" 
			CssClass="MsgVal" 
			ForeColor=" " 
			Display="Dynamic" 
			ValueToCompare="(null)" 
			Operator="NotEqual">
		</asp:comparevalidator>
			<!-- <xsl:value-of select="column_name_friendly"/> must be entered -->
	</xsl:if>

</xsl:template>


</xsl:stylesheet>
