<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet 
	version="1.0" 
	xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
	>
	
<xsl:import 
	href="WebUICommon.xsl" 
	/>
	
<xsl:output 
	method="text" 
	indent="no" 
	omit-xml-declaration="yes"
	/>


	
<!-- 
//
// NextGeneration Template
// 
// Template Set:	Web User Interface
// Language:		.NET C#
// Template:		Code behind for the search page
//
// Copyright (c) Ross Donald 2003-2004
// http://www.radsoftware.com.au
//
-->

<!-- FileName = "{0}_Search.aspx.cs" -->
<!-- Folder   = "WebUI"		-->

<xsl:param name="ObjectName" select="'EmployeeTerritories'"/>
<xsl:param name="Namespace" select="'NextGeneration'"/>

<!--
//
// Main Template
//
-->
<xsl:template match="/">

	<!-- 
	// Create the table of controls to edit the table
	-->
	<xsl:apply-templates select="/db/Table[table_name_safe = $ObjectName]"/>
	
</xsl:template>


<!--
//
// Create an ASPX Editing and viewing page for a Table
//
-->
<xsl:template match="Table">
<xsl:text>
using System;
using System.Collections;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Web;
using System.Web.SessionState;
using System.Web.UI;
using System.Web.UI.WebControls;
using System.Web.UI.HtmlControls;

using RAD.AppFramework.QueryObjects;

using </xsl:text><xsl:value-of select="$Namespace"/><xsl:text>.BusinessServiceInterfaces;
using </xsl:text><xsl:value-of select="$Namespace"/><xsl:text>.Data;
using </xsl:text><xsl:value-of select="$Namespace"/><xsl:text>.DataRetrieval;
using </xsl:text><xsl:value-of select="$Namespace"/><xsl:text>.Common;
using </xsl:text><xsl:value-of select="$Namespace"/><xsl:text>.DatabaseSchema;

namespace </xsl:text><xsl:value-of select="$Namespace"/><xsl:text>.WebUI
{
	/// &lt;summary&gt;
	/// Searches the </xsl:text><xsl:value-of select="table_name"/><xsl:text> table
	/// &lt;/summary&gt;
	public class </xsl:text><xsl:value-of select="table_name_safe"/><xsl:text>_Search : SearchPage
	{
		#region Constants



		#endregion


		#region Fields

		

		#endregion


		#region Page Events


		/// &lt;summary&gt;
		/// Event raised when the page is requested
		/// &lt;/summary&gt;
		private void Page_Load(object sender, System.EventArgs e)
		{
			// AllowSearchAll = true;

			int CriteriaCount = 0;

			//
			// Load the search criteria from the query string into the controls
			//
			</xsl:text>
			<xsl:for-each select="Column[data_type_native != 'timestamp' and data_type_clr != 'Byte[]']">
			
				<xsl:variable  name="search_type">
					<xsl:apply-templates select="." mode="SearchType"/>
				</xsl:variable>
				
				<xsl:choose>
					<!-- Boolean search field -->
					<xsl:when test="string($search_type) = 'Boolean'">
						<xsl:text>CriteriaCount += LoadSearchBoolean("</xsl:text>
						<xsl:value-of select="column_name_safe"/>
						<xsl:text>", </xsl:text>
						<xsl:value-of select="column_name_safe"/>
						<xsl:text>);</xsl:text>
					</xsl:when>
					
					<!-- column ends in 'ID' or String search field -->
					<xsl:when test="string($search_type) = 'ID' or string($search_type) = 'String'">
						<xsl:text>CriteriaCount += LoadSearchString("</xsl:text>
						<xsl:value-of select="column_name_safe"/>
						<xsl:text>", </xsl:text>
						<xsl:value-of select="column_name_safe"/>
						<xsl:text>);</xsl:text>					
					</xsl:when>

					<!-- Numeric/date search field -->
					<xsl:when test="string($search_type) = 'Between' or string($search_type) = 'DateTime'">
						<xsl:text>CriteriaCount += LoadSearchBetween("</xsl:text>
						<xsl:value-of select="column_name_safe"/>
						<xsl:text>", </xsl:text>
						<xsl:value-of select="column_name_safe"/><xsl:text>Begin, </xsl:text>
						<xsl:value-of select="column_name_safe"/><xsl:text>End);</xsl:text>
					</xsl:when>
					
					<!-- Don't search on Byte[] or Object columns -->
				</xsl:choose>
				
				<!-- new line -->
				<xsl:text>
			</xsl:text>
			
			</xsl:for-each>
			<xsl:text>

			if (IsPostBack)
			{
			}
			else
			{
				PageTitle = "</xsl:text><xsl:value-of select="table_name"/><xsl:text> Search";

				if (CriteriaCount &gt; 0)
				{
					</xsl:text><xsl:value-of select="table_name_safe"/><xsl:text>Grid.CurrentPageIndex = FirstPage;
					LoadData();
				}
			}
		}

		#endregion


		#region Event Handlers for Controls

		/// &lt;summary&gt;
		/// Event raised when a button is pressed on the grid
		/// &lt;/summary&gt;
		private void </xsl:text><xsl:value-of select="table_name_safe"/><xsl:text>Grid_ItemCommand(object source, DataGridCommandEventArgs e)
		{
			switch (e.CommandName)
			{
				case "Edit":
					</xsl:text>
					
					<xsl:choose>
						<!-- 
						// Table does not have a primary key - what to do? 
						-->
						<xsl:when test="count(Column[is_key = 'true']) = 0">
							<xsl:text>// Table does not have a primary key</xsl:text>
						</xsl:when>
						
						<!-- 
						// Single column in the primary key 
						-->
						<xsl:when test="count(Column[is_key = 'true']) = 1">
							<xsl:text>Response.Redirect(
						string.Format("</xsl:text>
							<xsl:value-of select="table_name_safe"/>
							<xsl:text>.aspx?{0}={1}", "</xsl:text>
							<xsl:value-of select="Column[is_key='true'][1]/column_name_safe"/>
							<xsl:text>", </xsl:text>
							<xsl:value-of select="table_name_safe"/>
							<xsl:text>Grid.DataKeys[e.Item.ItemIndex].ToString())
						);</xsl:text>
						
						</xsl:when>
						
						<!-- 
						// Multiple columns in the primary key 
						-->
						<xsl:otherwise>
							<xsl:text>Response.Redirect(string.Format(
						"</xsl:text>
							<xsl:value-of select="table_name_safe"/>
							<xsl:text>.aspx?</xsl:text>
							
							<!-- build a format string for string.format like "{0}={1}&{2}={3}"	-->
							<xsl:apply-templates select="." mode="StringFormatArgList">
								<xsl:with-param name="seperatorChar" select="'='"/>
								<xsl:with-param name="joinChar" select="'&amp;'"/>
							</xsl:apply-templates>
							
							<xsl:text>", 
						</xsl:text>
							
							<xsl:for-each select="Column[is_key = 'true']">
								<xsl:if test="position() &gt; 1">
									<xsl:text>, 
						</xsl:text>
								</xsl:if>
							
								<xsl:text>"</xsl:text>			
								<xsl:value-of select="column_name_safe"/>
								<xsl:text>", e.Item.Cells[</xsl:text>
								<xsl:value-of select="position()"/>
								<xsl:text>].Text</xsl:text>
							</xsl:for-each>
					
							<xsl:text>)
						);</xsl:text>

						</xsl:otherwise>
					
					</xsl:choose>
					
					<xsl:text>	
					break;
			}
		}

		/// &lt;summary&gt;
		/// Event raised when the next or previous links are clicked on the grid
		/// &lt;/summary&gt;
		private void </xsl:text><xsl:value-of select="table_name_safe"/><xsl:text>Grid_PageIndexChanged(object source, DataGridPageChangedEventArgs e)
		{
			</xsl:text><xsl:value-of select="table_name_safe"/><xsl:text>Grid.CurrentPageIndex = e.NewPageIndex;

			LoadData();
		}

		/// &lt;summary&gt;
		/// Event raised when a column heading is clicked and sorting is enabled
		/// &lt;/summary&gt;
		private void </xsl:text><xsl:value-of select="table_name_safe"/><xsl:text>Grid_SortCommand(object source, DataGridSortCommandEventArgs e)
		{
			RedirectWithSortExpression(e.SortExpression);
		}

		
		#endregion


		#region Methods - Private

		/// &lt;summary&gt;
		/// Searches the </xsl:text><xsl:value-of select="table_name"/><xsl:text> table for rows that match 
		/// the criteria entered in the search form
		/// &lt;/summary&gt;
		private void LoadData()
		{
			Query m_</xsl:text><xsl:value-of select="table_name_safe"/><xsl:text>Query = CommonFactory.CreateQuery();

			</xsl:text>
			<xsl:for-each select="Column[data_type_native != 'timestamp' and data_type_clr != 'Byte[]']">
			
				<xsl:variable  name="search_type">
					<xsl:apply-templates select="." mode="SearchType"/>
				</xsl:variable>
				
				<xsl:choose>
					<!-- Boolean search field -->
					<xsl:when test="string($search_type) = 'Boolean'">
						<xsl:text>AddToQuery(m_</xsl:text>
						<xsl:value-of select="../table_name_safe"/>
						<xsl:text>Query, </xsl:text>
						<xsl:value-of select="../table_name_safe"/>
						<xsl:text>Table.</xsl:text>
						<xsl:value-of select="column_name_safe"/>
						<xsl:text>, Comparison.EqualTo, </xsl:text>
						<xsl:value-of select="column_name_safe"/>
						<xsl:text>);</xsl:text>
					</xsl:when>
					
					<!-- column ends in 'ID' -->
					<xsl:when test="string($search_type) = 'ID'">
						<xsl:text>AddToQuery(m_</xsl:text>
						<xsl:value-of select="../table_name_safe"/>
						<xsl:text>Query, </xsl:text>
						<xsl:value-of select="../table_name_safe"/>
						<xsl:text>Table.</xsl:text>
						<xsl:value-of select="column_name_safe"/>
						<xsl:text>, Comparison.EqualTo, </xsl:text>
						<xsl:value-of select="column_name_safe"/>
						<xsl:text>);</xsl:text>
					</xsl:when>
					
					<!-- String search field -->
					<xsl:when test="string($search_type) = 'String'">
						<xsl:text>AddToQuery(m_</xsl:text>
						<xsl:value-of select="../table_name_safe"/>
						<xsl:text>Query, </xsl:text>
						<xsl:value-of select="../table_name_safe"/>
						<xsl:text>Table.</xsl:text>
						<xsl:value-of select="column_name_safe"/>
						<xsl:text>, Comparison.Contains, </xsl:text>
						<xsl:value-of select="column_name_safe"/>
						<xsl:text>);</xsl:text>
					</xsl:when>

					<!-- Numeric/date search field -->
					<xsl:when test="string($search_type) = 'Between' or string($search_type) = 'DateTime'">
						<xsl:text>AddToQuery(m_</xsl:text>
						<xsl:value-of select="../table_name_safe"/>
						<xsl:text>Query, </xsl:text>
						<xsl:value-of select="../table_name_safe"/>
						<xsl:text>Table.</xsl:text>
						<xsl:value-of select="column_name_safe"/>
						<xsl:text>, </xsl:text>
						<xsl:value-of select="column_name_safe"/><xsl:text>Begin, </xsl:text>
						<xsl:value-of select="column_name_safe"/><xsl:text>End);</xsl:text>
					</xsl:when>
					
				</xsl:choose>
				
				<!-- new line -->
				<xsl:text>
			</xsl:text>
			
			</xsl:for-each>
			<xsl:text>

			AddSortToQuery(m_</xsl:text>
			<xsl:value-of select="table_name_safe"/>
			<xsl:text>Query, typeof(</xsl:text>
			<xsl:value-of select="table_name_safe"/>
			<xsl:text>Table));
			
			I</xsl:text><xsl:value-of select="table_name_safe"/><xsl:text>Service </xsl:text>
			<xsl:value-of select="table_name_safe"/><xsl:text>Logic = DataRetrievalFactory.GetDataRetrievalFactory().Create</xsl:text>
			<xsl:value-of select="table_name_safe"/><xsl:text>Service();
			int ResultCount = </xsl:text>
			<xsl:value-of select="table_name_safe"/>
			<xsl:text>Logic.GetByQuery(m_</xsl:text>
			<xsl:value-of select="table_name_safe"/>
			<xsl:text>DataSet, m_</xsl:text>
			<xsl:value-of select="table_name_safe"/>
			<xsl:text>Query);

			if (ResultCount &gt; 0)
			{
				lblMessage.Text = string.Format(MatchesFoundMessage, ResultCount);
				</xsl:text><xsl:value-of select="table_name_safe"/><xsl:text>Grid.DataBind();
			}
			else
			{
				lblMessage.Text = NoMatchesMessage;
			}			
		}


		#endregion


		#region Web Form Designer generated code
		
		protected </xsl:text><xsl:value-of select="$Namespace"/><xsl:text>.Data.</xsl:text><xsl:value-of select="table_name_safe"/><xsl:text>DataSet m_</xsl:text><xsl:value-of select="table_name_safe"/><xsl:text>DataSet;
		protected System.Web.UI.WebControls.Label lblMessage;
		protected System.Web.UI.WebControls.DataGrid </xsl:text><xsl:value-of select="table_name_safe"/><xsl:text>Grid;
		</xsl:text>
		<xsl:for-each select="Column[data_type_native != 'timestamp' and data_type_clr != 'Byte[]']">
			
			<xsl:text>protected System.Web.UI.HtmlControls.</xsl:text>
			
			<xsl:variable  name="search_type">
				<xsl:apply-templates select="." mode="SearchType"/>
			</xsl:variable>
			
			<xsl:choose>
				<!-- Boolean search field -->
				<xsl:when test="string($search_type) = 'Boolean'">
					<xsl:text>HtmlSelect </xsl:text>
					<xsl:value-of select="column_name_safe"/>
					<xsl:text>;</xsl:text>
				</xsl:when>
				
				<!-- column ends in 'ID' or String search field -->
				<xsl:when test="string($search_type) = 'ID' or string($search_type) = 'String'">
					<xsl:text>HtmlInputText </xsl:text>
					<xsl:value-of select="column_name_safe"/>
					<xsl:text>;</xsl:text>
				</xsl:when>

				<!-- Numeric/date search field -->
				<xsl:when test="string($search_type) = 'Between' or string($search_type) = 'DateTime'">
					<xsl:text>HtmlInputText </xsl:text>
					<xsl:value-of select="column_name_safe"/>
					<xsl:text>Begin;
		protected System.Web.UI.HtmlControls.HtmlInputText </xsl:text>
					<xsl:value-of select="column_name_safe"/>
					<xsl:text>End;</xsl:text>
				</xsl:when>
				
			</xsl:choose>
			
			<!-- new line -->
			<xsl:text>
		</xsl:text>
		
		</xsl:for-each>
		<xsl:text>
		
		override protected void OnInit(EventArgs e)
		{
			//
			// CODEGEN: This call is required by the ASP.NET Web Form Designer.
			//
			InitializeComponent();
			base.OnInit(e);
		}
		
		/// &lt;summary&gt;
		/// Required method for Designer support - do not modify
		/// the contents of this method with the code editor.
		/// &lt;/summary&gt;
		private void InitializeComponent()
		{    
			this.m_</xsl:text><xsl:value-of select="table_name_safe"/><xsl:text>DataSet = new </xsl:text><xsl:value-of select="$Namespace"/><xsl:text>.Data.</xsl:text><xsl:value-of select="table_name_safe"/><xsl:text>DataSet();
			((System.ComponentModel.ISupportInitialize)(this.m_</xsl:text><xsl:value-of select="table_name_safe"/><xsl:text>DataSet)).BeginInit();
			this.</xsl:text><xsl:value-of select="table_name_safe"/><xsl:text>Grid.ItemCommand += new System.Web.UI.WebControls.DataGridCommandEventHandler(this.</xsl:text><xsl:value-of select="table_name_safe"/><xsl:text>Grid_ItemCommand);
			this.</xsl:text><xsl:value-of select="table_name_safe"/><xsl:text>Grid.PageIndexChanged += new System.Web.UI.WebControls.DataGridPageChangedEventHandler(this.</xsl:text><xsl:value-of select="table_name_safe"/><xsl:text>Grid_PageIndexChanged);
			this.</xsl:text><xsl:value-of select="table_name_safe"/><xsl:text>Grid.SortCommand += new System.Web.UI.WebControls.DataGridSortCommandEventHandler(this.</xsl:text><xsl:value-of select="table_name_safe"/><xsl:text>Grid_SortCommand);
			// 
			// m_</xsl:text><xsl:value-of select="table_name_safe"/><xsl:text>DataSet
			// 
			this.m_</xsl:text><xsl:value-of select="table_name_safe"/><xsl:text>DataSet.DataSetName = "</xsl:text><xsl:value-of select="table_name_safe"/><xsl:text>DataSet";
			this.m_</xsl:text><xsl:value-of select="table_name_safe"/><xsl:text>DataSet.Locale = new System.Globalization.CultureInfo("en-US");
			this.Load += new System.EventHandler(this.Page_Load);
			((System.ComponentModel.ISupportInitialize)(this.m_</xsl:text><xsl:value-of select="table_name_safe"/><xsl:text>DataSet)).EndInit();

		}
		
		#endregion

	}
}
</xsl:text>
</xsl:template>

</xsl:stylesheet>