<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet 
	version="1.0" 
	xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
	>

<!-- 
//
// NextGeneration Template
// 
// Template Set:	Web User Interface 
// Language:		.NET C#
// Template:		Common Templates
//
// Copyright (c) Ross Donald 2003-2004
// http://www.radsoftware.com.au
//
-->

<!--
//
// Gets the WebControl class name for a column
//
-->
<xsl:template match="Column" mode="GetControlType">

	<xsl:variable name="ColumnCurrentName" select="column_name"/>

	<xsl:choose>
	
		<!--
		// Create as a Drop Down List
		-->
		<xsl:when test="count(parent::*/Foreign_Key_Child/Column[fk_column_name = $ColumnCurrentName]) &gt; 0">
			<xsl:text>DropDownList</xsl:text>
		</xsl:when>
	
		<!-- 
		// Create as Read only Label
		-->
		<xsl:when test="is_auto_increment = 'true' or is_read_only = 'true'">
			<xsl:text>Label</xsl:text>
		</xsl:when>
		
		<!-- 
		// Create as Checkbox
		-->
		<xsl:when test="data_type_clr = 'Boolean'">
			<xsl:text>CheckBox</xsl:text>
		</xsl:when>
					
		<!-- 
		// Create as Textbox Control
		-->		
		<xsl:otherwise>
			<xsl:text>TextBox</xsl:text>
		</xsl:otherwise>
		
	</xsl:choose>

</xsl:template>

<!--
//
// Checks if a column ends with 'ID'
// e.g. EmployeeID
//
-->
<xsl:template match="Column" mode="SearchType">
	
	<xsl:variable  name="id_column">
		<xsl:apply-templates select="." mode="IsIDColumn"/>
	</xsl:variable>
	
	<xsl:choose>
		<!-- Boolean search field -->
		<xsl:when test="data_type_clr = 'Boolean'">
			<xsl:text>Boolean</xsl:text>
		</xsl:when>
		
		<!-- column ends in 'ID' -->
		<xsl:when test="boolean(number($id_column)) or data_type_clr='Guid'">
			<xsl:text>ID</xsl:text>
		</xsl:when>
		
		<!-- String search field -->
		<xsl:when test="data_type_clr='String'">
			<xsl:text>String</xsl:text>
		</xsl:when>

		<!-- date search field -->
		<xsl:when test="data_type_clr='DateTime'">
			<xsl:text>DateTime</xsl:text>
		</xsl:when>
		
		<!-- Numeric search field -->
		<xsl:when test="data_type_clr='Int32' or data_type_clr='Int64' or data_type_clr='Int16' or data_type_clr='Single' or data_type_clr='Decimal' or data_type_clr='Double' or data_type_clr='Byte'">
			<xsl:text>Between</xsl:text>
		</xsl:when>
		
		<!-- Can't search on Byte[] or Object columns -->
	</xsl:choose>
</xsl:template>


<!--
//
// Checks if a column ends with 'ID'
// e.g. EmployeeID
//
-->
<xsl:template match="Column" mode="IsIDColumn">

	<xsl:choose>
		<xsl:when test="translate(substring(column_name_safe, string-length(column_name_safe)-1, 2), 'ID','id') = 'id'">
			<xsl:text>-1</xsl:text>
		</xsl:when>
		
		<xsl:otherwise>
			<xsl:text></xsl:text>		
		</xsl:otherwise>
	</xsl:choose>

</xsl:template>


<!--
//
// Build a format string for string.format
// to lists the primary key variables 
//
// e.g. "{0}={1}&{2}={3}"
// or "{0}:{1} {2}:{3}"
//
-->
<xsl:template match="Table" mode="StringFormatArgList">
	<xsl:param name="seperatorChar" select="'='"/>
	<xsl:param name="joinChar" select="'&amp;'"/>
	
	<xsl:for-each select="Column[is_key = 'true']">

		<xsl:if test="position() != 1">
			<xsl:value-of select="$joinChar"/>
		</xsl:if>
		
		<xsl:text>{</xsl:text>
		<xsl:value-of select="(position() * 2) - 2"/>
		<xsl:text>}</xsl:text>
		<xsl:value-of select="$seperatorChar"/>
		<xsl:text>{</xsl:text>
		<xsl:value-of select="(position() * 2) - 1"/>
		<xsl:text>}</xsl:text>

	</xsl:for-each>
</xsl:template>

</xsl:stylesheet>