using System;
using System.Collections;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Web;
using System.Web.SessionState;
using System.Web.UI;
using System.Web.UI.WebControls;
using System.Web.UI.HtmlControls;

using NorthwindSample.BusinessServiceInterfaces;
using NorthwindSample.Data;
using NorthwindSample.DataRetrieval;

namespace NorthwindSample.WebUI
{
	/// <summary>
	/// Code-behind file for the CustomerCustomerDemo.aspx Page
	/// </summary>
	public class CustomerCustomerDemo : EditablePage
	{
		#region Constants


		#endregion


		#region Fields

		private String m_CustomerIDCurrent;
		private String m_CustomerTypeIDCurrent;
		

		#endregion

				
		#region Page Events

		/// <summary>
		/// Event raised when the page is requested
		/// </summary>
		private void Page_Load(object sender, System.EventArgs e)
		{
			//
			// Find primary key values to use to populate the form
			//
			if (HasQueryStringParameter("CustomerID") && HasQueryStringParameter("CustomerTypeID"))
			{
				m_CustomerIDCurrent = Convert.ToString(Request.QueryString["CustomerID"]);
				m_CustomerTypeIDCurrent = Convert.ToString(Request.QueryString["CustomerTypeID"]);
				
				DataEntryMode = PageDataEntryMode.EditRow;

				PageTitle = string.Format("Customer Customer Demo - Editing {0}: {1}, {2}: {3}", "CustomerID", m_CustomerIDCurrent, "CustomerTypeID", m_CustomerTypeIDCurrent);
			}
			else
			{
				DataEntryMode = PageDataEntryMode.AddRow;

				PageTitle = "Customer Customer Demo - Adding a new entry";
				lblMessage.Text = "Adding a new entry";
			}

			if (Page.IsPostBack)
			{
			
			}
			else
			{
				//
				// Initial Page Request
				//
				PopulateControls();

				if (DataEntryMode == PageDataEntryMode.EditRow || DataEntryMode == PageDataEntryMode.ViewRow)
				{
					if (!LoadData())
					{
						//
						// Could not load the row from the database
						//
						lblMessage.Text = "Error loading CustomerCustomerDemo";

						DataEntryMode = PageDataEntryMode.ErrorOccurred;
						
						DisableDataEntryControls(this.Controls);
					}
				}
			}
		}

		#endregion


		#region Event Handlers for Controls

		/// <summary>
		/// Apply the changes and return to the previous screen
		/// </summary>
		private void btnOK_Click(object sender, System.EventArgs e)
		{
			if (SaveData())
			{
				Response.Redirect(UrlPrevious.ToString());
			}
		}


		/// <summary>
		/// Apply the changes and remain on this page
		/// </summary>
		private void btnApply_Click(object sender, System.EventArgs e)
		{
			if (SaveData())
			{
				//
				// Redirect back to this page in Edit mode
				//
				if (DataEntryMode == PageDataEntryMode.AddRow)
				{	
					UriBuilder EditUri = new UriBuilder(Request.Url);
					EditUri.Query += string.Format("{0}={1}&{2}={3}", "CustomerID", m_CustomerIDCurrent, "CustomerTypeID", m_CustomerTypeIDCurrent);

					//
					// Redirect back to this page 
					// with the primary key information in the query string
					//
					Response.Redirect(EditUri.ToString());
							
				}
				else
				{
					lblMessage.Text = "Customer Customer Demo saved";

					LoadData();
				}
			}
			else
			{
				lblMessage.Text = "Error saving Customer Customer Demo";
				DataEntryMode = PageDataEntryMode.ErrorOccurred;
			}
		}
		
		
		/// <summary>
		/// return to the previous screen
		/// </summary>
		private void btnCancel_Click(object sender, System.EventArgs e)
		{
			Response.Redirect(UrlPrevious.ToString());
		}
		
		#endregion


		#region Private Methods
		
		/// <summary>
		/// Loads data from the database for drop down lists
		/// </summary>
		private void PopulateControls()
		{
			
			//
			// Populate the CustomerID Drop Down List
			//
			CustomersDataSet CustomersDS = new CustomersDataSet();
			ICustomersService CustomersLogic = DataRetrievalFactory.GetDataRetrievalFactory().CreateCustomersService();
			
			if (CustomersLogic.GetAll(CustomersDS) > 0)
			{
				ListItem CustomersListItemNew;
				foreach (CustomersDataSet.CustomersRow CustomersCurrent in CustomersDS.Customers.Rows)
				{
					CustomersListItemNew = new ListItem();
					CustomersListItemNew.Value = CustomersCurrent.CustomerID.ToString();
					CustomersListItemNew.Text = CustomersCurrent.CustomerID.ToString();

					ctlCustomerID.Items.Add(CustomersListItemNew);
				}
			}
			
			//
			// Populate the CustomerTypeID Drop Down List
			//
			CustomerDemographicsDataSet CustomerDemographicsDS = new CustomerDemographicsDataSet();
			ICustomerDemographicsService CustomerDemographicsLogic = DataRetrievalFactory.GetDataRetrievalFactory().CreateCustomerDemographicsService();
			
			if (CustomerDemographicsLogic.GetAll(CustomerDemographicsDS) > 0)
			{
				ListItem CustomerDemographicsListItemNew;
				foreach (CustomerDemographicsDataSet.CustomerDemographicsRow CustomerDemographicsCurrent in CustomerDemographicsDS.CustomerDemographics.Rows)
				{
					CustomerDemographicsListItemNew = new ListItem();
					CustomerDemographicsListItemNew.Value = CustomerDemographicsCurrent.CustomerTypeID.ToString();
					CustomerDemographicsListItemNew.Text = CustomerDemographicsCurrent.CustomerTypeID.ToString();

					ctlCustomerTypeID.Items.Add(CustomerDemographicsListItemNew);
				}
			}
			
		}
		
		/// <summary>
		/// Loads a row from the CustomerCustomerDemo table for viewing or editing
		/// </summary>
		/// <returns>true on success, false on error</returns>
		private bool LoadData()
		{
			if ((DataEntryMode != PageDataEntryMode.EditRow) && (DataEntryMode != PageDataEntryMode.ViewRow))
			{
				return true;
			}
			
			CustomerCustomerDemoDataSet CustomerCustomerDemoDS = new CustomerCustomerDemoDataSet();
			ICustomerCustomerDemoService CustomerCustomerDemoLogic = DataRetrievalFactory.GetDataRetrievalFactory().CreateCustomerCustomerDemoService();
			
			if (CustomerCustomerDemoLogic.GetByCustomerIDAndCustomerTypeID(CustomerCustomerDemoDS, m_CustomerIDCurrent, m_CustomerTypeIDCurrent) == 0)
			{
				//
				// CustomerCustomerDemo Row not found
				//
				return false;
			}

			CustomerCustomerDemoDataSet.CustomerCustomerDemoRow CustomerCustomerDemoRowCurrent = CustomerCustomerDemoDS.CustomerCustomerDemo[0];
			ListItem SelectedListItem;
			
			//
			// Populate the Page controls from the DataRow
			//
			SelectedListItem = ctlCustomerID.Items.FindByValue(CustomerCustomerDemoRowCurrent.CustomerID.ToString());
			if (SelectedListItem != null)
			{
				ctlCustomerID.ClearSelection();
				SelectedListItem.Selected = true;
			}
			SelectedListItem = ctlCustomerTypeID.Items.FindByValue(CustomerCustomerDemoRowCurrent.CustomerTypeID.ToString());
			if (SelectedListItem != null)
			{
				ctlCustomerTypeID.ClearSelection();
				SelectedListItem.Selected = true;
			}
			
			
			return true;
		}
		
		
		/// <summary>
		/// Adds or updates the row in the Database
		/// </summary>
		/// <returns>true on success, false on error</returns>
		private bool SaveData()
		{
			//
			// Check that the Form has passed validation
			//
			Page.Validate();
			
			if (!Page.IsValid)
			{
				// Validation failed
				return false;
			}
			
			CustomerCustomerDemoDataSet CustomerCustomerDemoDS = new CustomerCustomerDemoDataSet();
			ICustomerCustomerDemoService CustomerCustomerDemoLogic = DataRetrievalFactory.GetDataRetrievalFactory().CreateCustomerCustomerDemoService();
			CustomerCustomerDemoDataSet.CustomerCustomerDemoRow CustomerCustomerDemoRowCurrent;
			
			
			switch (DataEntryMode)
			{
				case PageDataEntryMode.AddRow:
					//
					// Create a New Row
					//
					CustomerCustomerDemoRowCurrent = CustomerCustomerDemoDS.CustomerCustomerDemo.NewCustomerCustomerDemoRow();
					break;
					
				case PageDataEntryMode.EditRow:
					//
					// Update existing Row
					//
					if (CustomerCustomerDemoLogic.GetByCustomerIDAndCustomerTypeID(CustomerCustomerDemoDS, m_CustomerIDCurrent, m_CustomerTypeIDCurrent) == 0)
					{
						//
						// CustomerCustomerDemo Row not found
						//
						return false;
					}
					else
					{
						CustomerCustomerDemoRowCurrent = CustomerCustomerDemoDS.CustomerCustomerDemo[0];
					}
					break;
					
				default:
					return false;
			}

			//
			// Set the DataRow values from the Page Controls
			//
			
			// CustomerID
			CustomerCustomerDemoRowCurrent.CustomerID = ctlCustomerID.SelectedItem.Value;
			// CustomerTypeID
			CustomerCustomerDemoRowCurrent.CustomerTypeID = ctlCustomerTypeID.SelectedItem.Value;
			
			if (DataEntryMode == PageDataEntryMode.AddRow)
			{
				//
				// Add the new Row to the DataSet
				//
				CustomerCustomerDemoDS.CustomerCustomerDemo.Rows.Add(CustomerCustomerDemoRowCurrent);
			}

			//
			// Save the changes to the database
			//
			CustomerCustomerDemoLogic.UpdateDataSet(CustomerCustomerDemoDS);
			
			//
			// Update the primary key values
			//
			m_CustomerIDCurrent = CustomerCustomerDemoRowCurrent.CustomerID;
			m_CustomerTypeIDCurrent = CustomerCustomerDemoRowCurrent.CustomerTypeID;
			
			
			return true;
		}
		
		
		#endregion

		
		#region Web Form Designer generated code
		
		protected System.Web.UI.WebControls.Label lblMessage;
		protected System.Web.UI.WebControls.ValidationSummary ctlValidationSummary;
		protected System.Web.UI.WebControls.Button btnOK;
		protected System.Web.UI.WebControls.Button btnApply;
		protected System.Web.UI.WebControls.Button btnCancel;
		protected System.Web.UI.WebControls.DropDownList ctlCustomerID;
		protected System.Web.UI.WebControls.DropDownList ctlCustomerTypeID;
		
		
		override protected void OnInit(EventArgs e)
		{
			//
			// CODEGEN: This call is required by the ASP.NET Web Form Designer.
			//
			InitializeComponent();
			base.OnInit(e);
		}
		
		/// <summary>
		/// Required method for Designer support - do not modify
		/// the contents of this method with the code editor.
		/// </summary>
		private void InitializeComponent()
		{    
			this.btnOK.Click += new System.EventHandler(this.btnOK_Click);
			this.btnApply.Click += new System.EventHandler(this.btnApply_Click);
			this.btnCancel.Click += new System.EventHandler(this.btnCancel_Click);
			this.Load += new System.EventHandler(this.Page_Load);
			
		}
		
		#endregion
	}
}
