using System;
using System.Collections;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Web;
using System.Web.SessionState;
using System.Web.UI;
using System.Web.UI.WebControls;
using System.Web.UI.HtmlControls;

using NorthwindSample.BusinessServiceInterfaces;
using NorthwindSample.Data;
using NorthwindSample.DataRetrieval;

namespace NorthwindSample.WebUI
{
	/// <summary>
	/// Code-behind file for the Employees.aspx Page
	/// </summary>
	public class Employees : EditablePage
	{
		#region Constants


		#endregion


		#region Fields

		private Int32 m_EmployeeIDCurrent;
		

		#endregion

				
		#region Page Events

		/// <summary>
		/// Event raised when the page is requested
		/// </summary>
		private void Page_Load(object sender, System.EventArgs e)
		{
			//
			// Find primary key values to use to populate the form
			//
			if (HasQueryStringParameter("EmployeeID"))
			{
				m_EmployeeIDCurrent = Convert.ToInt32(Request.QueryString["EmployeeID"]);
				
				DataEntryMode = PageDataEntryMode.EditRow;

				PageTitle = string.Format("Employees - Editing {0}: {1}", "EmployeeID", m_EmployeeIDCurrent);
			}
			else
			{
				DataEntryMode = PageDataEntryMode.AddRow;

				PageTitle = "Employees - Adding a new entry";
				lblMessage.Text = "Adding a new entry";
			}

			if (Page.IsPostBack)
			{
			
			}
			else
			{
				//
				// Initial Page Request
				//
				PopulateControls();

				if (DataEntryMode == PageDataEntryMode.EditRow || DataEntryMode == PageDataEntryMode.ViewRow)
				{
					if (!LoadData())
					{
						//
						// Could not load the row from the database
						//
						lblMessage.Text = "Error loading Employees";

						DataEntryMode = PageDataEntryMode.ErrorOccurred;
						
						DisableDataEntryControls(this.Controls);
					}
				}
			}
		}

		#endregion


		#region Event Handlers for Controls

		/// <summary>
		/// Apply the changes and return to the previous screen
		/// </summary>
		private void btnOK_Click(object sender, System.EventArgs e)
		{
			if (SaveData())
			{
				Response.Redirect(UrlPrevious.ToString());
			}
		}


		/// <summary>
		/// Apply the changes and remain on this page
		/// </summary>
		private void btnApply_Click(object sender, System.EventArgs e)
		{
			if (SaveData())
			{
				//
				// Redirect back to this page in Edit mode
				//
				if (DataEntryMode == PageDataEntryMode.AddRow)
				{	
					UriBuilder EditUri = new UriBuilder(Request.Url);
					EditUri.Query += string.Format("{0}={1}", "EmployeeID", m_EmployeeIDCurrent);

					//
					// Redirect back to this page 
					// with the primary key information in the query string
					//
					Response.Redirect(EditUri.ToString());
							
				}
				else
				{
					lblMessage.Text = "Employees saved";

					LoadData();
				}
			}
			else
			{
				lblMessage.Text = "Error saving Employees";
				DataEntryMode = PageDataEntryMode.ErrorOccurred;
			}
		}
		
		
		/// <summary>
		/// return to the previous screen
		/// </summary>
		private void btnCancel_Click(object sender, System.EventArgs e)
		{
			Response.Redirect(UrlPrevious.ToString());
		}
		
		#endregion


		#region Private Methods
		
		/// <summary>
		/// Loads data from the database for drop down lists
		/// </summary>
		private void PopulateControls()
		{
			
			//
			// Populate the ReportsTo Drop Down List
			//
			EmployeesDataSet EmployeesDS = new EmployeesDataSet();
			IEmployeesService EmployeesLogic = DataRetrievalFactory.GetDataRetrievalFactory().CreateEmployeesService();
			
			if (EmployeesLogic.GetAll(EmployeesDS) > 0)
			{
				ListItem EmployeesListItemNew;
				foreach (EmployeesDataSet.EmployeesRow EmployeesCurrent in EmployeesDS.Employees.Rows)
				{
					EmployeesListItemNew = new ListItem();
					EmployeesListItemNew.Value = EmployeesCurrent.EmployeeID.ToString();
					EmployeesListItemNew.Text = EmployeesCurrent.EmployeeID.ToString();

					ctlReportsTo.Items.Add(EmployeesListItemNew);
				}
			}
			
		}
		
		/// <summary>
		/// Loads a row from the Employees table for viewing or editing
		/// </summary>
		/// <returns>true on success, false on error</returns>
		private bool LoadData()
		{
			if ((DataEntryMode != PageDataEntryMode.EditRow) && (DataEntryMode != PageDataEntryMode.ViewRow))
			{
				return true;
			}
			
			EmployeesDataSet EmployeesDS = new EmployeesDataSet();
			IEmployeesService EmployeesLogic = DataRetrievalFactory.GetDataRetrievalFactory().CreateEmployeesService();
			
			if (EmployeesLogic.GetByEmployeeID(EmployeesDS, m_EmployeeIDCurrent) == 0)
			{
				//
				// Employees Row not found
				//
				return false;
			}

			EmployeesDataSet.EmployeesRow EmployeesRowCurrent = EmployeesDS.Employees[0];
			ListItem SelectedListItem;
			
			//
			// Populate the Page controls from the DataRow
			//
			ctlEmployeeID.Text = EmployeesRowCurrent.EmployeeID.ToString();
			ctlLastName.Text = EmployeesRowCurrent.LastName;
			ctlFirstName.Text = EmployeesRowCurrent.FirstName;
			ctlTitle.Text = (EmployeesRowCurrent.IsTitleNull()) ? string.Empty : EmployeesRowCurrent.Title;
			ctlTitleOfCourtesy.Text = (EmployeesRowCurrent.IsTitleOfCourtesyNull()) ? string.Empty : EmployeesRowCurrent.TitleOfCourtesy;
			ctlBirthDate.Text = (EmployeesRowCurrent.IsBirthDateNull()) ? string.Empty : EmployeesRowCurrent.BirthDate.ToString();
			ctlHireDate.Text = (EmployeesRowCurrent.IsHireDateNull()) ? string.Empty : EmployeesRowCurrent.HireDate.ToString();
			ctlAddress.Text = (EmployeesRowCurrent.IsAddressNull()) ? string.Empty : EmployeesRowCurrent.Address;
			ctlCity.Text = (EmployeesRowCurrent.IsCityNull()) ? string.Empty : EmployeesRowCurrent.City;
			ctlRegion.Text = (EmployeesRowCurrent.IsRegionNull()) ? string.Empty : EmployeesRowCurrent.Region;
			ctlPostalCode.Text = (EmployeesRowCurrent.IsPostalCodeNull()) ? string.Empty : EmployeesRowCurrent.PostalCode;
			ctlCountry.Text = (EmployeesRowCurrent.IsCountryNull()) ? string.Empty : EmployeesRowCurrent.Country;
			ctlHomePhone.Text = (EmployeesRowCurrent.IsHomePhoneNull()) ? string.Empty : EmployeesRowCurrent.HomePhone;
			ctlExtension.Text = (EmployeesRowCurrent.IsExtensionNull()) ? string.Empty : EmployeesRowCurrent.Extension;
			ctlNotes.Text = (EmployeesRowCurrent.IsNotesNull()) ? string.Empty : EmployeesRowCurrent.Notes;
			
			if (!EmployeesRowCurrent.IsReportsToNull())
			{
				SelectedListItem = ctlReportsTo.Items.FindByValue(EmployeesRowCurrent.ReportsTo.ToString());
				if (SelectedListItem != null)
				{
					ctlReportsTo.ClearSelection();
					SelectedListItem.Selected = true;
				}
			}
			ctlPhotoPath.Text = (EmployeesRowCurrent.IsPhotoPathNull()) ? string.Empty : EmployeesRowCurrent.PhotoPath;
			
			
			return true;
		}
		
		
		/// <summary>
		/// Adds or updates the row in the Database
		/// </summary>
		/// <returns>true on success, false on error</returns>
		private bool SaveData()
		{
			//
			// Check that the Form has passed validation
			//
			Page.Validate();
			
			if (!Page.IsValid)
			{
				// Validation failed
				return false;
			}
			
			EmployeesDataSet EmployeesDS = new EmployeesDataSet();
			IEmployeesService EmployeesLogic = DataRetrievalFactory.GetDataRetrievalFactory().CreateEmployeesService();
			EmployeesDataSet.EmployeesRow EmployeesRowCurrent;
			
			
			switch (DataEntryMode)
			{
				case PageDataEntryMode.AddRow:
					//
					// Create a New Row
					//
					EmployeesRowCurrent = EmployeesDS.Employees.NewEmployeesRow();
					break;
					
				case PageDataEntryMode.EditRow:
					//
					// Update existing Row
					//
					if (EmployeesLogic.GetByEmployeeID(EmployeesDS, m_EmployeeIDCurrent) == 0)
					{
						//
						// Employees Row not found
						//
						return false;
					}
					else
					{
						EmployeesRowCurrent = EmployeesDS.Employees[0];
					}
					break;
					
				default:
					return false;
			}

			//
			// Set the DataRow values from the Page Controls
			//
			
			// LastName
			EmployeesRowCurrent.LastName = ctlLastName.Text;
			// FirstName
			EmployeesRowCurrent.FirstName = ctlFirstName.Text;
			// Title
			if (ctlTitle.Text.Length == 0)
			{
				EmployeesRowCurrent.SetTitleNull();
			}
			else
			{
				EmployeesRowCurrent.Title = ctlTitle.Text;
			}
						
			// TitleOfCourtesy
			if (ctlTitleOfCourtesy.Text.Length == 0)
			{
				EmployeesRowCurrent.SetTitleOfCourtesyNull();
			}
			else
			{
				EmployeesRowCurrent.TitleOfCourtesy = ctlTitleOfCourtesy.Text;
			}
						
			// BirthDate
			if (ctlBirthDate.Text.Length == 0)
			{
				EmployeesRowCurrent.SetBirthDateNull();
			}
			else
			{
				EmployeesRowCurrent.BirthDate = Convert.ToDateTime(ctlBirthDate.Text);
			}
						
			// HireDate
			if (ctlHireDate.Text.Length == 0)
			{
				EmployeesRowCurrent.SetHireDateNull();
			}
			else
			{
				EmployeesRowCurrent.HireDate = Convert.ToDateTime(ctlHireDate.Text);
			}
						
			// Address
			if (ctlAddress.Text.Length == 0)
			{
				EmployeesRowCurrent.SetAddressNull();
			}
			else
			{
				EmployeesRowCurrent.Address = ctlAddress.Text;
			}
						
			// City
			if (ctlCity.Text.Length == 0)
			{
				EmployeesRowCurrent.SetCityNull();
			}
			else
			{
				EmployeesRowCurrent.City = ctlCity.Text;
			}
						
			// Region
			if (ctlRegion.Text.Length == 0)
			{
				EmployeesRowCurrent.SetRegionNull();
			}
			else
			{
				EmployeesRowCurrent.Region = ctlRegion.Text;
			}
						
			// PostalCode
			if (ctlPostalCode.Text.Length == 0)
			{
				EmployeesRowCurrent.SetPostalCodeNull();
			}
			else
			{
				EmployeesRowCurrent.PostalCode = ctlPostalCode.Text;
			}
						
			// Country
			if (ctlCountry.Text.Length == 0)
			{
				EmployeesRowCurrent.SetCountryNull();
			}
			else
			{
				EmployeesRowCurrent.Country = ctlCountry.Text;
			}
						
			// HomePhone
			if (ctlHomePhone.Text.Length == 0)
			{
				EmployeesRowCurrent.SetHomePhoneNull();
			}
			else
			{
				EmployeesRowCurrent.HomePhone = ctlHomePhone.Text;
			}
						
			// Extension
			if (ctlExtension.Text.Length == 0)
			{
				EmployeesRowCurrent.SetExtensionNull();
			}
			else
			{
				EmployeesRowCurrent.Extension = ctlExtension.Text;
			}
						
			// Notes
			if (ctlNotes.Text.Length == 0)
			{
				EmployeesRowCurrent.SetNotesNull();
			}
			else
			{
				EmployeesRowCurrent.Notes = ctlNotes.Text;
			}
						
			// ReportsTo
			
			
			if (ctlReportsTo.SelectedIndex == 0)
			{
				EmployeesRowCurrent.SetReportsToNull();	
			}
			else
			{
				EmployeesRowCurrent.ReportsTo = Convert.ToInt32(ctlReportsTo.SelectedItem.Value);
			}
			
			// PhotoPath
			if (ctlPhotoPath.Text.Length == 0)
			{
				EmployeesRowCurrent.SetPhotoPathNull();
			}
			else
			{
				EmployeesRowCurrent.PhotoPath = ctlPhotoPath.Text;
			}
						
			
			if (DataEntryMode == PageDataEntryMode.AddRow)
			{
				//
				// Add the new Row to the DataSet
				//
				EmployeesDS.Employees.Rows.Add(EmployeesRowCurrent);
			}

			//
			// Save the changes to the database
			//
			EmployeesLogic.UpdateDataSet(EmployeesDS);
			
			//
			// Update the primary key values
			//
			m_EmployeeIDCurrent = EmployeesRowCurrent.EmployeeID;
			
			
			return true;
		}
		
		
		#endregion

		
		#region Web Form Designer generated code
		
		protected System.Web.UI.WebControls.Label lblMessage;
		protected System.Web.UI.WebControls.ValidationSummary ctlValidationSummary;
		protected System.Web.UI.WebControls.Button btnOK;
		protected System.Web.UI.WebControls.Button btnApply;
		protected System.Web.UI.WebControls.Button btnCancel;
		protected System.Web.UI.WebControls.Label ctlEmployeeID;
		protected System.Web.UI.WebControls.TextBox ctlLastName;
		protected System.Web.UI.WebControls.TextBox ctlFirstName;
		protected System.Web.UI.WebControls.TextBox ctlTitle;
		protected System.Web.UI.WebControls.TextBox ctlTitleOfCourtesy;
		protected System.Web.UI.WebControls.TextBox ctlBirthDate;
		protected System.Web.UI.WebControls.TextBox ctlHireDate;
		protected System.Web.UI.WebControls.TextBox ctlAddress;
		protected System.Web.UI.WebControls.TextBox ctlCity;
		protected System.Web.UI.WebControls.TextBox ctlRegion;
		protected System.Web.UI.WebControls.TextBox ctlPostalCode;
		protected System.Web.UI.WebControls.TextBox ctlCountry;
		protected System.Web.UI.WebControls.TextBox ctlHomePhone;
		protected System.Web.UI.WebControls.TextBox ctlExtension;
		protected System.Web.UI.WebControls.TextBox ctlNotes;
		protected System.Web.UI.WebControls.DropDownList ctlReportsTo;
		protected System.Web.UI.WebControls.TextBox ctlPhotoPath;
		
		
		override protected void OnInit(EventArgs e)
		{
			//
			// CODEGEN: This call is required by the ASP.NET Web Form Designer.
			//
			InitializeComponent();
			base.OnInit(e);
		}
		
		/// <summary>
		/// Required method for Designer support - do not modify
		/// the contents of this method with the code editor.
		/// </summary>
		private void InitializeComponent()
		{    
			this.btnOK.Click += new System.EventHandler(this.btnOK_Click);
			this.btnApply.Click += new System.EventHandler(this.btnApply_Click);
			this.btnCancel.Click += new System.EventHandler(this.btnCancel_Click);
			this.Load += new System.EventHandler(this.Page_Load);
			
		}
		
		#endregion
	}
}
