using System;
using System.Collections;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Web;
using System.Web.SessionState;
using System.Web.UI;
using System.Web.UI.WebControls;
using System.Web.UI.HtmlControls;

using NorthwindSample.BusinessServiceInterfaces;
using NorthwindSample.Data;
using NorthwindSample.DataRetrieval;

namespace NorthwindSample.WebUI
{
	/// <summary>
	/// Code-behind file for the OrderDetails.aspx Page
	/// </summary>
	public class OrderDetails : EditablePage
	{
		#region Constants


		#endregion


		#region Fields

		private Int32 m_OrderIDCurrent;
		protected System.Web.UI.WebControls.CompareValidator ctlOrderIDValNotNull;
		protected System.Web.UI.WebControls.CompareValidator ctlProductIDValNotNull;
		protected System.Web.UI.WebControls.RequiredFieldValidator ctlUnitPriceValRequired;
		protected System.Web.UI.WebControls.CompareValidator ctlUnitPriceDataTypeCurrency;
		protected System.Web.UI.WebControls.RequiredFieldValidator ctlQuantityValRequired;
		protected System.Web.UI.WebControls.RangeValidator ctlQuantityValInt16;
		protected System.Web.UI.WebControls.RequiredFieldValidator ctlDiscountValRequired;
		private Int32 m_ProductIDCurrent;
		

		#endregion

				
		#region Page Events

		/// <summary>
		/// Event raised when the page is requested
		/// </summary>
		private void Page_Load(object sender, System.EventArgs e)
		{
			//
			// Find primary key values to use to populate the form
			//
			if (HasQueryStringParameter("OrderID") && HasQueryStringParameter("ProductID"))
			{
				m_OrderIDCurrent = Convert.ToInt32(Request.QueryString["OrderID"]);
				m_ProductIDCurrent = Convert.ToInt32(Request.QueryString["ProductID"]);
				
				DataEntryMode = PageDataEntryMode.EditRow;

				PageTitle = string.Format("Order Details - Editing {0}: {1}, {2}: {3}", "OrderID", m_OrderIDCurrent, "ProductID", m_ProductIDCurrent);
			}
			else
			{
				DataEntryMode = PageDataEntryMode.AddRow;

				PageTitle = "Order Details - Adding a new entry";
				lblMessage.Text = "Adding a new entry";
			}

			if (Page.IsPostBack)
			{
			
			}
			else
			{
				//
				// Initial Page Request
				//
				PopulateControls();

				if (DataEntryMode == PageDataEntryMode.EditRow || DataEntryMode == PageDataEntryMode.ViewRow)
				{
					if (!LoadData())
					{
						//
						// Could not load the row from the database
						//
						lblMessage.Text = "Error loading OrderDetails";

						DataEntryMode = PageDataEntryMode.ErrorOccurred;
						
						DisableDataEntryControls(this.Controls);
					}
				}
			}
		}

		#endregion


		#region Event Handlers for Controls

		/// <summary>
		/// Apply the changes and return to the previous screen
		/// </summary>
		private void btnOK_Click(object sender, System.EventArgs e)
		{
			if (SaveData())
			{
				Response.Redirect(UrlPrevious.ToString());
			}
		}


		/// <summary>
		/// Apply the changes and remain on this page
		/// </summary>
		private void btnApply_Click(object sender, System.EventArgs e)
		{
			if (SaveData())
			{
				//
				// Redirect back to this page in Edit mode
				//
				if (DataEntryMode == PageDataEntryMode.AddRow)
				{	
					UriBuilder EditUri = new UriBuilder(Request.Url);
					EditUri.Query += string.Format("{0}={1}&{2}={3}", "OrderID", m_OrderIDCurrent, "ProductID", m_ProductIDCurrent);

					//
					// Redirect back to this page 
					// with the primary key information in the query string
					//
					Response.Redirect(EditUri.ToString());
							
				}
				else
				{
					lblMessage.Text = "Order Details saved";

					LoadData();
				}
			}
			else
			{
				lblMessage.Text = "Error saving Order Details";
				DataEntryMode = PageDataEntryMode.ErrorOccurred;
			}
		}
		
		
		/// <summary>
		/// return to the previous screen
		/// </summary>
		private void btnCancel_Click(object sender, System.EventArgs e)
		{
			Response.Redirect(UrlPrevious.ToString());
		}
		
		#endregion


		#region Private Methods
		
		/// <summary>
		/// Loads data from the database for drop down lists
		/// </summary>
		private void PopulateControls()
		{
			
			//
			// Populate the OrderID Drop Down List
			//
			OrdersDataSet OrdersDS = new OrdersDataSet();
			IOrdersService OrdersLogic = DataRetrievalFactory.GetDataRetrievalFactory().CreateOrdersService();
			
			if (OrdersLogic.GetAll(OrdersDS) > 0)
			{
				ListItem OrdersListItemNew;
				foreach (OrdersDataSet.OrdersRow OrdersCurrent in OrdersDS.Orders.Rows)
				{
					OrdersListItemNew = new ListItem();
					OrdersListItemNew.Value = OrdersCurrent.OrderID.ToString();
					OrdersListItemNew.Text = OrdersCurrent.OrderID.ToString();

					ctlOrderID.Items.Add(OrdersListItemNew);
				}
			}
			
			//
			// Populate the ProductID Drop Down List
			//
			ProductsDataSet ProductsDS = new ProductsDataSet();
			IProductsService ProductsLogic = DataRetrievalFactory.GetDataRetrievalFactory().CreateProductsService();
			
			if (ProductsLogic.GetAll(ProductsDS) > 0)
			{
				ListItem ProductsListItemNew;
				foreach (ProductsDataSet.ProductsRow ProductsCurrent in ProductsDS.Products.Rows)
				{
					ProductsListItemNew = new ListItem();
					ProductsListItemNew.Value = ProductsCurrent.ProductID.ToString();
					ProductsListItemNew.Text = ProductsCurrent.ProductName;

					ctlProductID.Items.Add(ProductsListItemNew);
				}
			}
			
		}
		
		/// <summary>
		/// Loads a row from the Order Details table for viewing or editing
		/// </summary>
		/// <returns>true on success, false on error</returns>
		private bool LoadData()
		{
			if ((DataEntryMode != PageDataEntryMode.EditRow) && (DataEntryMode != PageDataEntryMode.ViewRow))
			{
				return true;
			}
			
			OrderDetailsDataSet OrderDetailsDS = new OrderDetailsDataSet();
			IOrderDetailsService OrderDetailsLogic = DataRetrievalFactory.GetDataRetrievalFactory().CreateOrderDetailsService();
			
			if (OrderDetailsLogic.GetByOrderIDAndProductID(OrderDetailsDS, m_OrderIDCurrent, m_ProductIDCurrent) == 0)
			{
				//
				// OrderDetails Row not found
				//
				return false;
			}

			OrderDetailsDataSet.OrderDetailsRow OrderDetailsRowCurrent = OrderDetailsDS.OrderDetails[0];
			ListItem SelectedListItem;
			
			//
			// Populate the Page controls from the DataRow
			//
			SelectedListItem = ctlOrderID.Items.FindByValue(OrderDetailsRowCurrent.OrderID.ToString());
			if (SelectedListItem != null)
			{
				ctlOrderID.ClearSelection();
				SelectedListItem.Selected = true;
			}
			SelectedListItem = ctlProductID.Items.FindByValue(OrderDetailsRowCurrent.ProductID.ToString());
			if (SelectedListItem != null)
			{
				ctlProductID.ClearSelection();
				SelectedListItem.Selected = true;
			}
			ctlUnitPrice.Text = OrderDetailsRowCurrent.UnitPrice.ToString("0.00");
			ctlQuantity.Text = OrderDetailsRowCurrent.Quantity.ToString();
			ctlDiscount.Text = OrderDetailsRowCurrent.Discount.ToString();
			
			
			return true;
		}
		
		
		/// <summary>
		/// Adds or updates the row in the Database
		/// </summary>
		/// <returns>true on success, false on error</returns>
		private bool SaveData()
		{
			//
			// Check that the Form has passed validation
			//
			Page.Validate();
			
			if (!Page.IsValid)
			{
				// Validation failed
				return false;
			}
			
			OrderDetailsDataSet OrderDetailsDS = new OrderDetailsDataSet();
			IOrderDetailsService OrderDetailsLogic = DataRetrievalFactory.GetDataRetrievalFactory().CreateOrderDetailsService();
			OrderDetailsDataSet.OrderDetailsRow OrderDetailsRowCurrent;
			
			
			switch (DataEntryMode)
			{
				case PageDataEntryMode.AddRow:
					//
					// Create a New Row
					//
					OrderDetailsRowCurrent = OrderDetailsDS.OrderDetails.NewOrderDetailsRow();
					break;
					
				case PageDataEntryMode.EditRow:
					//
					// Update existing Row
					//
					if (OrderDetailsLogic.GetByOrderIDAndProductID(OrderDetailsDS, m_OrderIDCurrent, m_ProductIDCurrent) == 0)
					{
						//
						// OrderDetails Row not found
						//
						return false;
					}
					else
					{
						OrderDetailsRowCurrent = OrderDetailsDS.OrderDetails[0];
					}
					break;
					
				default:
					return false;
			}

			//
			// Set the DataRow values from the Page Controls
			//
			
			// OrderID
			OrderDetailsRowCurrent.OrderID = Convert.ToInt32(ctlOrderID.SelectedItem.Value);
			// ProductID
			OrderDetailsRowCurrent.ProductID = Convert.ToInt32(ctlProductID.SelectedItem.Value);
			// UnitPrice
			OrderDetailsRowCurrent.UnitPrice = Convert.ToDecimal(ctlUnitPrice.Text);
			// Quantity
			OrderDetailsRowCurrent.Quantity = Convert.ToInt16(ctlQuantity.Text);
			// Discount
			OrderDetailsRowCurrent.Discount = Convert.ToSingle(ctlDiscount.Text);
			
			if (DataEntryMode == PageDataEntryMode.AddRow)
			{
				//
				// Add the new Row to the DataSet
				//
				OrderDetailsDS.OrderDetails.Rows.Add(OrderDetailsRowCurrent);
			}

			//
			// Save the changes to the database
			//
			OrderDetailsLogic.UpdateDataSet(OrderDetailsDS);
			
			//
			// Update the primary key values
			//
			m_OrderIDCurrent = OrderDetailsRowCurrent.OrderID;
			m_ProductIDCurrent = OrderDetailsRowCurrent.ProductID;
			
			
			return true;
		}
		
		
		#endregion

		
		#region Web Form Designer generated code
		
		protected System.Web.UI.WebControls.Label lblMessage;
		protected System.Web.UI.WebControls.ValidationSummary ctlValidationSummary;
		protected System.Web.UI.WebControls.Button btnOK;
		protected System.Web.UI.WebControls.Button btnApply;
		protected System.Web.UI.WebControls.Button btnCancel;
		protected System.Web.UI.WebControls.DropDownList ctlOrderID;
		protected System.Web.UI.WebControls.DropDownList ctlProductID;
		protected System.Web.UI.WebControls.TextBox ctlUnitPrice;
		protected System.Web.UI.WebControls.TextBox ctlQuantity;
		protected System.Web.UI.WebControls.TextBox ctlDiscount;
		
		
		override protected void OnInit(EventArgs e)
		{
			//
			// CODEGEN: This call is required by the ASP.NET Web Form Designer.
			//
			InitializeComponent();
			base.OnInit(e);
		}
		
		/// <summary>
		/// Required method for Designer support - do not modify
		/// the contents of this method with the code editor.
		/// </summary>
		private void InitializeComponent()
		{    
			this.btnOK.Click += new System.EventHandler(this.btnOK_Click);
			this.btnCancel.Click += new System.EventHandler(this.btnCancel_Click);
			this.btnApply.Click += new System.EventHandler(this.btnApply_Click);
			this.Load += new System.EventHandler(this.Page_Load);

		}
		
		#endregion
	}
}
