using System;
using System.Collections;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Web;
using System.Web.SessionState;
using System.Web.UI;
using System.Web.UI.WebControls;
using System.Web.UI.HtmlControls;

using RAD.AppFramework.QueryObjects;

using NorthwindSample.BusinessServiceInterfaces;
using NorthwindSample.Data;
using NorthwindSample.DataRetrieval;
using NorthwindSample.Common;
using NorthwindSample.DatabaseSchema;

namespace NorthwindSample.WebUI
{
	/// <summary>
	/// Searches the Shippers table
	/// </summary>
	public class Shippers_Search : SearchPage
	{
		#region Constants



		#endregion


		#region Fields

		

		#endregion


		#region Page Events


		/// <summary>
		/// Event raised when the page is requested
		/// </summary>
		private void Page_Load(object sender, System.EventArgs e)
		{
			// AllowSearchAll = true;

			int CriteriaCount = 0;

			//
			// Load the search criteria from the query string into the controls
			//
			CriteriaCount += LoadSearchString("ShipperID", ShipperID);
			CriteriaCount += LoadSearchString("CompanyName", CompanyName);
			CriteriaCount += LoadSearchString("Phone", Phone);
			

			if (IsPostBack)
			{
			}
			else
			{
				PageTitle = "Shippers Search";

				if (CriteriaCount > 0)
				{
					ShippersGrid.CurrentPageIndex = FirstPage;
					LoadData();
				}
			}
		}

		#endregion


		#region Event Handlers for Controls

		/// <summary>
		/// Event raised when a button is pressed on the grid
		/// </summary>
		private void ShippersGrid_ItemCommand(object source, DataGridCommandEventArgs e)
		{
			switch (e.CommandName)
			{
				case "Edit":
					Response.Redirect(
						string.Format("Shippers.aspx?{0}={1}", "ShipperID", ShippersGrid.DataKeys[e.Item.ItemIndex].ToString())
						);	
					break;
			}
		}

		/// <summary>
		/// Event raised when the next or previous links are clicked on the grid
		/// </summary>
		private void ShippersGrid_PageIndexChanged(object source, DataGridPageChangedEventArgs e)
		{
			ShippersGrid.CurrentPageIndex = e.NewPageIndex;

			LoadData();
		}

		/// <summary>
		/// Event raised when a column heading is clicked and sorting is enabled
		/// </summary>
		private void ShippersGrid_SortCommand(object source, DataGridSortCommandEventArgs e)
		{
			RedirectWithSortExpression(e.SortExpression);
		}

		
		#endregion


		#region Methods - Private

		/// <summary>
		/// Searches the Shippers table for rows that match 
		/// the criteria entered in the search form
		/// </summary>
		private void LoadData()
		{
			Query m_ShippersQuery = CommonFactory.CreateQuery();

			AddToQuery(m_ShippersQuery, ShippersTable.ShipperID, Comparison.EqualTo, ShipperID);
			AddToQuery(m_ShippersQuery, ShippersTable.CompanyName, Comparison.Contains, CompanyName);
			AddToQuery(m_ShippersQuery, ShippersTable.Phone, Comparison.Contains, Phone);
			

			AddSortToQuery(m_ShippersQuery, typeof(ShippersTable));
			
			IShippersService ShippersLogic = DataRetrievalFactory.GetDataRetrievalFactory().CreateShippersService();
			int ResultCount = ShippersLogic.GetByQuery(m_ShippersDataSet, m_ShippersQuery);

			if (ResultCount > 0)
			{
				lblMessage.Text = string.Format(MatchesFoundMessage, ResultCount);
				ShippersGrid.DataBind();
			}
			else
			{
				lblMessage.Text = NoMatchesMessage;
			}			
		}


		#endregion


		#region Web Form Designer generated code
		
		protected NorthwindSample.Data.ShippersDataSet m_ShippersDataSet;
		protected System.Web.UI.WebControls.Label lblMessage;
		protected System.Web.UI.WebControls.DataGrid ShippersGrid;
		protected System.Web.UI.HtmlControls.HtmlInputText ShipperID;
		protected System.Web.UI.HtmlControls.HtmlInputText CompanyName;
		protected System.Web.UI.HtmlControls.HtmlInputText Phone;
		
		
		override protected void OnInit(EventArgs e)
		{
			//
			// CODEGEN: This call is required by the ASP.NET Web Form Designer.
			//
			InitializeComponent();
			base.OnInit(e);
		}
		
		/// <summary>
		/// Required method for Designer support - do not modify
		/// the contents of this method with the code editor.
		/// </summary>
		private void InitializeComponent()
		{    
			this.m_ShippersDataSet = new NorthwindSample.Data.ShippersDataSet();
			((System.ComponentModel.ISupportInitialize)(this.m_ShippersDataSet)).BeginInit();
			this.ShippersGrid.ItemCommand += new System.Web.UI.WebControls.DataGridCommandEventHandler(this.ShippersGrid_ItemCommand);
			this.ShippersGrid.PageIndexChanged += new System.Web.UI.WebControls.DataGridPageChangedEventHandler(this.ShippersGrid_PageIndexChanged);
			this.ShippersGrid.SortCommand += new System.Web.UI.WebControls.DataGridSortCommandEventHandler(this.ShippersGrid_SortCommand);
			// 
			// m_ShippersDataSet
			// 
			this.m_ShippersDataSet.DataSetName = "ShippersDataSet";
			this.m_ShippersDataSet.Locale = new System.Globalization.CultureInfo("en-US");
			this.Load += new System.EventHandler(this.Page_Load);
			((System.ComponentModel.ISupportInitialize)(this.m_ShippersDataSet)).EndInit();

		}
		
		#endregion

	}
}
