using System;
using System.Collections;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Web;
using System.Web.SessionState;
using System.Web.UI;
using System.Web.UI.WebControls;
using System.Web.UI.HtmlControls;

using NorthwindSample.BusinessServiceInterfaces;
using NorthwindSample.Data;
using NorthwindSample.DataRetrieval;

namespace NorthwindSample.WebUI
{
	/// <summary>
	/// Code-behind file for the Territories.aspx Page
	/// </summary>
	public class Territories : EditablePage
	{
		#region Constants


		#endregion


		#region Fields

		private String m_TerritoryIDCurrent;
		

		#endregion

				
		#region Page Events

		/// <summary>
		/// Event raised when the page is requested
		/// </summary>
		private void Page_Load(object sender, System.EventArgs e)
		{
			//
			// Find primary key values to use to populate the form
			//
			if (HasQueryStringParameter("TerritoryID"))
			{
				m_TerritoryIDCurrent = Convert.ToString(Request.QueryString["TerritoryID"]);
				
				DataEntryMode = PageDataEntryMode.EditRow;

				PageTitle = string.Format("Territories - Editing {0}: {1}", "TerritoryID", m_TerritoryIDCurrent);
			}
			else
			{
				DataEntryMode = PageDataEntryMode.AddRow;

				PageTitle = "Territories - Adding a new entry";
				lblMessage.Text = "Adding a new entry";
			}

			if (Page.IsPostBack)
			{
			
			}
			else
			{
				//
				// Initial Page Request
				//
				PopulateControls();

				if (DataEntryMode == PageDataEntryMode.EditRow || DataEntryMode == PageDataEntryMode.ViewRow)
				{
					if (!LoadData())
					{
						//
						// Could not load the row from the database
						//
						lblMessage.Text = "Error loading Territories";

						DataEntryMode = PageDataEntryMode.ErrorOccurred;
						
						DisableDataEntryControls(this.Controls);
					}
				}
			}
		}

		#endregion


		#region Event Handlers for Controls

		/// <summary>
		/// Apply the changes and return to the previous screen
		/// </summary>
		private void btnOK_Click(object sender, System.EventArgs e)
		{
			if (SaveData())
			{
				Response.Redirect(UrlPrevious.ToString());
			}
		}


		/// <summary>
		/// Apply the changes and remain on this page
		/// </summary>
		private void btnApply_Click(object sender, System.EventArgs e)
		{
			if (SaveData())
			{
				//
				// Redirect back to this page in Edit mode
				//
				if (DataEntryMode == PageDataEntryMode.AddRow)
				{	
					UriBuilder EditUri = new UriBuilder(Request.Url);
					EditUri.Query += string.Format("{0}={1}", "TerritoryID", m_TerritoryIDCurrent);

					//
					// Redirect back to this page 
					// with the primary key information in the query string
					//
					Response.Redirect(EditUri.ToString());
							
				}
				else
				{
					lblMessage.Text = "Territories saved";

					LoadData();
				}
			}
			else
			{
				lblMessage.Text = "Error saving Territories";
				DataEntryMode = PageDataEntryMode.ErrorOccurred;
			}
		}
		
		
		/// <summary>
		/// return to the previous screen
		/// </summary>
		private void btnCancel_Click(object sender, System.EventArgs e)
		{
			Response.Redirect(UrlPrevious.ToString());
		}
		
		#endregion


		#region Private Methods
		
		/// <summary>
		/// Loads data from the database for drop down lists
		/// </summary>
		private void PopulateControls()
		{
			
			//
			// Populate the RegionID Drop Down List
			//
			RegionDataSet RegionDS = new RegionDataSet();
			IRegionService RegionLogic = DataRetrievalFactory.GetDataRetrievalFactory().CreateRegionService();
			
			if (RegionLogic.GetAll(RegionDS) > 0)
			{
				ListItem RegionListItemNew;
				foreach (RegionDataSet.RegionRow RegionCurrent in RegionDS.Region.Rows)
				{
					RegionListItemNew = new ListItem();
					RegionListItemNew.Value = RegionCurrent.RegionID.ToString();
					RegionListItemNew.Text = RegionCurrent.RegionID.ToString();

					ctlRegionID.Items.Add(RegionListItemNew);
				}
			}
			
		}
		
		/// <summary>
		/// Loads a row from the Territories table for viewing or editing
		/// </summary>
		/// <returns>true on success, false on error</returns>
		private bool LoadData()
		{
			if ((DataEntryMode != PageDataEntryMode.EditRow) && (DataEntryMode != PageDataEntryMode.ViewRow))
			{
				return true;
			}
			
			TerritoriesDataSet TerritoriesDS = new TerritoriesDataSet();
			ITerritoriesService TerritoriesLogic = DataRetrievalFactory.GetDataRetrievalFactory().CreateTerritoriesService();
			
			if (TerritoriesLogic.GetByTerritoryID(TerritoriesDS, m_TerritoryIDCurrent) == 0)
			{
				//
				// Territories Row not found
				//
				return false;
			}

			TerritoriesDataSet.TerritoriesRow TerritoriesRowCurrent = TerritoriesDS.Territories[0];
			ListItem SelectedListItem;
			
			//
			// Populate the Page controls from the DataRow
			//
			ctlTerritoryID.Text = TerritoriesRowCurrent.TerritoryID;
			ctlTerritoryDescription.Text = TerritoriesRowCurrent.TerritoryDescription;
			SelectedListItem = ctlRegionID.Items.FindByValue(TerritoriesRowCurrent.RegionID.ToString());
			if (SelectedListItem != null)
			{
				ctlRegionID.ClearSelection();
				SelectedListItem.Selected = true;
			}
			
			
			return true;
		}
		
		
		/// <summary>
		/// Adds or updates the row in the Database
		/// </summary>
		/// <returns>true on success, false on error</returns>
		private bool SaveData()
		{
			//
			// Check that the Form has passed validation
			//
			Page.Validate();
			
			if (!Page.IsValid)
			{
				// Validation failed
				return false;
			}
			
			TerritoriesDataSet TerritoriesDS = new TerritoriesDataSet();
			ITerritoriesService TerritoriesLogic = DataRetrievalFactory.GetDataRetrievalFactory().CreateTerritoriesService();
			TerritoriesDataSet.TerritoriesRow TerritoriesRowCurrent;
			
			
			switch (DataEntryMode)
			{
				case PageDataEntryMode.AddRow:
					//
					// Create a New Row
					//
					TerritoriesRowCurrent = TerritoriesDS.Territories.NewTerritoriesRow();
					break;
					
				case PageDataEntryMode.EditRow:
					//
					// Update existing Row
					//
					if (TerritoriesLogic.GetByTerritoryID(TerritoriesDS, m_TerritoryIDCurrent) == 0)
					{
						//
						// Territories Row not found
						//
						return false;
					}
					else
					{
						TerritoriesRowCurrent = TerritoriesDS.Territories[0];
					}
					break;
					
				default:
					return false;
			}

			//
			// Set the DataRow values from the Page Controls
			//
			
			// TerritoryID
			TerritoriesRowCurrent.TerritoryID = ctlTerritoryID.Text;
			// TerritoryDescription
			TerritoriesRowCurrent.TerritoryDescription = ctlTerritoryDescription.Text;
			// RegionID
			TerritoriesRowCurrent.RegionID = Convert.ToInt32(ctlRegionID.SelectedItem.Value);
			
			if (DataEntryMode == PageDataEntryMode.AddRow)
			{
				//
				// Add the new Row to the DataSet
				//
				TerritoriesDS.Territories.Rows.Add(TerritoriesRowCurrent);
			}

			//
			// Save the changes to the database
			//
			TerritoriesLogic.UpdateDataSet(TerritoriesDS);
			
			//
			// Update the primary key values
			//
			m_TerritoryIDCurrent = TerritoriesRowCurrent.TerritoryID;
			
			
			return true;
		}
		
		
		#endregion

		
		#region Web Form Designer generated code
		
		protected System.Web.UI.WebControls.Label lblMessage;
		protected System.Web.UI.WebControls.ValidationSummary ctlValidationSummary;
		protected System.Web.UI.WebControls.Button btnOK;
		protected System.Web.UI.WebControls.Button btnApply;
		protected System.Web.UI.WebControls.Button btnCancel;
		protected System.Web.UI.WebControls.TextBox ctlTerritoryID;
		protected System.Web.UI.WebControls.TextBox ctlTerritoryDescription;
		protected System.Web.UI.WebControls.DropDownList ctlRegionID;
		
		
		override protected void OnInit(EventArgs e)
		{
			//
			// CODEGEN: This call is required by the ASP.NET Web Form Designer.
			//
			InitializeComponent();
			base.OnInit(e);
		}
		
		/// <summary>
		/// Required method for Designer support - do not modify
		/// the contents of this method with the code editor.
		/// </summary>
		private void InitializeComponent()
		{    
			this.btnOK.Click += new System.EventHandler(this.btnOK_Click);
			this.btnApply.Click += new System.EventHandler(this.btnApply_Click);
			this.btnCancel.Click += new System.EventHandler(this.btnCancel_Click);
			this.Load += new System.EventHandler(this.Page_Load);
			
		}
		
		#endregion
	}
}
